@@ -279,9 +279,7 @@ var _Color = class {
     ));
   }
   toString() {
-    if (!this._toString) {
-      this._toString = _Color.Format.CSS.format(this);
-    }
+    this._toString ?? (this._toString = _Color.Format.CSS.format(this));
     return this._toString;
   }
   static getLighterColor(of, relative, factor) {
@@ -932,33 +930,32 @@ function calcANSI8bitColor(colorNumber) {
 }
 
 // extensions/notebook-renderers/src/textHelper.ts
-function generateViewMoreElement(outputId) {
+function generateViewMoreElement(outputId, adjustableSize) {
   const container = document.createElement("span");
   const first = document.createElement("span");
-  first.textContent = "Output exceeds the ";
-  const second = document.createElement("a");
-  second.textContent = "size limit";
-  second.href = `command:workbench.action.openSettings?%5B%22notebook.output.textLineLimit%22%5D`;
+  if (adjustableSize) {
+    first.textContent = "Output exceeds the ";
+    const second = document.createElement("a");
+    second.textContent = "size limit";
+    second.href = `command:workbench.action.openSettings?%5B%22notebook.output.textLineLimit%22%5D`;
+    container.appendChild(first);
+    container.appendChild(second);
+  } else {
+    first.textContent = "Output exceeds the maximium size limit";
+    container.appendChild(first);
+  }
   const third = document.createElement("span");
-  third.textContent = ". Open the full output data";
+  third.textContent = ". Open the full output data ";
   const forth = document.createElement("a");
-  forth.textContent = " in a text editor";
+  forth.textContent = "in a text editor";
   forth.href = `command:workbench.action.openLargeOutput?${outputId}`;
-  container.appendChild(first);
-  container.appendChild(second);
   container.appendChild(third);
   container.appendChild(forth);
   return container;
 }
-function truncatedArrayOfString(id, outputs, linesLimit, container) {
-  const buffer = outputs.join("\n").split(/\r\n|\r|\n/g);
+function truncatedArrayOfString(id, buffer, linesLimit, container) {
   const lineCount = buffer.length;
-  if (lineCount < linesLimit) {
-    const spanElement = handleANSIOutput(buffer.slice(0, linesLimit).join("\n"));
-    container.appendChild(spanElement);
-    return;
-  }
-  container.appendChild(generateViewMoreElement(id));
+  container.appendChild(generateViewMoreElement(id, true));
   const div = document.createElement("div");
   container.appendChild(div);
   div.appendChild(handleANSIOutput(buffer.slice(0, linesLimit - 5).join("\n")));
@@ -969,6 +966,29 @@ function truncatedArrayOfString(id, outputs, linesLimit, container) {
   container.appendChild(div2);
   div2.appendChild(handleANSIOutput(buffer.slice(lineCount - 5).join("\n")));
 }
+function scrollableArrayOfString(id, buffer, container) {
+  container.classList.add("scrollable");
+  if (buffer.length > 5e3) {
+    container.appendChild(generateViewMoreElement(id, false));
+  }
+  const div = document.createElement("div");
+  container.appendChild(div);
+  div.appendChild(handleANSIOutput(buffer.slice(0, 5e3).join("\n")));
+}
+function insertOutput(id, outputs, linesLimit, scrollable, container) {
+  const buffer = outputs.join("\n").split(/\r\n|\r|\n/g);
+  const lineCount = buffer.length;
+  if (lineCount < linesLimit) {
+    const spanElement = handleANSIOutput(buffer.join("\n"));
+    container.appendChild(spanElement);
+    return;
+  }
+  if (scrollable) {
+    scrollableArrayOfString(id, buffer, container);
+  } else {
+    truncatedArrayOfString(id, buffer, linesLimit, container);
+  }
+}
 
 // extensions/notebook-renderers/src/index.ts
 function clearContainer(container) {
@@ -1019,23 +1039,34 @@ var domEval = (container) => {
     container.appendChild(scriptTag).parentNode.removeChild(scriptTag);
   }
 };
-function renderHTML(outputInfo, container, hooks) {
+async function renderHTML(outputInfo, container, signal, hooks) {
   clearContainer(container);
   let element = document.createElement("div");
   const htmlContent = outputInfo.text();
   const trustedHtml = ttPolicy?.createHTML(htmlContent) ?? htmlContent;
   element.innerHTML = trustedHtml;
   for (const hook of hooks) {
-    element = hook.postRender(outputInfo, element) ?? element;
+    element = await hook.postRender(outputInfo, element, signal) ?? element;
+    if (signal.aborted) {
+      return;
+    }
   }
   container.appendChild(element);
   domEval(element);
 }
-function renderJavascript(outputInfo, container) {
-  const str = outputInfo.text();
-  const scriptVal = `<script type="application/javascript">${str}<\/script>`;
+async function renderJavascript(outputInfo, container, signal, hooks) {
+  let scriptText = outputInfo.text();
+  for (const hook of hooks) {
+    scriptText = await hook.preEvaluate(outputInfo, container, scriptText, signal) ?? scriptText;
+    if (signal.aborted) {
+      return;
+    }
+  }
+  const script = document.createElement("script");
+  script.type = "module";
+  script.textContent = scriptText;
   const element = document.createElement("div");
-  const trustedHtml = ttPolicy?.createHTML(scriptVal) ?? scriptVal;
+  const trustedHtml = ttPolicy?.createHTML(script.outerHTML) ?? script.outerHTML;
   element.innerHTML = trustedHtml;
   container.appendChild(element);
   domEval(element);
@@ -1055,7 +1086,7 @@ function renderError(outputInfo, container, ctx) {
     stack.classList.add("traceback");
     stack.style.margin = "8px 0";
     const element2 = document.createElement("span");
-    truncatedArrayOfString(outputInfo.id, [err.stack ?? ""], ctx.settings.lineLimit, element2);
+    insertOutput(outputInfo.id, [err.stack ?? ""], ctx.settings.lineLimit, false, element2);
     stack.appendChild(element2);
     container.appendChild(stack);
   } else {
@@ -1079,7 +1110,7 @@ function renderStream(outputInfo, container, error, ctx) {
     if (outputElement && outputElement.getAttribute("output-mime-type") === outputInfo.mime) {
       const text2 = outputInfo.text();
       const element2 = document.createElement("span");
-      truncatedArrayOfString(outputInfo.id, [text2], ctx.settings.lineLimit, element2);
+      insertOutput(outputInfo.id, [text2], ctx.settings.lineLimit, ctx.settings.outputScrolling, element2);
       outputElement.appendChild(element2);
       return;
     }
@@ -1087,7 +1118,7 @@ function renderStream(outputInfo, container, error, ctx) {
   const element = document.createElement("span");
   element.classList.add("output-stream");
   const text = outputInfo.text();
-  truncatedArrayOfString(outputInfo.id, [text], ctx.settings.lineLimit, element);
+  insertOutput(outputInfo.id, [text], ctx.settings.lineLimit, ctx.settings.outputScrolling, element);
   while (container.firstChild) {
     container.removeChild(container.firstChild);
   }
@@ -1102,31 +1133,42 @@ function renderText(outputInfo, container, ctx) {
   const contentNode = document.createElement("div");
   contentNode.classList.add("output-plaintext");
   const text = outputInfo.text();
-  truncatedArrayOfString(outputInfo.id, [text], ctx.settings.lineLimit, contentNode);
+  insertOutput(outputInfo.id, [text], ctx.settings.lineLimit, ctx.settings.outputScrolling, contentNode);
   container.appendChild(contentNode);
 }
 var activate = (ctx) => {
   const disposables = /* @__PURE__ */ new Map();
   const htmlHooks = /* @__PURE__ */ new Set();
+  const jsHooks = /* @__PURE__ */ new Set();
   const latestContext = ctx;
   const style = document.createElement("style");
   style.textContent = `
 	.output-plaintext,
 	.output-stream,
 	.traceback {
+		display: inline-block;
+		white-space: pre-wrap;
+		width: 100%;
 		line-height: var(--notebook-cell-output-line-height);
 		font-family: var(--notebook-cell-output-font-family);
-		white-space: pre-wrap;
-		word-wrap: break-word;
-
 		font-size: var(--notebook-cell-output-font-size);
 		user-select: text;
 		-webkit-user-select: text;
 		-ms-user-select: text;
 		cursor: auto;
 	}
-	span.output-stream {
-		display: inline-block;
+	output-plaintext,
+	.traceback {
+		word-wrap: break-word;
+	}
+	.output > span.scrollable {
+		overflow-y: scroll;
+		max-height: var(--notebook-cell-output-max-height);
+		border: var(--vscode-editorWidget-border);
+		border-style: solid;
+		padding-left: 4px;
+		box-sizing: border-box;
+		border-width: 1px;
 	}
 	.output-plaintext .code-bold,
 	.output-stream .code-bold,
@@ -1151,25 +1193,23 @@ var activate = (ctx) => {
 	`;
   document.body.appendChild(style);
   return {
-    renderOutputItem: (outputInfo, element) => {
+    renderOutputItem: async (outputInfo, element, signal) => {
       switch (outputInfo.mime) {
         case "text/html":
-        case "image/svg+xml":
-          {
-            if (!ctx.workspace.isTrusted) {
-              return;
-            }
-            renderHTML(outputInfo, element, htmlHooks);
+        case "image/svg+xml": {
+          if (!ctx.workspace.isTrusted) {
+            return;
           }
+          await renderHTML(outputInfo, element, signal, htmlHooks);
           break;
-        case "application/javascript":
-          {
-            if (!ctx.workspace.isTrusted) {
-              return;
-            }
-            renderJavascript(outputInfo, element);
+        }
+        case "application/javascript": {
+          if (!ctx.workspace.isTrusted) {
+            return;
           }
+          renderJavascript(outputInfo, element, signal, jsHooks);
           break;
+        }
         case "image/gif":
         case "image/png":
         case "image/jpeg":
@@ -1220,6 +1260,14 @@ var activate = (ctx) => {
           htmlHooks.delete(hook);
         }
       };
+    },
+    experimental_registerJavaScriptRenderingHook: (hook) => {
+      jsHooks.add(hook);
+      return {
+        dispose: () => {
+          jsHooks.delete(hook);
+        }
+      };
     }
   };
 };
