@@ -3,6 +3,7 @@
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
 use super::paths::{InstalledServer, LastUsedServers, ServerPaths};
+use crate::constants::{APPLICATION_NAME, QUALITYLESS_PRODUCT_NAME, QUALITYLESS_SERVER_NAME};
 use crate::options::{Quality, TelemetryLevel};
 use crate::state::LauncherPaths;
 use crate::update_service::{
@@ -12,7 +13,7 @@ use crate::util::command::{capture_command, kill_tree};
 use crate::util::errors::{
 	wrap, AnyError, ExtensionInstallFailed, MissingEntrypointError, WrappedError,
 };
-use crate::util::http;
+use crate::util::http::{self, SimpleHttp};
 use crate::util::io::SilentCopyProgress;
 use crate::util::machine::process_exists;
 use crate::{debug, info, log, span, spanf, trace, warning};
@@ -24,6 +25,7 @@ use std::fs;
 use std::fs::File;
 use std::io::{ErrorKind, Write};
 use std::path::{Path, PathBuf};
+use std::sync::Arc;
 use std::time::Duration;
 use tokio::fs::remove_file;
 use tokio::io::{AsyncBufReadExt, BufReader};
@@ -169,14 +171,22 @@ impl ResolvedServerParams {
 }
 
 impl ServerParamsRaw {
-	pub async fn resolve(self, log: &log::Logger) -> Result<ResolvedServerParams, AnyError> {
+	pub async fn resolve(
+		self,
+		log: &log::Logger,
+		http: impl SimpleHttp + Send + Sync + 'static,
+	) -> Result<ResolvedServerParams, AnyError> {
 		Ok(ResolvedServerParams {
-			release: self.get_or_fetch_commit_id(log).await?,
+			release: self.get_or_fetch_commit_id(log, http).await?,
 			code_server_args: self.code_server_args,
 		})
 	}
 
-	async fn get_or_fetch_commit_id(&self, log: &log::Logger) -> Result<Release, AnyError> {
+	async fn get_or_fetch_commit_id(
+		&self,
+		log: &log::Logger,
+		http: impl SimpleHttp + Send + Sync + 'static,
+	) -> Result<Release, AnyError> {
 		let target = match self.headless {
 			true => TargetKind::Server,
 			false => TargetKind::Web,
@@ -192,7 +202,7 @@ impl ServerParamsRaw {
 			});
 		}
 
-		UpdateService::new(log.clone(), reqwest::Client::new())
+		UpdateService::new(log.clone(), http)
 			.get_latest_commit(self.platform, target, self.quality)
 			.await
 	}
@@ -209,17 +219,19 @@ struct UpdateServerVersion {
 }
 
 /// Code server listening on a port address.
+#[derive(Clone)]
 pub struct SocketCodeServer {
 	pub commit_id: String,
 	pub socket: PathBuf,
-	pub origin: CodeServerOrigin,
+	pub origin: Arc<CodeServerOrigin>,
 }
 
 /// Code server listening on a socket address.
+#[derive(Clone)]
 pub struct PortCodeServer {
 	pub commit_id: String,
 	pub port: u16,
-	pub origin: CodeServerOrigin,
+	pub origin: Arc<CodeServerOrigin>,
 }
 
 /// A server listening on any address/location.
@@ -282,6 +294,7 @@ async fn install_server_if_needed(
 	log: &log::Logger,
 	paths: &ServerPaths,
 	release: &Release,
+	http: impl SimpleHttp + Send + Sync + 'static,
 ) -> Result<(), AnyError> {
 	if paths.executable.exists() {
 		info!(
@@ -295,7 +308,7 @@ async fn install_server_if_needed(
 	let tar_file_path = spanf!(
 		log,
 		log.span("server.download"),
-		download_server(&paths.server_dir, release, log)
+		download_server(&paths.server_dir, release, log, http)
 	)?;
 
 	span!(
@@ -311,28 +324,22 @@ async fn download_server(
 	path: &Path,
 	release: &Release,
 	log: &log::Logger,
+	http: impl SimpleHttp + Send + Sync + 'static,
 ) -> Result<PathBuf, AnyError> {
-	let response = UpdateService::new(log.clone(), reqwest::Client::new())
+	let response = UpdateService::new(log.clone(), http)
 		.get_download_stream(release)
 		.await?;
 
 	let mut save_path = path.to_owned();
-
-	let fname = response
-		.url()
-		.path_segments()
-		.and_then(|segments| segments.last())
-		.and_then(|name| if name.is_empty() { None } else { Some(name) })
-		.unwrap_or("tmp.zip");
+	save_path.push("archive");
 
 	info!(
 		log,
-		"Downloading VS Code server {} -> {}",
-		response.url(),
+		"Downloading {} server -> {}",
+		QUALITYLESS_PRODUCT_NAME,
 		save_path.display()
 	);
 
-	save_path.push(fname);
 	http::download_into_file(
 		&save_path,
 		log.get_download_logger("server download progress:"),
@@ -352,7 +359,7 @@ fn install_server(
 
 	unzip_downloaded_release(compressed_file, &paths.server_dir, SilentCopyProgress())?;
 
-	match fs::remove_file(&compressed_file) {
+	match fs::remove_file(compressed_file) {
 		Ok(()) => {}
 		Err(e) => {
 			if e.kind() != ErrorKind::NotFound {
@@ -399,18 +406,20 @@ async fn do_extension_install_on_running_server(
 	}
 }
 
-pub struct ServerBuilder<'a> {
+pub struct ServerBuilder<'a, Http: SimpleHttp + Send + Sync + Clone> {
 	logger: &'a log::Logger,
 	server_params: &'a ResolvedServerParams,
 	last_used: LastUsedServers<'a>,
 	server_paths: ServerPaths,
+	http: Http,
 }
 
-impl<'a> ServerBuilder<'a> {
+impl<'a, Http: SimpleHttp + Send + Sync + Clone + 'static> ServerBuilder<'a, Http> {
 	pub fn new(
 		logger: &'a log::Logger,
 		server_params: &'a ResolvedServerParams,
 		launcher_paths: &'a LauncherPaths,
+		http: Http,
 	) -> Self {
 		Self {
 			logger,
@@ -419,6 +428,7 @@ impl<'a> ServerBuilder<'a> {
 			server_paths: server_params
 				.as_installed_server()
 				.server_paths(launcher_paths),
+			http,
 		}
 	}
 
@@ -437,7 +447,7 @@ impl<'a> ServerBuilder<'a> {
 		};
 		info!(self.logger, "Found running server (pid={})", pid);
 		if !Path::new(&self.server_paths.logfile).exists() {
-			warning!(self.logger, "VS Code Server is running but its logfile is missing. Don't delete the VS Code Server manually, run the command 'code-server prune'.");
+			warning!(self.logger, "{} Server is running but its logfile is missing. Don't delete the {} Server manually, run the command '{} prune'.", QUALITYLESS_PRODUCT_NAME, QUALITYLESS_PRODUCT_NAME, APPLICATION_NAME);
 			return Ok(None);
 		}
 
@@ -448,7 +458,7 @@ impl<'a> ServerBuilder<'a> {
 		)
 		.await?;
 
-		let origin = CodeServerOrigin::Existing(pid);
+		let origin = Arc::new(CodeServerOrigin::Existing(pid));
 		let contents = fs::read_to_string(&self.server_paths.logfile)
 			.expect("Something went wrong reading log file");
 
@@ -471,10 +481,18 @@ impl<'a> ServerBuilder<'a> {
 
 	/// Ensures the server is set up in the configured directory.
 	pub async fn setup(&self) -> Result<(), AnyError> {
-		debug!(self.logger, "Installing and setting up VS Code Server...");
+		debug!(
+			self.logger,
+			"Installing and setting up {}...", QUALITYLESS_SERVER_NAME
+		);
 		check_and_create_dir(&self.server_paths.server_dir).await?;
-		install_server_if_needed(self.logger, &self.server_paths, &self.server_params.release)
-			.await?;
+		install_server_if_needed(
+			self.logger,
+			&self.server_paths,
+			&self.server_params.release,
+			self.http.clone(),
+		)
+		.await?;
 		debug!(self.logger, "Server setup complete");
 
 		match self.last_used.add(self.server_params.as_installed_server()) {
@@ -516,7 +534,6 @@ impl<'a> ServerBuilder<'a> {
 
 		let mut cmd = self.get_base_command();
 		cmd.arg("--start-server")
-			.arg("--without-connection-token")
 			.arg("--enable-remote-auto-shutdown")
 			.arg(format!("--socket-path={}", socket.display()));
 
@@ -544,7 +561,7 @@ impl<'a> ServerBuilder<'a> {
 		Ok(SocketCodeServer {
 			commit_id: self.server_params.release.commit.to_owned(),
 			socket,
-			origin,
+			origin: Arc::new(origin),
 		})
 	}
 
