@@ -11,15 +11,29 @@ use serde::{Deserialize, Serialize};
 #[serde(tag = "method", content = "params")]
 #[allow(non_camel_case_types)]
 pub enum ServerRequestMethod {
+	/// Request from the client to start the VS Code server. It will download the
+	/// requested version, if necessary.
 	serve(ServeParams),
+	/// Prunes unused servers on the CLI.
 	prune,
+	/// Empty ping/pong method used for liveness check.
 	ping(EmptyResult),
+	/// Forwards a port from the machine the CLI is running on.
 	forward(ForwardParams),
+	/// Stops forwarding a port from the machine the CLI is running on.
 	unforward(UnforwardParams),
+	/// Gets the hostname of the machine the CLI is running on.
 	gethostname(EmptyResult),
+	/// Checks for or applies an update to the CLI.
 	update(UpdateParams),
+	/// Sent when the remote instance of VS Code has a message for the server.
 	servermsg(ServerMessageParams),
+	/// Sent to make an http call on the local VS Code server.
 	callserverhttp(CallServerHttpParams),
+	/// Sent once with data in response to an `makehttpreq` from the server.
+	httpheaders(HttpHeadersParams),
+	/// Sent (repeatedly) with data in response to an `makehttpreq` from the server.
+	httpbody(HttpBodyParams),
 }
 
 #[derive(Serialize, Debug)]
@@ -28,9 +42,32 @@ pub enum ServerRequestMethod {
 pub enum ClientRequestMethod<'a> {
 	servermsg(RefServerMessageParams<'a>),
 	serverlog(ServerLog<'a>),
+	makehttpreq(HttpRequestParams<'a>),
 	version(VersionParams),
 }
 
+#[derive(Deserialize, Debug)]
+pub struct HttpBodyParams {
+	#[serde(with = "serde_bytes")]
+	pub segment: Vec<u8>,
+	pub complete: bool,
+	pub req_id: u32,
+}
+
+#[derive(Serialize, Debug)]
+pub struct HttpRequestParams<'a> {
+	pub url: &'a str,
+	pub method: &'static str,
+	pub req_id: u32,
+}
+
+#[derive(Deserialize, Debug)]
+pub struct HttpHeadersParams {
+	pub status_code: u16,
+	pub headers: Vec<(String, String)>,
+	pub req_id: u32,
+}
+
 #[derive(Deserialize, Debug)]
 pub struct ForwardParams {
 	pub port: u16,
@@ -52,6 +89,11 @@ pub struct ServeParams {
 	pub commit_id: Option<String>,
 	pub quality: Quality,
 	pub extensions: Vec<String>,
+	#[serde(default)]
+	pub use_local_download: bool,
+	/// If true, the client and server should gzip servermsg's sent in either direction.
+	#[serde(default)]
+	pub compress: bool,
 }
 
 #[derive(Deserialize, Serialize, Debug)]
@@ -84,14 +126,14 @@ pub struct UpdateResult {
 
 #[derive(Deserialize, Debug)]
 pub struct ToServerRequest {
-	pub id: Option<u8>,
+	pub id: Option<u32>,
 	#[serde(flatten)]
 	pub params: ServerRequestMethod,
 }
 
 #[derive(Serialize, Debug)]
 pub struct ToClientRequest<'a> {
-	pub id: Option<u8>,
+	pub id: Option<u32>,
 	#[serde(flatten)]
 	pub params: ClientRequestMethod<'a>,
 }
@@ -101,13 +143,13 @@ pub struct SuccessResponse<T>
 where
 	T: Serialize,
 {
-	pub id: u8,
+	pub id: u32,
 	pub result: T,
 }
 
 #[derive(Serialize, Deserialize)]
 pub struct ErrorResponse {
-	pub id: u8,
+	pub id: u32,
 	pub error: ResponseError,
 }
 
