@@ -4,7 +4,7 @@
  *--------------------------------------------------------------------------------------------*/
 
 import 'mocha';
-import { GitStatusParser, parseGitCommits, parseGitmodules, parseLsTree, parseLsFiles } from '../git';
+import { GitStatusParser, parseGitCommits, parseGitmodules, parseLsTree, parseLsFiles, parseGitRemotes } from '../git';
 import * as assert from 'assert';
 import { splitInChunks } from '../util';
 
@@ -197,6 +197,89 @@ suite('git', () => {
 		});
 	});
 
+	suite('parseGitRemotes', () => {
+		test('empty', () => {
+			assert.deepStrictEqual(parseGitRemotes(''), []);
+		});
+
+		test('single remote', () => {
+			const sample = `[remote "origin"]
+	url = https://github.com/microsoft/vscode.git
+	fetch = +refs/heads/*:refs/remotes/origin/*
+`;
+
+			assert.deepStrictEqual(parseGitRemotes(sample), [
+				{ name: 'origin', fetchUrl: 'https://github.com/microsoft/vscode.git', pushUrl: 'https://github.com/microsoft/vscode.git', isReadOnly: false }
+			]);
+		});
+
+		test('single remote (read-only)', () => {
+			const sample = `[remote "origin"]
+	url = https://github.com/microsoft/vscode.git
+	fetch = +refs/heads/*:refs/remotes/origin/*
+	pushurl = no_push
+`;
+
+			assert.deepStrictEqual(parseGitRemotes(sample), [
+				{ name: 'origin', fetchUrl: 'https://github.com/microsoft/vscode.git', pushUrl: 'no_push', isReadOnly: true }
+			]);
+		});
+
+		test('single remote (multiple urls)', () => {
+			const sample = `[remote "origin"]
+	url = https://github.com/microsoft/vscode.git
+	url = https://github.com/microsoft/vscode2.git
+	fetch = +refs/heads/*:refs/remotes/origin/*
+`;
+
+			assert.deepStrictEqual(parseGitRemotes(sample), [
+				{ name: 'origin', fetchUrl: 'https://github.com/microsoft/vscode.git', pushUrl: 'https://github.com/microsoft/vscode.git', isReadOnly: false }
+			]);
+		});
+
+		test('multiple remotes', () => {
+			const sample = `[remote "origin"]
+	url = https://github.com/microsoft/vscode.git
+	pushurl = https://github.com/microsoft/vscode1.git
+	fetch = +refs/heads/*:refs/remotes/origin/*
+[remote "remote2"]
+	url = https://github.com/microsoft/vscode2.git
+	fetch = +refs/heads/*:refs/remotes/origin/*
+`;
+
+			assert.deepStrictEqual(parseGitRemotes(sample), [
+				{ name: 'origin', fetchUrl: 'https://github.com/microsoft/vscode.git', pushUrl: 'https://github.com/microsoft/vscode1.git', isReadOnly: false },
+				{ name: 'remote2', fetchUrl: 'https://github.com/microsoft/vscode2.git', pushUrl: 'https://github.com/microsoft/vscode2.git', isReadOnly: false }
+			]);
+		});
+
+		test('remotes (white space)', () => {
+			const sample = ` [remote "origin"]
+	url  =  https://github.com/microsoft/vscode.git
+	pushurl=https://github.com/microsoft/vscode1.git
+	fetch = +refs/heads/*:refs/remotes/origin/*
+[ remote"remote2"]
+	url = https://github.com/microsoft/vscode2.git
+	fetch = +refs/heads/*:refs/remotes/origin/*
+`;
+
+			assert.deepStrictEqual(parseGitRemotes(sample), [
+				{ name: 'origin', fetchUrl: 'https://github.com/microsoft/vscode.git', pushUrl: 'https://github.com/microsoft/vscode1.git', isReadOnly: false },
+				{ name: 'remote2', fetchUrl: 'https://github.com/microsoft/vscode2.git', pushUrl: 'https://github.com/microsoft/vscode2.git', isReadOnly: false }
+			]);
+		});
+
+		test('remotes (invalid section)', () => {
+			const sample = `[remote "origin"
+	url = https://github.com/microsoft/vscode.git
+	pushurl = https://github.com/microsoft/vscode1.git
+	fetch = +refs/heads/*:refs/remotes/origin/*
+`;
+
+			assert.deepStrictEqual(parseGitRemotes(sample), []);
+		});
+	});
+
 	suite('parseGitCommit', () => {
 		test('single parent commit', function () {
 			const GIT_OUTPUT_SINGLE_PARENT = `52c293a05038d865604c2284aa8698bd087915a1
