@@ -11,13 +11,20 @@ export function scrollEditorToLine(
 	line: number,
 	editor: vscode.TextEditor
 ) {
+	const revealRange = toRevealRange(line, editor);
+	editor.revealRange(revealRange, vscode.TextEditorRevealType.AtTop);
+}
+
+function toRevealRange(line: number, editor: vscode.TextEditor): vscode.Range {
 	const sourceLine = Math.floor(line);
+	if (sourceLine >= editor.document.lineCount) {
+		return new vscode.Range(editor.document.lineCount - 1, 0, editor.document.lineCount - 1, 0);
+	}
+
 	const fraction = line - sourceLine;
 	const text = editor.document.lineAt(sourceLine).text;
 	const start = Math.floor(fraction * text.length);
-	editor.revealRange(
-		new vscode.Range(sourceLine, start, sourceLine + 1, 0),
-		vscode.TextEditorRevealType.AtTop);
+	return new vscode.Range(sourceLine, start, sourceLine + 1, 0);
 }
 
 export class StartingScrollFragment {
