@@ -49,7 +49,7 @@ export function activate(
 	const packageInfo = getPackageInfo(context);
 	if (packageInfo) {
 		const { name: id, version, aiKey } = packageInfo;
-		const vscTelemetryReporter = new VsCodeTelemetryReporter(id, version, aiKey);
+		const vscTelemetryReporter = new VsCodeTelemetryReporter(aiKey);
 		experimentTelemetryReporter = new ExperimentationTelemetryReporter(vscTelemetryReporter);
 		context.subscriptions.push(experimentTelemetryReporter);
 
