@@ -269,28 +269,8 @@
 
 	//#endregion
 
-
-	//#region ApplicationInsights
-
-	// Prevents appinsights from monkey patching modules.
-	// This should be called before importing the applicationinsights module
-	function avoidMonkeyPatchFromAppInsights() {
-		if (typeof process === 'undefined') {
-			console.warn('avoidMonkeyPatchFromAppInsights() is only available in node.js environments');
-			return;
-		}
-
-		// @ts-ignore
-		process.env['APPLICATION_INSIGHTS_NO_DIAGNOSTIC_CHANNEL'] = true; // Skip monkey patching of 3rd party modules by appinsights
-		global['diagnosticsSource'] = {}; // Prevents diagnostic channel (which patches "require") from initializing entirely
-	}
-
-	//#endregion
-
-
 	return {
 		enableASARSupport,
-		avoidMonkeyPatchFromAppInsights,
 		setupNLS,
 		fileUriFromPath
 	};
