@@ -12,6 +12,7 @@ import { IContextViewProvider } from 'vs/base/browser/ui/contextview/contextview
 import { IHoverDelegate } from 'vs/base/browser/ui/iconLabel/iconHoverDelegate';
 import { ICustomHover, setupCustomHover } from 'vs/base/browser/ui/iconLabel/iconLabelHover';
 import { ISelectBoxOptions, ISelectOptionItem, SelectBox } from 'vs/base/browser/ui/selectBox/selectBox';
+import { IToggleStyles } from 'vs/base/browser/ui/toggle/toggle';
 import { Action, ActionRunner, IAction, IActionChangeEvent, IActionRunner, Separator } from 'vs/base/common/actions';
 import { Disposable } from 'vs/base/common/lifecycle';
 import * as platform from 'vs/base/common/platform';
@@ -252,7 +253,7 @@ export class BaseActionViewItem extends Disposable implements IActionViewItem {
 			this.element.remove();
 			this.element = undefined;
 		}
-
+		this._context = undefined;
 		super.dispose();
 	}
 }
@@ -261,6 +262,7 @@ export interface IActionViewItemOptions extends IBaseActionViewItemOptions {
 	icon?: boolean;
 	label?: boolean;
 	keybinding?: string | null;
+	toggleStyles?: IToggleStyles;
 }
 
 export class ActionViewItem extends BaseActionViewItem {
@@ -270,7 +272,7 @@ export class ActionViewItem extends BaseActionViewItem {
 
 	private cssClass?: string;
 
-	constructor(context: unknown, action: IAction, options: IActionViewItemOptions = {}) {
+	constructor(context: unknown, action: IAction, options: IActionViewItemOptions) {
 		super(context, action, options);
 
 		this.options = options;
@@ -334,13 +336,13 @@ export class ActionViewItem extends BaseActionViewItem {
 		}
 	}
 
-	override updateLabel(): void {
+	protected override updateLabel(): void {
 		if (this.options.label && this.label) {
 			this.label.textContent = this.action.label;
 		}
 	}
 
-	override getTooltip() {
+	protected override getTooltip() {
 		let title: string | null = null;
 
 		if (this.action.tooltip) {
@@ -356,7 +358,7 @@ export class ActionViewItem extends BaseActionViewItem {
 		return title ?? undefined;
 	}
 
-	override updateClass(): void {
+	protected override updateClass(): void {
 		if (this.cssClass && this.label) {
 			this.label.classList.remove(...this.cssClass.split(' '));
 		}
@@ -377,7 +379,7 @@ export class ActionViewItem extends BaseActionViewItem {
 		}
 	}
 
-	override updateEnabled(): void {
+	protected override updateEnabled(): void {
 		if (this.action.enabled) {
 			if (this.label) {
 				this.label.removeAttribute('aria-disabled');
@@ -395,14 +397,14 @@ export class ActionViewItem extends BaseActionViewItem {
 		}
 	}
 
-	override updateAriaLabel(): void {
+	protected override updateAriaLabel(): void {
 		if (this.label) {
 			const title = this.getTooltip() ?? '';
 			this.label.setAttribute('aria-label', title);
 		}
 	}
 
-	override updateChecked(): void {
+	protected override updateChecked(): void {
 		if (this.label) {
 			if (this.action.checked) {
 				this.label.classList.add('checked');
