@@ -7,7 +7,7 @@ import { IContextMenuProvider } from 'vs/base/browser/contextmenu';
 import { $, addDisposableListener, append, EventHelper, EventType } from 'vs/base/browser/dom';
 import { StandardKeyboardEvent } from 'vs/base/browser/keyboardEvent';
 import { EventType as GestureEventType, Gesture } from 'vs/base/browser/touch';
-import { AnchorAlignment, IAnchor, IContextViewProvider } from 'vs/base/browser/ui/contextview/contextview';
+import { AnchorAlignment } from 'vs/base/browser/ui/contextview/contextview';
 import { IMenuOptions } from 'vs/base/browser/ui/menu/menu';
 import { ActionRunner, IAction } from 'vs/base/common/actions';
 import { Emitter } from 'vs/base/common/event';
@@ -19,12 +19,12 @@ export interface ILabelRenderer {
 	(container: HTMLElement): IDisposable | null;
 }
 
-export interface IBaseDropdownOptions {
+interface IBaseDropdownOptions {
 	label?: string;
 	labelRenderer?: ILabelRenderer;
 }
 
-export class BaseDropdown extends ActionRunner {
+class BaseDropdown extends ActionRunner {
 	private _element: HTMLElement;
 	private boxContainer?: HTMLElement;
 	private _label?: HTMLElement;
@@ -148,58 +148,6 @@ export class BaseDropdown extends ActionRunner {
 	}
 }
 
-export interface IDropdownOptions extends IBaseDropdownOptions {
-	contextViewProvider: IContextViewProvider;
-}
-
-export class Dropdown extends BaseDropdown {
-	private contextViewProvider: IContextViewProvider;
-
-	constructor(container: HTMLElement, options: IDropdownOptions) {
-		super(container, options);
-
-		this.contextViewProvider = options.contextViewProvider;
-	}
-
-	override show(): void {
-		super.show();
-
-		this.element.classList.add('active');
-
-		this.contextViewProvider.showContextView({
-			getAnchor: () => this.getAnchor(),
-
-			render: (container) => {
-				return this.renderContents(container);
-			},
-
-			onDOMEvent: (e, activeElement) => {
-				this.onEvent(e, activeElement);
-			},
-
-			onHide: () => this.onHide()
-		});
-	}
-
-	protected getAnchor(): HTMLElement | IAnchor {
-		return this.element;
-	}
-
-	protected onHide(): void {
-		this.element.classList.remove('active');
-	}
-
-	override hide(): void {
-		super.hide();
-
-		this.contextViewProvider?.hideContextView();
-	}
-
-	protected renderContents(container: HTMLElement): IDisposable | null {
-		return null;
-	}
-}
-
 export interface IActionProvider {
 	getActions(): readonly IAction[];
 }
