@@ -6,6 +6,7 @@
 import * as dom from 'vs/base/browser/dom';
 import { StandardKeyboardEvent } from 'vs/base/browser/keyboardEvent';
 import { ActionBar } from 'vs/base/browser/ui/actionbar/actionbar';
+import { AriaRole } from 'vs/base/browser/ui/aria/aria';
 import { IconLabel, IIconLabelValueOptions } from 'vs/base/browser/ui/iconLabel/iconLabel';
 import { KeybindingLabel } from 'vs/base/browser/ui/keybindingLabel/keybindingLabel';
 import { IListRenderer, IListVirtualDelegate } from 'vs/base/browser/ui/list/list';
@@ -502,7 +503,7 @@ export class QuickInputList {
 				separator = previous;
 			}
 
-			result.push(new ListElement({
+			const element = new ListElement({
 				hasCheckbox,
 				index,
 				item: item.type !== 'separator' ? item : undefined,
@@ -519,11 +520,14 @@ export class QuickInputList {
 				separator,
 				fireButtonTriggered,
 				fireSeparatorButtonTriggered
-			}));
+			});
+
+			this.elementDisposables.push(element);
+			this.elementDisposables.push(element.onChecked(() => this.fireCheckedEvents()));
+
+			result.push(element);
 			return result;
 		}, [] as ListElement[]);
-		this.elementDisposables.push(...this.elements);
-		this.elementDisposables.push(...this.elements.map(element => element.onChecked(() => this.fireCheckedEvents())));
 
 		this.elementsToIndexes = this.elements.reduce((map, element, index) => {
 			map.set(element.item ?? element.separator!, index);
@@ -794,7 +798,7 @@ export class QuickInputList {
 	}
 }
 
-export function matchesContiguousIconAware(query: string, target: IParsedLabelWithIcons): IMatch[] | null {
+function matchesContiguousIconAware(query: string, target: IParsedLabelWithIcons): IMatch[] | null {
 
 	const { text, iconOffsets } = target;
 
@@ -862,7 +866,7 @@ class QuickInputAccessibilityProvider implements IListAccessibilityProvider<List
 			: element.saneAriaLabel;
 	}
 
-	getWidgetRole() {
+	getWidgetRole(): AriaRole {
 		return 'listbox';
 	}
 
