@@ -4,8 +4,11 @@
  *--------------------------------------------------------------------------------------------*/
 
 import * as assert from 'assert';
+import { unthemedInboxStyles } from 'vs/base/browser/ui/inputbox/inputBox';
+import { unthemedButtonStyles } from 'vs/base/browser/ui/button/button';
 import { IListRenderer, IListVirtualDelegate } from 'vs/base/browser/ui/list/list';
 import { IListOptions, List } from 'vs/base/browser/ui/list/listWidget';
+import { unthemedToggleStyles } from 'vs/base/browser/ui/toggle/toggle';
 import { raceTimeout } from 'vs/base/common/async';
 import { QuickInputController } from 'vs/base/parts/quickinput/browser/quickInput';
 import { IQuickPick, IQuickPickItem } from 'vs/base/parts/quickinput/common/quickInput';
@@ -29,7 +32,7 @@ suite('QuickInput', () => { // https://github.com/microsoft/vscode/issues/147543
 	let fixture: HTMLElement, controller: QuickInputController, quickpick: IQuickPick<IQuickPickItem>;
 
 	function getScrollTop(): number {
-		return (quickpick as any).scrollTop;
+		return quickpick.scrollTop;
 	}
 
 	setup(() => {
@@ -52,9 +55,10 @@ suite('QuickInput', () => { // https://github.com/microsoft/vscode/issues/147543
 				options: IListOptions<T>,
 			) => new List<T>(user, container, delegate, renderers, options),
 			styles: {
-				button: {},
+				button: unthemedButtonStyles,
 				countBadge: {},
-				inputBox: {},
+				inputBox: unthemedInboxStyles,
+				toggle: unthemedToggleStyles,
 				keybindingLabel: {},
 				list: {},
 				progressBar: {},
