@@ -9,6 +9,7 @@ import { CancellationToken, CancellationTokenSource } from 'vs/base/common/cance
 import { isCancellationError } from 'vs/base/common/errors';
 import { Event } from 'vs/base/common/event';
 import { URI } from 'vs/base/common/uri';
+import { runWithFakedTimers } from 'vs/base/test/common/timeTravelScheduler';
 
 suite('Async', () => {
 
@@ -636,29 +637,33 @@ suite('Async', () => {
 
 	suite('retry', () => {
 		test('success case', async () => {
-			let counter = 0;
+			return runWithFakedTimers({ useFakeTimers: true }, async () => {
+				let counter = 0;
 
-			const res = await async.retry(() => {
-				counter++;
-				if (counter < 2) {
-					return Promise.reject(new Error('fail'));
-				}
+				const res = await async.retry(() => {
+					counter++;
+					if (counter < 2) {
+						return Promise.reject(new Error('fail'));
+					}
 
-				return Promise.resolve(true);
-			}, 10, 3);
+					return Promise.resolve(true);
+				}, 10, 3);
 
-			assert.strictEqual(res, true);
+				assert.strictEqual(res, true);
+			});
 		});
 
 		test('error case', async () => {
-			const expectedError = new Error('fail');
-			try {
-				await async.retry(() => {
-					return Promise.reject(expectedError);
-				}, 10, 3);
-			} catch (error) {
-				assert.strictEqual(error, error);
-			}
+			return runWithFakedTimers({ useFakeTimers: true }, async () => {
+				const expectedError = new Error('fail');
+				try {
+					await async.retry(() => {
+						return Promise.reject(expectedError);
+					}, 10, 3);
+				} catch (error) {
+					assert.strictEqual(error, error);
+				}
+			});
 		});
 	});
 
