@@ -14,10 +14,14 @@ import { URI, UriComponents } from 'vs/base/common/uri';
 import { request } from 'vs/base/parts/request/browser/request';
 import product from 'vs/platform/product/common/product';
 import { isFolderToOpen, isWorkspaceToOpen } from 'vs/platform/window/common/window';
-import { create, ICredentialsProvider, IURLCallbackProvider, IWorkbenchConstructionOptions, IWorkspace, IWorkspaceProvider } from 'vs/workbench/workbench.web.main';
+import { create } from 'vs/workbench/workbench.web.main';
 import { posix } from 'vs/base/common/path';
 import { ltrim } from 'vs/base/common/strings';
 import { getCheConfig } from 'vs/code/browser/workbench/che/workbench-che-config';
+import type { ICredentialsProvider } from 'vs/platform/credentials/common/credentials';
+import type { IURLCallbackProvider } from 'vs/workbench/services/url/browser/urlService';
+import type { IWorkbenchConstructionOptions } from 'vs/workbench/browser/web.api';
+import type { IWorkspace, IWorkspaceProvider } from 'vs/workbench/services/host/browser/browserHostService';
 
 interface ICredential {
 	service: string;
