@@ -30,9 +30,43 @@ export type ServicesAccessor = InstantiationServicesAccessor;
 export type IEditorContributionCtor = IConstructorSignature<IEditorContribution, [ICodeEditor]>;
 export type IDiffEditorContributionCtor = IConstructorSignature<IDiffEditorContribution, [IDiffEditor]>;
 
+export const enum EditorContributionInstantiation {
+	/**
+	 * The contribution is created eagerly when the {@linkcode ICodeEditor} is instantiated.
+	 * Only Eager contributions can participate in saving or restoring of view state.
+	 */
+	Eager,
+
+	/**
+	 * The contribution is created at the latest 50ms after the first render after attaching a text model.
+	 * If the contribution is explicitly requested via `getContribution`, it will be instantiated sooner.
+	 * If there is idle time available, it will be instantiated sooner.
+	 */
+	AfterFirstRender,
+
+	/**
+	 * The contribution is created before the editor emits events produced by user interaction (mouse events, keyboard events).
+	 * If the contribution is explicitly requested via `getContribution`, it will be instantiated sooner.
+	 * If there is idle time available, it will be instantiated sooner.
+	 */
+	BeforeFirstInteraction,
+
+	/**
+	 * The contribution is created when there is idle time available, at the latest 5000ms after the editor creation.
+	 * If the contribution is explicitly requested via `getContribution`, it will be instantiated sooner.
+	 */
+	Eventually,
+
+	/**
+	 * The contribution is created only when explicitly requested via `getContribution`.
+	 */
+	Lazy,
+}
+
 export interface IEditorContributionDescription {
-	id: string;
-	ctor: IEditorContributionCtor;
+	readonly id: string;
+	readonly ctor: IEditorContributionCtor;
+	readonly instantiation: EditorContributionInstantiation;
 }
 
 export interface IDiffEditorContributionDescription {
@@ -481,8 +515,8 @@ export function registerInstantiatedEditorAction(editorAction: EditorAction): vo
 	EditorContributionRegistry.INSTANCE.registerEditorAction(editorAction);
 }
 
-export function registerEditorContribution<Services extends BrandedService[]>(id: string, ctor: { new(editor: ICodeEditor, ...services: Services): IEditorContribution }): void {
-	EditorContributionRegistry.INSTANCE.registerEditorContribution(id, ctor);
+export function registerEditorContribution<Services extends BrandedService[]>(id: string, ctor: { new(editor: ICodeEditor, ...services: Services): IEditorContribution }, instantiation: EditorContributionInstantiation): void {
+	EditorContributionRegistry.INSTANCE.registerEditorContribution(id, ctor, instantiation);
 }
 
 export function registerDiffEditorContribution<Services extends BrandedService[]>(id: string, ctor: { new(editor: IDiffEditor, ...services: Services): IEditorContribution }): void {
@@ -533,8 +567,8 @@ class EditorContributionRegistry {
 		this.editorCommands = Object.create(null);
 	}
 
-	public registerEditorContribution<Services extends BrandedService[]>(id: string, ctor: { new(editor: ICodeEditor, ...services: Services): IEditorContribution }): void {
-		this.editorContributions.push({ id, ctor: ctor as IEditorContributionCtor });
+	public registerEditorContribution<Services extends BrandedService[]>(id: string, ctor: { new(editor: ICodeEditor, ...services: Services): IEditorContribution }, instantiation: EditorContributionInstantiation): void {
+		this.editorContributions.push({ id, ctor: ctor as IEditorContributionCtor, instantiation });
 	}
 
 	public getEditorContributions(): IEditorContributionDescription[] {
