@@ -49,6 +49,9 @@ import { getThemeTypeSelector, IColorTheme } from 'vs/platform/theme/common/them
 import { EditorOption } from 'vs/editor/common/config/editorOptions';
 import { PointerHandlerLastRenderData } from 'vs/editor/browser/controller/mouseTarget';
 import { BlockDecorations } from 'vs/editor/browser/viewParts/blockDecorations/blockDecorations';
+import { inputLatency } from 'vs/base/browser/performance';
+import { IMouseWheelEvent } from 'vs/base/browser/mouseEvent';
+import { WhitespaceOverlay } from 'vs/editor/browser/viewParts/whitespace/whitespace';
 
 
 export interface IContentWidgetData {
@@ -152,6 +155,7 @@ export class View extends ViewEventHandler {
 		contentViewOverlays.addDynamicOverlay(new SelectionsOverlay(this._context));
 		contentViewOverlays.addDynamicOverlay(new IndentGuidesOverlay(this._context));
 		contentViewOverlays.addDynamicOverlay(new DecorationsOverlay(this._context));
+		contentViewOverlays.addDynamicOverlay(new WhitespaceOverlay(this._context));
 
 		const marginViewOverlays = new MarginViewOverlays(this._context);
 		this._viewParts.push(marginViewOverlays);
@@ -222,6 +226,7 @@ export class View extends ViewEventHandler {
 	}
 
 	private _flushAccumulatedAndRenderNow(): void {
+		inputLatency.onRenderStart();
 		this._renderNow();
 	}
 
@@ -424,6 +429,10 @@ export class View extends ViewEventHandler {
 		this._scrollbar.delegateVerticalScrollbarPointerDown(browserEvent);
 	}
 
+	public delegateScrollFromMouseWheelEvent(browserEvent: IMouseWheelEvent) {
+		this._scrollbar.delegateScrollFromMouseWheelEvent(browserEvent);
+	}
+
 	public restoreState(scrollPosition: { scrollLeft: number; scrollTop: number }): void {
 		this._context.viewModel.viewLayout.setScrollPosition({
 			scrollTop: scrollPosition.scrollTop,
