@@ -113,7 +113,12 @@ export class ViewCursor {
 		return true;
 	}
 
-	public onCursorPositionChanged(position: Position): boolean {
+	public onCursorPositionChanged(position: Position, pauseAnimation: boolean): boolean {
+		if (pauseAnimation) {
+			this._domNode.domNode.style.transitionProperty = 'none';
+		} else {
+			this._domNode.domNode.style.transitionProperty = '';
+		}
 		this._position = position;
 		return true;
 	}
@@ -131,6 +136,7 @@ export class ViewCursor {
 
 	private _prepareRender(ctx: RenderingContext): ViewCursorRenderData | null {
 		let textContent = '';
+		let textContentClassName = '';
 		const [position, nextGrapheme] = this._getGraphemeAwarePosition();
 
 		if (this._cursorStyle === TextEditorCursorStyle.Line || this._cursorStyle === TextEditorCursorStyle.LineThin) {
@@ -145,6 +151,7 @@ export class ViewCursor {
 				width = dom.computeScreenAwareSize(this._lineCursorWidth > 0 ? this._lineCursorWidth : 2);
 				if (width > 2) {
 					textContent = nextGrapheme;
+					textContentClassName = this._getTokenClassName(position);
 				}
 			} else {
 				width = dom.computeScreenAwareSize(1);
@@ -159,7 +166,7 @@ export class ViewCursor {
 			}
 
 			const top = ctx.getVerticalOffsetForLineNumber(position.lineNumber) - ctx.bigNumbersDelta;
-			return new ViewCursorRenderData(top, left, paddingLeft, width, this._lineHeight, textContent, '');
+			return new ViewCursorRenderData(top, left, paddingLeft, width, this._lineHeight, textContent, textContentClassName);
 		}
 
 		const visibleRangeForCharacter = ctx.linesVisibleRangesForRange(new Range(position.lineNumber, position.column, position.lineNumber, position.column + nextGrapheme.length), false);
@@ -183,12 +190,9 @@ export class ViewCursor {
 					: range.width)
 		);
 
-		let textContentClassName = '';
 		if (this._cursorStyle === TextEditorCursorStyle.Block) {
-			const lineData = this._context.viewModel.getViewLineData(position.lineNumber);
 			textContent = nextGrapheme;
-			const tokenIndex = lineData.tokens.findTokenIndexAtOffset(position.column - 1);
-			textContentClassName = lineData.tokens.getClassName(tokenIndex);
+			textContentClassName = this._getTokenClassName(position);
 		}
 
 		let top = ctx.getVerticalOffsetForLineNumber(position.lineNumber) - ctx.bigNumbersDelta;
@@ -203,6 +207,12 @@ export class ViewCursor {
 		return new ViewCursorRenderData(top, range.left, 0, width, height, textContent, textContentClassName);
 	}
 
+	private _getTokenClassName(position: Position): string {
+		const lineData = this._context.viewModel.getViewLineData(position.lineNumber);
+		const tokenIndex = lineData.tokens.findTokenIndexAtOffset(position.column - 1);
+		return lineData.tokens.getClassName(tokenIndex);
+	}
+
 	public prepareRender(ctx: RenderingContext): void {
 		this._renderData = this._prepareRender(ctx);
 	}
