@@ -33,9 +33,6 @@ export const sourceActionCommandId = 'editor.action.sourceAction';
 export const organizeImportsCommandId = 'editor.action.organizeImports';
 export const fixAllCommandId = 'editor.action.fixAll';
 
-export const acceptSelectedCodeActionCommand = 'acceptSelectedCodeAction';
-export const previewSelectedCodeActionCommand = 'previewSelectedCodeAction';
-
 class ManagedCodeActionSet extends Disposable implements CodeActionSet {
 
 	private static codeActionsPreferredComparator(a: languages.CodeAction, b: languages.CodeAction): number {
@@ -235,6 +232,7 @@ export async function applyCodeAction(
 	item: CodeActionItem,
 	codeActionReason: ApplyCodeActionReason,
 	options?: { preview?: boolean; editor?: ICodeEditor },
+	token: CancellationToken = CancellationToken.None,
 ): Promise<void> {
 	const bulkEditService = accessor.get(IBulkEditService);
 	const commandService = accessor.get(ICommandService);
@@ -263,17 +261,24 @@ export async function applyCodeAction(
 		reason: codeActionReason,
 	});
 
-	await item.resolve(CancellationToken.None);
+	await item.resolve(token);
+	if (token.isCancellationRequested) {
+		return;
+	}
 
 	if (item.action.edit) {
-		await bulkEditService.apply(item.action.edit, {
+		const result = await bulkEditService.apply(item.action.edit, {
 			editor: options?.editor,
 			label: item.action.title,
 			quotableLabel: item.action.title,
 			code: 'undoredo.codeAction',
-			respectAutoSaveConfig: true,
+			respectAutoSaveConfig: codeActionReason !== ApplyCodeActionReason.OnSave,
 			showPreview: options?.preview,
 		});
+
+		if (!result.isApplied) {
+			return;
+		}
 	}
 
 	if (item.action.command) {
