@@ -4,6 +4,7 @@
  *--------------------------------------------------------------------------------------------*/
 
 import * as dom from 'vs/base/browser/dom';
+import 'vs/css!./findOptionsWidget';
 import { CaseSensitiveToggle, RegexToggle, WholeWordsToggle } from 'vs/base/browser/ui/findinput/findInputToggles';
 import { Widget } from 'vs/base/browser/ui/widget';
 import { RunOnceScheduler } from 'vs/base/common/async';
@@ -11,8 +12,7 @@ import { ICodeEditor, IOverlayWidget, IOverlayWidgetPosition, OverlayWidgetPosit
 import { FIND_IDS } from 'vs/editor/contrib/find/browser/findModel';
 import { FindReplaceState } from 'vs/editor/contrib/find/browser/findState';
 import { IKeybindingService } from 'vs/platform/keybinding/common/keybinding';
-import { contrastBorder, editorWidgetBackground, editorWidgetForeground, inputActiveOptionBackground, inputActiveOptionBorder, inputActiveOptionForeground, widgetShadow } from 'vs/platform/theme/common/colorRegistry';
-import { IColorTheme, IThemeService, registerThemingParticipant } from 'vs/platform/theme/common/themeService';
+import { asCssValue, inputActiveOptionBackground, inputActiveOptionBorder, inputActiveOptionForeground } from 'vs/platform/theme/common/colorRegistry';
 
 export class FindOptionsWidget extends Widget implements IOverlayWidget {
 
@@ -30,8 +30,7 @@ export class FindOptionsWidget extends Widget implements IOverlayWidget {
 	constructor(
 		editor: ICodeEditor,
 		state: FindReplaceState,
-		keybindingService: IKeybindingService,
-		themeService: IThemeService
+		keybindingService: IKeybindingService
 	) {
 		super();
 
@@ -47,16 +46,16 @@ export class FindOptionsWidget extends Widget implements IOverlayWidget {
 		this._domNode.setAttribute('role', 'presentation');
 		this._domNode.setAttribute('aria-hidden', 'true');
 
-		const inputActiveOptionBorderColor = themeService.getColorTheme().getColor(inputActiveOptionBorder);
-		const inputActiveOptionForegroundColor = themeService.getColorTheme().getColor(inputActiveOptionForeground);
-		const inputActiveOptionBackgroundColor = themeService.getColorTheme().getColor(inputActiveOptionBackground);
+		const toggleStyles = {
+			inputActiveOptionBorder: asCssValue(inputActiveOptionBorder),
+			inputActiveOptionForeground: asCssValue(inputActiveOptionForeground),
+			inputActiveOptionBackground: asCssValue(inputActiveOptionBackground),
+		};
 
 		this.caseSensitive = this._register(new CaseSensitiveToggle({
 			appendTitle: this._keybindingLabelFor(FIND_IDS.ToggleCaseSensitiveCommand),
 			isChecked: this._state.matchCase,
-			inputActiveOptionBorder: inputActiveOptionBorderColor,
-			inputActiveOptionForeground: inputActiveOptionForegroundColor,
-			inputActiveOptionBackground: inputActiveOptionBackgroundColor
+			...toggleStyles
 		}));
 		this._domNode.appendChild(this.caseSensitive.domNode);
 		this._register(this.caseSensitive.onChange(() => {
@@ -68,9 +67,7 @@ export class FindOptionsWidget extends Widget implements IOverlayWidget {
 		this.wholeWords = this._register(new WholeWordsToggle({
 			appendTitle: this._keybindingLabelFor(FIND_IDS.ToggleWholeWordCommand),
 			isChecked: this._state.wholeWord,
-			inputActiveOptionBorder: inputActiveOptionBorderColor,
-			inputActiveOptionForeground: inputActiveOptionForegroundColor,
-			inputActiveOptionBackground: inputActiveOptionBackgroundColor
+			...toggleStyles
 		}));
 		this._domNode.appendChild(this.wholeWords.domNode);
 		this._register(this.wholeWords.onChange(() => {
@@ -82,9 +79,7 @@ export class FindOptionsWidget extends Widget implements IOverlayWidget {
 		this.regex = this._register(new RegexToggle({
 			appendTitle: this._keybindingLabelFor(FIND_IDS.ToggleRegexCommand),
 			isChecked: this._state.isRegex,
-			inputActiveOptionBorder: inputActiveOptionBorderColor,
-			inputActiveOptionForeground: inputActiveOptionForegroundColor,
-			inputActiveOptionBackground: inputActiveOptionBackgroundColor
+			...toggleStyles
 		}));
 		this._domNode.appendChild(this.regex.domNode);
 		this._register(this.regex.onChange(() => {
@@ -116,9 +111,6 @@ export class FindOptionsWidget extends Widget implements IOverlayWidget {
 
 		this._register(dom.addDisposableListener(this._domNode, dom.EventType.MOUSE_LEAVE, (e) => this._onMouseLeave()));
 		this._register(dom.addDisposableListener(this._domNode, 'mouseover', (e) => this._onMouseOver()));
-
-		this._applyTheme(themeService.getColorTheme());
-		this._register(themeService.onDidColorThemeChange(this._applyTheme.bind(this)));
 	}
 
 	private _keybindingLabelFor(actionId: string): string {
@@ -186,39 +178,4 @@ export class FindOptionsWidget extends Widget implements IOverlayWidget {
 		this._isVisible = false;
 		this._domNode.style.display = 'none';
 	}
-
-	private _applyTheme(theme: IColorTheme) {
-		const inputStyles = {
-			inputActiveOptionBorder: theme.getColor(inputActiveOptionBorder),
-			inputActiveOptionForeground: theme.getColor(inputActiveOptionForeground),
-			inputActiveOptionBackground: theme.getColor(inputActiveOptionBackground)
-		};
-		this.caseSensitive.style(inputStyles);
-		this.wholeWords.style(inputStyles);
-		this.regex.style(inputStyles);
-	}
 }
-
-
-registerThemingParticipant((theme, collector) => {
-	const widgetBackground = theme.getColor(editorWidgetBackground);
-	if (widgetBackground) {
-		collector.addRule(`.monaco-editor .findOptionsWidget { background-color: ${widgetBackground}; }`);
-	}
-
-	const widgetForeground = theme.getColor(editorWidgetForeground);
-	if (widgetForeground) {
-		collector.addRule(`.monaco-editor .findOptionsWidget { color: ${widgetForeground}; }`);
-	}
-
-
-	const widgetShadowColor = theme.getColor(widgetShadow);
-	if (widgetShadowColor) {
-		collector.addRule(`.monaco-editor .findOptionsWidget { box-shadow: 0 0 8px 2px ${widgetShadowColor}; }`);
-	}
-
-	const hcBorder = theme.getColor(contrastBorder);
-	if (hcBorder) {
-		collector.addRule(`.monaco-editor .findOptionsWidget { border: 2px solid ${hcBorder}; }`);
-	}
-});
