@@ -17,7 +17,7 @@ import { StopWatch } from 'vs/base/common/stopwatch';
 import { assertType, isObject } from 'vs/base/common/types';
 import { StableEditorScrollState } from 'vs/editor/browser/stableEditorScroll';
 import { ICodeEditor } from 'vs/editor/browser/editorBrowser';
-import { EditorAction, EditorCommand, registerEditorAction, registerEditorCommand, registerEditorContribution, ServicesAccessor } from 'vs/editor/browser/editorExtensions';
+import { EditorAction, EditorCommand, EditorContributionInstantiation, registerEditorAction, registerEditorCommand, registerEditorContribution, ServicesAccessor } from 'vs/editor/browser/editorExtensions';
 import { EditorOption } from 'vs/editor/common/config/editorOptions';
 import { EditOperation } from 'vs/editor/common/core/editOperation';
 import { IPosition, Position } from 'vs/editor/common/core/position';
@@ -94,6 +94,7 @@ class LineSuffix {
 }
 
 const enum InsertFlags {
+	None = 0,
 	NoBeforeUndoStop = 1,
 	NoAfterUndoStop = 2,
 	KeepAlternativeSuggestions = 4,
@@ -130,6 +131,12 @@ export class SuggestController implements IEditorContribution {
 		this.editor = editor;
 		this.model = _instantiationService.createInstance(SuggestModel, this.editor,);
 
+		// default selector
+		this._selectors.register({
+			priority: 0,
+			select: (model, pos, items) => this._memoryService.select(model, pos, items)
+		});
+
 		// context key: update insert/replace mode
 		const ctxInsertMode = SuggestContext.InsertMode.bindTo(_contextKeyService);
 		ctxInsertMode.set(editor.getOption(EditorOption.suggest).insertMode);
@@ -140,7 +147,7 @@ export class SuggestController implements IEditorContribution {
 			const widget = this._instantiationService.createInstance(SuggestWidget, this.editor);
 
 			this._toDispose.add(widget);
-			this._toDispose.add(widget.onDidSelect(item => this._insertSuggestion(item, 0), this));
+			this._toDispose.add(widget.onDidSelect(item => this._insertSuggestion(item, InsertFlags.None), this));
 
 			// Wire up logic to accept a suggestion on certain characters
 			const commitCharacterController = new CommitCharacterController(this.editor, widget, this.model, item => this._insertSuggestion(item, InsertFlags.NoAfterUndoStop));
@@ -227,18 +234,16 @@ export class SuggestController implements IEditorContribution {
 				return;
 			}
 			let index = -1;
-			if (!e.noSelect) {
-				for (const selector of this._selectors.itemsOrderedByPriorityDesc) {
-					index = selector.select(this.editor.getModel()!, this.editor.getPosition()!, e.completionModel.items);
-					if (index !== -1) {
-						break;
-					}
-				}
-				if (index === -1) {
-					index = this._memoryService.select(this.editor.getModel()!, this.editor.getPosition()!, e.completionModel.items);
+			for (const selector of this._selectors.itemsOrderedByPriorityDesc) {
+				index = selector.select(this.editor.getModel()!, this.editor.getPosition()!, e.completionModel.items);
+				if (index !== -1) {
+					break;
 				}
 			}
-			this.widget.value.showSuggestions(e.completionModel, index, e.isFrozen, e.auto);
+			if (index === -1) {
+				index = 0;
+			}
+			this.widget.value.showSuggestions(e.completionModel, index, e.isFrozen, e.auto, e.auto && !this.editor.getOption(EditorOption.suggest).selectQuickSuggestions);
 		}));
 		this._toDispose.add(this.model.onDidCancel(e => {
 			if (!e.retrigger) {
@@ -400,7 +405,7 @@ export class SuggestController implements IEditorContribution {
 		if (item.completion.command) {
 			if (item.completion.command.id === TriggerSuggestAction.id) {
 				// retigger
-				this.model.trigger({ auto: true, shy: false, noSelect: false }, true);
+				this.model.trigger({ auto: true, retrigger: true });
 			} else {
 				// exec command, done
 				tasks.push(this._commandService.executeCommand(item.completion.command.id, ...(item.completion.command.arguments ? [...item.completion.command.arguments] : [])).catch(onUnexpectedError));
@@ -493,9 +498,12 @@ export class SuggestController implements IEditorContribution {
 		}
 	}
 
-	triggerSuggest(onlyFrom?: Set<CompletionItemProvider>, auto?: boolean, noFilter?: boolean, noSelect?: boolean): void {
+	triggerSuggest(onlyFrom?: Set<CompletionItemProvider>, auto?: boolean, noFilter?: boolean): void {
 		if (this.editor.hasModel()) {
-			this.model.trigger({ auto: auto ?? false, shy: false, noSelect: noSelect ?? false }, false, onlyFrom, undefined, noFilter);
+			this.model.trigger({
+				auto: auto ?? false,
+				completionOptions: { providerFilter: onlyFrom, kindFilter: noFilter ? new Set() : undefined }
+			});
 			this.editor.revealPosition(this.editor.getPosition(), ScrollType.Smooth);
 			this.editor.focus();
 		}
@@ -564,7 +572,7 @@ export class SuggestController implements IEditorContribution {
 			}, undefined, listener);
 		});
 
-		this.model.trigger({ auto: false, shy: true, noSelect: false });
+		this.model.trigger({ auto: false, shy: true });
 		this.editor.revealPosition(positionNow, ScrollType.Smooth);
 		this.editor.focus();
 	}
@@ -580,6 +588,7 @@ export class SuggestController implements IEditorContribution {
 		}
 		this._insertSuggestion(item, flags);
 	}
+
 	acceptNextSuggestion() {
 		this._alternatives.value.next();
 	}
@@ -594,6 +603,10 @@ export class SuggestController implements IEditorContribution {
 		this.widget.value.hideWidget();
 	}
 
+	focusSuggestion(): void {
+		this.widget.value.focusSelected();
+	}
+
 	selectNextSuggestion(): void {
 		this.widget.value.selectNext();
 	}
@@ -705,23 +718,19 @@ export class TriggerSuggestAction extends EditorAction {
 			return;
 		}
 
-		type TriggerArgs = { auto: boolean; noSelection: boolean };
+		type TriggerArgs = { auto: boolean };
 		let auto: boolean | undefined;
-		let noSelect: boolean | undefined;
 		if (args && typeof args === 'object') {
 			if ((<TriggerArgs>args).auto === true) {
 				auto = true;
 			}
-			if ((<TriggerArgs>args).noSelection === true) {
-				noSelect = true;
-			}
 		}
 
-		controller.triggerSuggest(undefined, auto, undefined, noSelect);
+		controller.triggerSuggest(undefined, auto, undefined);
 	}
 }
 
-registerEditorContribution(SuggestController.ID, SuggestController);
+registerEditorContribution(SuggestController.ID, SuggestController, EditorContributionInstantiation.BeforeFirstInteraction);
 registerEditorAction(TriggerSuggestAction);
 
 const weight = KeybindingWeight.EditorContrib + 90;
@@ -872,9 +881,22 @@ registerEditorCommand(new SuggestCommand({
 	handler: c => c.selectFirstSuggestion()
 }));
 
+registerEditorCommand(new SuggestCommand({
+	id: 'focusSuggestion',
+	precondition: ContextKeyExpr.and(SuggestContext.Visible, SuggestContext.HasFocusedSuggestion.negate(), ContextKeyExpr.equals('config.editor.suggest.selectQuickSuggestions', false)),
+	handler: x => x.focusSuggestion(),
+	kbOpts: {
+		weight: weight,
+		kbExpr: EditorContextKeys.textInputFocus,
+		primary: KeyMod.CtrlCmd | KeyCode.Space,
+		secondary: [KeyMod.CtrlCmd | KeyCode.KeyI],
+		mac: { primary: KeyMod.WinCtrl | KeyCode.Space, secondary: [KeyMod.CtrlCmd | KeyCode.KeyI] }
+	},
+}));
+
 registerEditorCommand(new SuggestCommand({
 	id: 'toggleSuggestionDetails',
-	precondition: SuggestContext.Visible,
+	precondition: ContextKeyExpr.and(SuggestContext.Visible, SuggestContext.HasFocusedSuggestion),
 	handler: x => x.toggleSuggestionDetails(),
 	kbOpts: {
 		weight: weight,
