@@ -19,6 +19,12 @@ import { FileOperation, IFileService } from 'vs/platform/files/common/files';
 import { Registry } from 'vs/platform/registry/common/platform';
 import { Workspace } from 'vs/platform/workspace/common/workspace';
 
+export interface IInspectValue<V> {
+	value?: V;
+	override?: V;
+	merged?: V;
+}
+
 export class ConfigurationModel implements IConfigurationModel {
 
 	private frozen: boolean = false;
@@ -27,10 +33,32 @@ export class ConfigurationModel implements IConfigurationModel {
 	constructor(
 		private readonly _contents: any = {},
 		private readonly _keys: string[] = [],
-		private readonly _overrides: IOverrides[] = []
+		private readonly _overrides: IOverrides[] = [],
+		readonly raw?: ReadonlyArray<IStringDictionary<any> | ConfigurationModel>
 	) {
 	}
 
+	private _rawConfiguration: ConfigurationModel | undefined;
+	get rawConfiguration(): ConfigurationModel {
+		if (!this._rawConfiguration) {
+			if (this.raw?.length) {
+				const rawConfigurationModels = this.raw.map(raw => {
+					if (raw instanceof ConfigurationModel) {
+						return raw;
+					}
+					const parser = new ConfigurationModelParser('');
+					parser.parseRaw(raw);
+					return parser.configurationModel;
+				});
+				this._rawConfiguration = rawConfigurationModels.reduce((previous, current) => current === previous ? current : previous.merge(current), rawConfigurationModels[0]);
+			} else {
+				// raw is same as current
+				this._rawConfiguration = this;
+			}
+		}
+		return this._rawConfiguration;
+	}
+
 	get contents(): any {
 		return this.checkAndFreeze(this._contents);
 	}
@@ -55,6 +83,13 @@ export class ConfigurationModel implements IConfigurationModel {
 		return section ? getConfigurationValue<any>(this.contents, section) : this.contents;
 	}
 
+	inspect<V>(section: string | undefined, overrideIdentifier?: string | null): IInspectValue<V> {
+		const value = this.rawConfiguration.getValue<V>(section);
+		const override = overrideIdentifier ? this.rawConfiguration.getOverrideValue<V>(section, overrideIdentifier) : undefined;
+		const merged = overrideIdentifier ? this.rawConfiguration.override(overrideIdentifier).getValue<V>(section) : value;
+		return { value, override, merged };
+	}
+
 	getOverrideValue<V>(section: string | undefined, overrideIdentifier: string): V | undefined {
 		const overrideContents = this.getContentsForOverrideIdentifer(overrideIdentifier);
 		return overrideContents
@@ -93,8 +128,10 @@ export class ConfigurationModel implements IConfigurationModel {
 		const contents = objects.deepClone(this.contents);
 		const overrides = objects.deepClone(this.overrides);
 		const keys = [...this.keys];
+		const raws = this.raw?.length ? [...this.raw] : [this];
 
 		for (const other of others) {
+			raws.push(...(other.raw?.length ? other.raw : [other]));
 			if (other.isEmpty()) {
 				continue;
 			}
@@ -116,7 +153,7 @@ export class ConfigurationModel implements IConfigurationModel {
 				}
 			}
 		}
-		return new ConfigurationModel(contents, keys, overrides);
+		return new ConfigurationModel(contents, keys, overrides, raws.every(raw => raw instanceof ConfigurationModel) ? undefined : raws);
 	}
 
 	freeze(): ConfigurationModel {
@@ -284,8 +321,8 @@ export class ConfigurationModelParser {
 
 	public parseRaw(raw: any, options?: ConfigurationParseOptions): void {
 		this._raw = raw;
-		const { contents, keys, overrides, restricted } = this.doParseRaw(raw, options);
-		this._configurationModel = new ConfigurationModel(contents, keys, overrides);
+		const { contents, keys, overrides, restricted, hasExcludedProperties } = this.doParseRaw(raw, options);
+		this._configurationModel = new ConfigurationModel(contents, keys, overrides, hasExcludedProperties ? [raw] : undefined /* raw has not changed */);
 		this._restrictedConfigurations = restricted || [];
 	}
 
@@ -346,19 +383,20 @@ export class ConfigurationModelParser {
 		return raw;
 	}
 
-	protected doParseRaw(raw: any, options?: ConfigurationParseOptions): IConfigurationModel & { restricted?: string[] } {
+	protected doParseRaw(raw: any, options?: ConfigurationParseOptions): IConfigurationModel & { restricted?: string[]; hasExcludedProperties?: boolean } {
 		const configurationProperties = Registry.as<IConfigurationRegistry>(Extensions.Configuration).getConfigurationProperties();
 		const filtered = this.filter(raw, configurationProperties, true, options);
 		raw = filtered.raw;
 		const contents = toValuesTree(raw, message => console.error(`Conflict in settings file ${this._name}: ${message}`));
 		const keys = Object.keys(raw);
 		const overrides = this.toOverrides(raw, message => console.error(`Conflict in settings file ${this._name}: ${message}`));
-		return { contents, keys, overrides, restricted: filtered.restricted };
+		return { contents, keys, overrides, restricted: filtered.restricted, hasExcludedProperties: filtered.hasExcludedProperties };
 	}
 
-	private filter(properties: any, configurationProperties: { [qualifiedKey: string]: IConfigurationPropertySchema | undefined }, filterOverriddenProperties: boolean, options?: ConfigurationParseOptions): { raw: {}; restricted: string[] } {
+	private filter(properties: any, configurationProperties: { [qualifiedKey: string]: IConfigurationPropertySchema | undefined }, filterOverriddenProperties: boolean, options?: ConfigurationParseOptions): { raw: {}; restricted: string[]; hasExcludedProperties: boolean } {
+		let hasExcludedProperties = false;
 		if (!options?.scopes && !options?.skipRestricted) {
-			return { raw: properties, restricted: [] };
+			return { raw: properties, restricted: [], hasExcludedProperties };
 		}
 		const raw: any = {};
 		const restricted: string[] = [];
@@ -366,6 +404,7 @@ export class ConfigurationModelParser {
 			if (OVERRIDE_PROPERTY_REGEX.test(key) && filterOverriddenProperties) {
 				const result = this.filter(properties[key], configurationProperties, false, options);
 				raw[key] = result.raw;
+				hasExcludedProperties = hasExcludedProperties || result.hasExcludedProperties;
 				restricted.push(...result.restricted);
 			} else {
 				const propertySchema = configurationProperties[key];
@@ -374,14 +413,15 @@ export class ConfigurationModelParser {
 					restricted.push(key);
 				}
 				// Load unregistered configurations always.
-				if (scope === undefined || options.scopes === undefined || options.scopes.includes(scope)) {
-					if (!(options.skipRestricted && propertySchema?.restricted)) {
-						raw[key] = properties[key];
-					}
+				if ((scope === undefined || options.scopes === undefined || options.scopes.includes(scope)) // Check scopes
+					&& !(options.skipRestricted && propertySchema?.restricted)) { // Check restricted
+					raw[key] = properties[key];
+				} else {
+					hasExcludedProperties = true;
 				}
 			}
 		}
-		return { raw, restricted };
+		return { raw, restricted, hasExcludedProperties };
 	}
 
 	private toOverrides(raw: any, conflictReporter: (message: string) => void): IOverrides[] {
@@ -449,6 +489,162 @@ export class UserSettings extends Disposable {
 	}
 }
 
+class ConfigurationInspectValue<V> implements IConfigurationValue<V> {
+
+	constructor(
+		private readonly key: string,
+		private readonly overrides: IConfigurationOverrides,
+		readonly value: V | undefined,
+		readonly overrideIdentifiers: string[] | undefined,
+		private readonly defaultConfiguration: ConfigurationModel,
+		private readonly policyConfiguration: ConfigurationModel | undefined,
+		private readonly applicationConfiguration: ConfigurationModel | undefined,
+		private readonly userConfiguration: ConfigurationModel,
+		private readonly localUserConfiguration: ConfigurationModel,
+		private readonly remoteUserConfiguration: ConfigurationModel,
+		private readonly workspaceConfiguration: ConfigurationModel | undefined,
+		private readonly folderConfigurationModel: ConfigurationModel | undefined,
+		private readonly memoryInspectValue: IInspectValue<V>,
+	) {
+	}
+
+	private _defaultInspectValue: IInspectValue<V> | undefined;
+	private get defaultInspectValue(): IInspectValue<V> {
+		if (!this._defaultInspectValue) {
+			this._defaultInspectValue = this.defaultConfiguration.inspect<V>(this.key, this.overrides.overrideIdentifier);
+		}
+		return this._defaultInspectValue;
+	}
+
+	get defaultValue(): V | undefined {
+		return this.defaultInspectValue.merged;
+	}
+
+	get default(): { value?: V; override?: V } | undefined {
+		return this.defaultInspectValue.value !== undefined || this.defaultInspectValue.override !== undefined ? { value: this.defaultInspectValue.value, override: this.defaultInspectValue.override } : undefined;
+	}
+
+	private _policyInspectValue: IInspectValue<V> | undefined | null;
+	private get policyInspectValue(): IInspectValue<V> | null {
+		if (this._policyInspectValue === undefined) {
+			this._policyInspectValue = this.policyConfiguration ? this.policyConfiguration.inspect<V>(this.key) : null;
+		}
+		return this._policyInspectValue;
+	}
+
+	get policyValue(): V | undefined {
+		return this.policyInspectValue?.merged;
+	}
+
+	get policy(): { value?: V; override?: V } | undefined {
+		return this.policyInspectValue?.value !== undefined ? { value: this.policyInspectValue.value } : undefined;
+	}
+
+	private _applicationInspectValue: IInspectValue<V> | undefined | null;
+	private get applicationInspectValue(): IInspectValue<V> | null {
+		if (this._applicationInspectValue === undefined) {
+			this._applicationInspectValue = this.applicationConfiguration ? this.applicationConfiguration.inspect<V>(this.key) : null;
+		}
+		return this._applicationInspectValue;
+	}
+
+	get applicationValue(): V | undefined {
+		return this.applicationInspectValue?.merged;
+	}
+
+	get application(): { value?: V; override?: V } | undefined {
+		return this.applicationInspectValue?.value !== undefined || this.applicationInspectValue?.override !== undefined ? { value: this.applicationInspectValue.value, override: this.applicationInspectValue.override } : undefined;
+	}
+
+	private _userInspectValue: IInspectValue<V> | undefined;
+	private get userInspectValue(): IInspectValue<V> {
+		if (!this._userInspectValue) {
+			this._userInspectValue = this.userConfiguration.inspect<V>(this.key, this.overrides.overrideIdentifier);
+		}
+		return this._userInspectValue;
+	}
+
+	get userValue(): V | undefined {
+		return this.userInspectValue.merged;
+	}
+
+	get user(): { value?: V; override?: V } | undefined {
+		return this.userInspectValue.value !== undefined || this.userInspectValue.override !== undefined ? { value: this.userInspectValue.value, override: this.userInspectValue.override } : undefined;
+	}
+
+	private _userLocalInspectValue: IInspectValue<V> | undefined;
+	private get userLocalInspectValue(): IInspectValue<V> {
+		if (!this._userLocalInspectValue) {
+			this._userLocalInspectValue = this.localUserConfiguration.inspect<V>(this.key, this.overrides.overrideIdentifier);
+		}
+		return this._userLocalInspectValue;
+	}
+
+	get userLocalValue(): V | undefined {
+		return this.userLocalInspectValue.merged;
+	}
+
+	get userLocal(): { value?: V; override?: V } | undefined {
+		return this.userLocalInspectValue.value !== undefined || this.userLocalInspectValue.override !== undefined ? { value: this.userLocalInspectValue.value, override: this.userLocalInspectValue.override } : undefined;
+	}
+
+	private _userRemoteInspectValue: IInspectValue<V> | undefined;
+	private get userRemoteInspectValue(): IInspectValue<V> {
+		if (!this._userRemoteInspectValue) {
+			this._userRemoteInspectValue = this.remoteUserConfiguration.inspect<V>(this.key, this.overrides.overrideIdentifier);
+		}
+		return this._userRemoteInspectValue;
+	}
+
+	get userRemoteValue(): V | undefined {
+		return this.userRemoteInspectValue.merged;
+	}
+
+	get userRemote(): { value?: V; override?: V } | undefined {
+		return this.userRemoteInspectValue.value !== undefined || this.userRemoteInspectValue.override !== undefined ? { value: this.userRemoteInspectValue.value, override: this.userRemoteInspectValue.override } : undefined;
+	}
+
+	private _workspaceInspectValue: IInspectValue<V> | undefined | null;
+	private get workspaceInspectValue(): IInspectValue<V> | null {
+		if (this._workspaceInspectValue === undefined) {
+			this._workspaceInspectValue = this.workspaceConfiguration ? this.workspaceConfiguration.inspect<V>(this.key, this.overrides.overrideIdentifier) : null;
+		}
+		return this._workspaceInspectValue;
+	}
+
+	get workspaceValue(): V | undefined {
+		return this.workspaceInspectValue?.merged;
+	}
+
+	get workspace(): { value?: V; override?: V } | undefined {
+		return this.workspaceInspectValue?.value !== undefined || this.workspaceInspectValue?.override !== undefined ? { value: this.workspaceInspectValue.value, override: this.workspaceInspectValue.override } : undefined;
+	}
+
+	private _workspaceFolderInspectValue: IInspectValue<V> | undefined | null;
+	private get workspaceFolderInspectValue(): IInspectValue<V> | null {
+		if (this._workspaceFolderInspectValue === undefined) {
+			this._workspaceFolderInspectValue = this.folderConfigurationModel ? this.folderConfigurationModel.inspect<V>(this.key, this.overrides.overrideIdentifier) : null;
+		}
+		return this._workspaceFolderInspectValue;
+	}
+
+	get workspaceFolderValue(): V | undefined {
+		return this.workspaceFolderInspectValue?.merged;
+	}
+
+	get workspaceFolder(): { value?: V; override?: V } | undefined {
+		return this.workspaceFolderInspectValue?.value !== undefined || this.workspaceFolderInspectValue?.override !== undefined ? { value: this.workspaceFolderInspectValue.value, override: this.workspaceFolderInspectValue.override } : undefined;
+	}
+
+	get memoryValue(): V | undefined {
+		return this.memoryInspectValue.merged;
+	}
+
+	get memory(): { value?: V; override?: V } | undefined {
+		return this.memoryInspectValue.value !== undefined || this.memoryInspectValue.override !== undefined ? { value: this.memoryInspectValue.value, override: this.memoryInspectValue.override } : undefined;
+	}
+
+}
 
 export class Configuration {
 
@@ -498,45 +694,26 @@ export class Configuration {
 
 	inspect<C>(key: string, overrides: IConfigurationOverrides, workspace: Workspace | undefined): IConfigurationValue<C> {
 		const consolidateConfigurationModel = this.getConsolidatedConfigurationModel(key, overrides, workspace);
+		const overrideIdentifiers: string[] = arrays.distinct(consolidateConfigurationModel.overrides.map(override => override.identifiers).flat()).filter(overrideIdentifier => consolidateConfigurationModel.getOverrideValue(key, overrideIdentifier) !== undefined);
 		const folderConfigurationModel = this.getFolderConfigurationModelForResource(overrides.resource, workspace);
 		const memoryConfigurationModel = overrides.resource ? this._memoryConfigurationByResource.get(overrides.resource) || this._memoryConfiguration : this._memoryConfiguration;
 
-		const defaultValue = overrides.overrideIdentifier ? this._defaultConfiguration.freeze().override(overrides.overrideIdentifier).getValue<C>(key) : this._defaultConfiguration.freeze().getValue<C>(key);
-		const policyValue = this._policyConfiguration.isEmpty() ? undefined : this._policyConfiguration.freeze().getValue<C>(key);
-		const applicationValue = this.applicationConfiguration.isEmpty() ? undefined : this.applicationConfiguration.freeze().getValue<C>(key);
-		const userValue = overrides.overrideIdentifier ? this.userConfiguration.freeze().override(overrides.overrideIdentifier).getValue<C>(key) : this.userConfiguration.freeze().getValue<C>(key);
-		const userLocalValue = overrides.overrideIdentifier ? this.localUserConfiguration.freeze().override(overrides.overrideIdentifier).getValue<C>(key) : this.localUserConfiguration.freeze().getValue<C>(key);
-		const userRemoteValue = overrides.overrideIdentifier ? this.remoteUserConfiguration.freeze().override(overrides.overrideIdentifier).getValue<C>(key) : this.remoteUserConfiguration.freeze().getValue<C>(key);
-		const workspaceValue = workspace ? overrides.overrideIdentifier ? this._workspaceConfiguration.freeze().override(overrides.overrideIdentifier).getValue<C>(key) : this._workspaceConfiguration.freeze().getValue<C>(key) : undefined; //Check on workspace exists or not because _workspaceConfiguration is never null
-		const workspaceFolderValue = folderConfigurationModel ? overrides.overrideIdentifier ? folderConfigurationModel.freeze().override(overrides.overrideIdentifier).getValue<C>(key) : folderConfigurationModel.freeze().getValue<C>(key) : undefined;
-		const memoryValue = overrides.overrideIdentifier ? memoryConfigurationModel.override(overrides.overrideIdentifier).getValue<C>(key) : memoryConfigurationModel.getValue<C>(key);
-		const value = consolidateConfigurationModel.getValue<C>(key);
-		const overrideIdentifiers: string[] = arrays.distinct(consolidateConfigurationModel.overrides.map(override => override.identifiers).flat()).filter(overrideIdentifier => consolidateConfigurationModel.getOverrideValue(key, overrideIdentifier) !== undefined);
+		return new ConfigurationInspectValue<C>(
+			key,
+			overrides,
+			consolidateConfigurationModel.getValue<C>(key),
+			overrideIdentifiers.length ? overrideIdentifiers : undefined,
+			this._defaultConfiguration,
+			this._policyConfiguration.isEmpty() ? undefined : this._policyConfiguration.freeze(),
+			this.applicationConfiguration.isEmpty() ? undefined : this.applicationConfiguration.freeze(),
+			this.userConfiguration.freeze(),
+			this.localUserConfiguration.freeze(),
+			this.remoteUserConfiguration.freeze(),
+			workspace ? this._workspaceConfiguration.freeze() : undefined,
+			folderConfigurationModel ? folderConfigurationModel.freeze() : undefined,
+			memoryConfigurationModel.inspect<C>(key, overrides.overrideIdentifier)
+		);
 
-		return {
-			defaultValue,
-			policyValue,
-			applicationValue,
-			userValue,
-			userLocalValue,
-			userRemoteValue,
-			workspaceValue,
-			workspaceFolderValue,
-			memoryValue,
-			value,
-
-			default: defaultValue !== undefined ? { value: this._defaultConfiguration.freeze().getValue(key), override: overrides.overrideIdentifier ? this._defaultConfiguration.freeze().getOverrideValue(key, overrides.overrideIdentifier) : undefined } : undefined,
-			policy: policyValue !== undefined ? { value: policyValue } : undefined,
-			application: applicationValue !== undefined ? { value: applicationValue, override: overrides.overrideIdentifier ? this.applicationConfiguration.freeze().getOverrideValue(key, overrides.overrideIdentifier) : undefined } : undefined,
-			user: userValue !== undefined ? { value: this.userConfiguration.freeze().getValue(key), override: overrides.overrideIdentifier ? this.userConfiguration.freeze().getOverrideValue(key, overrides.overrideIdentifier) : undefined } : undefined,
-			userLocal: userLocalValue !== undefined ? { value: this.localUserConfiguration.freeze().getValue(key), override: overrides.overrideIdentifier ? this.localUserConfiguration.freeze().getOverrideValue(key, overrides.overrideIdentifier) : undefined } : undefined,
-			userRemote: userRemoteValue !== undefined ? { value: this.remoteUserConfiguration.freeze().getValue(key), override: overrides.overrideIdentifier ? this.remoteUserConfiguration.freeze().getOverrideValue(key, overrides.overrideIdentifier) : undefined } : undefined,
-			workspace: workspaceValue !== undefined ? { value: this._workspaceConfiguration.freeze().getValue(key), override: overrides.overrideIdentifier ? this._workspaceConfiguration.freeze().getOverrideValue(key, overrides.overrideIdentifier) : undefined } : undefined,
-			workspaceFolder: workspaceFolderValue !== undefined ? { value: folderConfigurationModel?.freeze().getValue(key), override: overrides.overrideIdentifier ? folderConfigurationModel?.freeze().getOverrideValue(key, overrides.overrideIdentifier) : undefined } : undefined,
-			memory: memoryValue !== undefined ? { value: memoryConfigurationModel.getValue(key), override: overrides.overrideIdentifier ? memoryConfigurationModel.getOverrideValue(key, overrides.overrideIdentifier) : undefined } : undefined,
-
-			overrideIdentifiers: overrideIdentifiers.length ? overrideIdentifiers : undefined
-		};
 	}
 
 	keys(workspace: Workspace | undefined): {
@@ -944,7 +1121,7 @@ export class ConfigurationChangeEvent implements IConfigurationChangeEvent {
 }
 
 function compare(from: ConfigurationModel | undefined, to: ConfigurationModel | undefined): IConfigurationCompareResult {
-	const { added, removed, updated } = compareConfigurationContents(to, from);
+	const { added, removed, updated } = compareConfigurationContents(to?.rawConfiguration, from?.rawConfiguration);
 	const overrides: [string, string[]][] = [];
 
 	const fromOverrideIdentifiers = from?.getAllOverrideIdentifiers() || [];
