@@ -5,14 +5,18 @@
 
 import { IContextMenuDelegate } from 'vs/base/browser/contextmenu';
 import { ModifierKeyEmitter } from 'vs/base/browser/dom';
+import { IAction, Separator } from 'vs/base/common/actions';
 import { Emitter } from 'vs/base/common/event';
 import { Disposable } from 'vs/base/common/lifecycle';
+import { createAndFillInContextMenuActions } from 'vs/platform/actions/browser/menuEntryActionViewItem';
+import { IMenuService, MenuId } from 'vs/platform/actions/common/actions';
+import { IContextKeyService } from 'vs/platform/contextkey/common/contextkey';
 import { IKeybindingService } from 'vs/platform/keybinding/common/keybinding';
 import { INotificationService } from 'vs/platform/notification/common/notification';
 import { ITelemetryService } from 'vs/platform/telemetry/common/telemetry';
 import { IThemeService } from 'vs/platform/theme/common/themeService';
 import { ContextMenuHandler, IContextMenuHandlerOptions } from './contextMenuHandler';
-import { IContextMenuService, IContextViewService } from './contextView';
+import { IContextMenuMenuDelegate, IContextMenuService, IContextViewService } from './contextView';
 
 export class ContextMenuService extends Disposable implements IContextMenuService {
 
@@ -27,10 +31,10 @@ export class ContextMenuService extends Disposable implements IContextMenuServic
 		return this._contextMenuHandler;
 	}
 
-	private readonly _onDidShowContextMenu = new Emitter<void>();
+	private readonly _onDidShowContextMenu = this._store.add(new Emitter<void>());
 	readonly onDidShowContextMenu = this._onDidShowContextMenu.event;
 
-	private readonly _onDidHideContextMenu = new Emitter<void>();
+	private readonly _onDidHideContextMenu = this._store.add(new Emitter<void>());
 	readonly onDidHideContextMenu = this._onDidHideContextMenu.event;
 
 	constructor(
@@ -38,7 +42,9 @@ export class ContextMenuService extends Disposable implements IContextMenuServic
 		@INotificationService private readonly notificationService: INotificationService,
 		@IContextViewService private readonly contextViewService: IContextViewService,
 		@IKeybindingService private readonly keybindingService: IKeybindingService,
-		@IThemeService private readonly themeService: IThemeService
+		@IThemeService private readonly themeService: IThemeService,
+		@IMenuService private readonly menuService: IMenuService,
+		@IContextKeyService private readonly contextKeyService: IContextKeyService,
 	) {
 		super();
 	}
@@ -49,7 +55,10 @@ export class ContextMenuService extends Disposable implements IContextMenuServic
 
 	// ContextMenu
 
-	showContextMenu(delegate: IContextMenuDelegate): void {
+	showContextMenu(delegate: IContextMenuDelegate | IContextMenuMenuDelegate): void {
+
+		delegate = ContextMenuMenuDelegate.transform(delegate, this.menuService, this.contextKeyService);
+
 		this.contextMenuHandler.showContextMenu({
 			...delegate,
 			onHide: (didCancel) => {
@@ -62,3 +71,33 @@ export class ContextMenuService extends Disposable implements IContextMenuServic
 		this._onDidShowContextMenu.fire();
 	}
 }
+
+export namespace ContextMenuMenuDelegate {
+
+	function is(thing: IContextMenuDelegate | IContextMenuMenuDelegate): thing is IContextMenuMenuDelegate {
+		return thing && (<IContextMenuMenuDelegate>thing).menuId instanceof MenuId;
+	}
+
+	export function transform(delegate: IContextMenuDelegate | IContextMenuMenuDelegate, menuService: IMenuService, globalContextKeyService: IContextKeyService): IContextMenuDelegate {
+		if (!is(delegate)) {
+			return delegate;
+		}
+		const { menuId, menuActionOptions, contextKeyService } = delegate;
+		return {
+			...delegate,
+			getActions: () => {
+				const target: IAction[] = [];
+				if (menuId) {
+					const menu = menuService.createMenu(menuId, contextKeyService ?? globalContextKeyService);
+					createAndFillInContextMenuActions(menu, menuActionOptions, target);
+					menu.dispose();
+				}
+				if (!delegate.getActions) {
+					return target;
+				} else {
+					return Separator.join(delegate.getActions(), target);
+				}
+			}
+		};
+	}
+}
