@@ -7,6 +7,18 @@
  * A list of command line arguments we support natively.
  */
 export interface NativeParsedArgs {
+	// subcommands
+	tunnel?: {
+		'cli-data-dir'?: string;
+		'disable-telemetry'?: boolean;
+		'telemetry-level'?: string;
+		user: {
+			login: {
+				'access-token'?: string;
+				'provider'?: string;
+			};
+		};
+	};
 	_: string[];
 	'folder-uri'?: string[]; // undefined or array of 1 or more
 	'file-uri'?: string[]; // undefined or array of 1 or more
@@ -36,7 +48,7 @@ export interface NativeParsedArgs {
 	'trace-category-filter'?: string;
 	'trace-options'?: string;
 	'open-devtools'?: boolean;
-	log?: string;
+	log?: string[];
 	logExtensionHostCommunication?: boolean;
 	'extensions-dir'?: string;
 	'extensions-download-dir'?: string;
@@ -90,10 +102,13 @@ export interface NativeParsedArgs {
 	'logsPath'?: string;
 	'__enable-file-policy'?: boolean;
 	editSessionId?: string;
+	continueOn?: string;
 	'locate-shell-integration-path'?: string;
 	'profile'?: string;
 	'profile-temp'?: boolean;
 
+	'enable-coi'?: boolean;
+
 	// chromium command line args: https://electronjs.org/docs/all#supported-chrome-command-line-switches
 	'no-proxy-server'?: boolean;
 	'no-sandbox'?: boolean;
