@@ -441,6 +441,11 @@ export interface IWatchOptions {
 
 export const enum FileSystemProviderCapabilities {
 
+	/**
+	 * No capabilities.
+	 */
+	None = 0,
+
 	/**
 	 * Provider supports unbuffered read/write.
 	 */
