@@ -4,13 +4,15 @@
  *--------------------------------------------------------------------------------------------*/
 
 import { join } from 'vs/base/common/path';
+import { URI } from 'vs/base/common/uri';
 import { ProxyChannel } from 'vs/base/parts/ipc/common/ipc';
 import { Server } from 'vs/base/parts/ipc/node/ipc.cp';
 import { OPTIONS, parseArgs } from 'vs/platform/environment/node/argv';
 import { NativeEnvironmentService } from 'vs/platform/environment/node/environmentService';
-import { ConsoleLogger, getLogLevel, LogService, MultiplexLogService } from 'vs/platform/log/common/log';
+import { BufferLogService } from 'vs/platform/log/common/bufferLog';
+import { ConsoleLogger, LogService, MultiplexLogService } from 'vs/platform/log/common/log';
 import { LogLevelChannel } from 'vs/platform/log/common/logIpc';
-import { SpdLogLogger } from 'vs/platform/log/node/spdlogLog';
+import { LoggerService } from 'vs/platform/log/node/loggerService';
 import product from 'vs/platform/product/common/product';
 import { IProductService } from 'vs/platform/product/common/productService';
 import { IReconnectConstants, TerminalIpcChannels, TerminalLogConstants } from 'vs/platform/terminal/common/terminal';
@@ -25,11 +27,14 @@ delete process.env.VSCODE_LAST_PTY_ID;
 // Logging
 const productService: IProductService = { _serviceBrand: undefined, ...product };
 const environmentService = new NativeEnvironmentService(parseArgs(process.argv, OPTIONS), productService);
+const bufferLogService = new BufferLogService();
 const logService = new LogService(new MultiplexLogService([
 	new ConsoleLogger(),
-	new SpdLogLogger(TerminalLogConstants.FileName, join(environmentService.logsPath, `${TerminalLogConstants.FileName}.log`), true, false, getLogLevel(environmentService))
+	bufferLogService
 ]));
-const logLevelChannel = new LogLevelChannel(logService);
+const loggerService = new LoggerService(logService);
+bufferLogService.logger = loggerService.createLogger(URI.file(join(environmentService.logsPath, `${TerminalLogConstants.FileName}.log`)), { name: TerminalLogConstants.FileName });
+const logLevelChannel = new LogLevelChannel(logService, loggerService);
 server.registerChannel(TerminalIpcChannels.Log, logLevelChannel);
 
 const heartbeatService = new HeartbeatService();
@@ -44,7 +49,7 @@ delete process.env.VSCODE_RECONNECT_GRACE_TIME;
 delete process.env.VSCODE_RECONNECT_SHORT_GRACE_TIME;
 delete process.env.VSCODE_RECONNECT_SCROLLBACK;
 
-const ptyService = new PtyService(lastPtyId, logService, reconnectConstants);
+const ptyService = new PtyService(lastPtyId, logService, productService, reconnectConstants);
 server.registerChannel(TerminalIpcChannels.PtyHost, ProxyChannel.fromService(ptyService));
 
 process.once('exit', () => {
