@@ -7,11 +7,12 @@ import * as assert from 'assert';
 import { VSBuffer } from 'vs/base/common/buffer';
 import { Event } from 'vs/base/common/event';
 import { DisposableStore, toDisposable } from 'vs/base/common/lifecycle';
+import { runWithFakedTimers } from 'vs/base/test/common/timeTravelScheduler';
 import { IConfigurationService } from 'vs/platform/configuration/common/configuration';
 import { ConfigurationScope, Extensions, IConfigurationRegistry } from 'vs/platform/configuration/common/configurationRegistry';
 import { IFileService } from 'vs/platform/files/common/files';
 import { Registry } from 'vs/platform/registry/common/platform';
-import { IUserDataProfilesService } from 'vs/platform/userDataProfile/common/userDataProfile';
+import { IUserDataProfile, IUserDataProfilesService } from 'vs/platform/userDataProfile/common/userDataProfile';
 import { ISettingsSyncContent, parseSettingsSyncContent, SettingsSynchroniser } from 'vs/platform/userDataSync/common/settingsSync';
 import { ISyncData, IUserDataSyncStoreService, SyncResource, SyncStatus, UserDataSyncError, UserDataSyncErrorCode } from 'vs/platform/userDataSync/common/userDataSync';
 import { UserDataSyncClient, UserDataSyncTestServer } from 'vs/platform/userDataSync/test/common/userDataSyncClient';
@@ -47,12 +48,12 @@ suite('SettingsSync - Auto', () => {
 
 	teardown(() => disposableStore.clear());
 
-	test('when settings file does not exist', async () => {
+	test('when settings file does not exist', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		const fileService = client.instantiationService.get(IFileService);
 		const settingResource = client.instantiationService.get(IUserDataProfilesService).defaultProfile.settingsResource;
 
 		assert.deepStrictEqual(await testObject.getLastSyncUserData(), null);
-		let manifest = await client.manifest();
+		let manifest = await client.getResourceManifest();
 		server.reset();
 		await testObject.sync(manifest);
 
@@ -67,32 +68,32 @@ suite('SettingsSync - Auto', () => {
 		assert.deepStrictEqual(lastSyncUserData!.syncData, remoteUserData.syncData);
 		assert.strictEqual(lastSyncUserData!.syncData, null);
 
-		manifest = await client.manifest();
+		manifest = await client.getResourceManifest();
 		server.reset();
 		await testObject.sync(manifest);
 		assert.deepStrictEqual(server.requests, []);
 
-		manifest = await client.manifest();
+		manifest = await client.getResourceManifest();
 		server.reset();
 		await testObject.sync(manifest);
 		assert.deepStrictEqual(server.requests, []);
-	});
+	}));
 
-	test('when settings file is empty and remote has no changes', async () => {
+	test('when settings file is empty and remote has no changes', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		const fileService = client.instantiationService.get(IFileService);
 		const settingsResource = client.instantiationService.get(IUserDataProfilesService).defaultProfile.settingsResource;
 		await fileService.writeFile(settingsResource, VSBuffer.fromString(''));
 
-		await testObject.sync(await client.manifest());
+		await testObject.sync(await client.getResourceManifest());
 
 		const lastSyncUserData = await testObject.getLastSyncUserData();
 		const remoteUserData = await testObject.getRemoteUserData(null);
 		assert.strictEqual(parseSettingsSyncContent(lastSyncUserData!.syncData!.content!)?.settings, '{}');
 		assert.strictEqual(parseSettingsSyncContent(remoteUserData!.syncData!.content!)?.settings, '{}');
 		assert.strictEqual((await fileService.readFile(settingsResource)).value.toString(), '');
-	});
+	}));
 
-	test('when settings file is empty and remote has changes', async () => {
+	test('when settings file is empty and remote has changes', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		const client2 = disposableStore.add(new UserDataSyncClient(server));
 		await client2.setUp(true);
 		const content =
@@ -124,24 +125,24 @@ suite('SettingsSync - Auto', () => {
 		const settingsResource = client.instantiationService.get(IUserDataProfilesService).defaultProfile.settingsResource;
 		await fileService.writeFile(settingsResource, VSBuffer.fromString(''));
 
-		await testObject.sync(await client.manifest());
+		await testObject.sync(await client.getResourceManifest());
 
 		const lastSyncUserData = await testObject.getLastSyncUserData();
 		const remoteUserData = await testObject.getRemoteUserData(null);
 		assert.strictEqual(parseSettingsSyncContent(lastSyncUserData!.syncData!.content!)?.settings, content);
 		assert.strictEqual(parseSettingsSyncContent(remoteUserData!.syncData!.content!)?.settings, content);
 		assert.strictEqual((await fileService.readFile(settingsResource)).value.toString(), content);
-	});
+	}));
 
-	test('when settings file is created after first sync', async () => {
+	test('when settings file is created after first sync', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		const fileService = client.instantiationService.get(IFileService);
 
 		const settingsResource = client.instantiationService.get(IUserDataProfilesService).defaultProfile.settingsResource;
-		await testObject.sync(await client.manifest());
+		await testObject.sync(await client.getResourceManifest());
 		await fileService.createFile(settingsResource, VSBuffer.fromString('{}'));
 
 		let lastSyncUserData = await testObject.getLastSyncUserData();
-		const manifest = await client.manifest();
+		const manifest = await client.getResourceManifest();
 		server.reset();
 		await testObject.sync(manifest);
 
@@ -154,9 +155,9 @@ suite('SettingsSync - Auto', () => {
 		assert.deepStrictEqual(lastSyncUserData!.ref, remoteUserData.ref);
 		assert.deepStrictEqual(lastSyncUserData!.syncData, remoteUserData.syncData);
 		assert.strictEqual(parseSettingsSyncContent(lastSyncUserData!.syncData!.content!)?.settings, '{}');
-	});
+	}));
 
-	test('sync for first time to the server', async () => {
+	test('sync for first time to the server', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		const expected =
 			`{
 	// Always
@@ -181,15 +182,15 @@ suite('SettingsSync - Auto', () => {
 }`;
 
 		await updateSettings(expected, client);
-		await testObject.sync(await client.manifest());
+		await testObject.sync(await client.getResourceManifest());
 
 		const { content } = await client.read(testObject.resource);
 		assert.ok(content !== null);
 		const actual = parseSettings(content!);
 		assert.deepStrictEqual(actual, expected);
-	});
+	}));
 
-	test('do not sync machine settings', async () => {
+	test('do not sync machine settings', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		const settingsContent =
 			`{
 	// Always
@@ -205,7 +206,7 @@ suite('SettingsSync - Auto', () => {
 }`;
 		await updateSettings(settingsContent, client);
 
-		await testObject.sync(await client.manifest());
+		await testObject.sync(await client.getResourceManifest());
 
 		const { content } = await client.read(testObject.resource);
 		assert.ok(content !== null);
@@ -218,9 +219,9 @@ suite('SettingsSync - Auto', () => {
 	// Workbench
 	"workbench.colorTheme": "GitHub Sharp"
 }`);
-	});
+	}));
 
-	test('do not sync machine settings when spread across file', async () => {
+	test('do not sync machine settings when spread across file', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		const settingsContent =
 			`{
 	// Always
@@ -236,7 +237,7 @@ suite('SettingsSync - Auto', () => {
 }`;
 		await updateSettings(settingsContent, client);
 
-		await testObject.sync(await client.manifest());
+		await testObject.sync(await client.getResourceManifest());
 
 		const { content } = await client.read(testObject.resource);
 		assert.ok(content !== null);
@@ -249,9 +250,9 @@ suite('SettingsSync - Auto', () => {
 	// Workbench
 	"workbench.colorTheme": "GitHub Sharp"
 }`);
-	});
+	}));
 
-	test('do not sync machine settings when spread across file - 2', async () => {
+	test('do not sync machine settings when spread across file - 2', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		const settingsContent =
 			`{
 	// Always
@@ -267,7 +268,7 @@ suite('SettingsSync - Auto', () => {
 }`;
 		await updateSettings(settingsContent, client);
 
-		await testObject.sync(await client.manifest());
+		await testObject.sync(await client.getResourceManifest());
 
 		const { content } = await client.read(testObject.resource);
 		assert.ok(content !== null);
@@ -280,9 +281,9 @@ suite('SettingsSync - Auto', () => {
 	"workbench.colorTheme": "GitHub Sharp",
 	"files.simpleDialog.enable": true,
 }`);
-	});
+	}));
 
-	test('sync when all settings are machine settings', async () => {
+	test('sync when all settings are machine settings', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		const settingsContent =
 			`{
 	// Machine
@@ -291,16 +292,16 @@ suite('SettingsSync - Auto', () => {
 }`;
 		await updateSettings(settingsContent, client);
 
-		await testObject.sync(await client.manifest());
+		await testObject.sync(await client.getResourceManifest());
 
 		const { content } = await client.read(testObject.resource);
 		assert.ok(content !== null);
 		const actual = parseSettings(content!);
 		assert.deepStrictEqual(actual, `{
 }`);
-	});
+	}));
 
-	test('sync when all settings are machine settings with trailing comma', async () => {
+	test('sync when all settings are machine settings with trailing comma', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		const settingsContent =
 			`{
 	// Machine
@@ -309,7 +310,7 @@ suite('SettingsSync - Auto', () => {
 }`;
 		await updateSettings(settingsContent, client);
 
-		await testObject.sync(await client.manifest());
+		await testObject.sync(await client.getResourceManifest());
 
 		const { content } = await client.read(testObject.resource);
 		assert.ok(content !== null);
@@ -317,9 +318,9 @@ suite('SettingsSync - Auto', () => {
 		assert.deepStrictEqual(actual, `{
 	,
 }`);
-	});
+	}));
 
-	test('local change event is triggered when settings are changed', async () => {
+	test('local change event is triggered when settings are changed', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		const content =
 			`{
 	"files.autoSave": "afterDelay",
@@ -327,7 +328,7 @@ suite('SettingsSync - Auto', () => {
 }`;
 
 		await updateSettings(content, client);
-		await testObject.sync(await client.manifest());
+		await testObject.sync(await client.getResourceManifest());
 
 		const promise = Event.toPromise(testObject.onDidChangeLocal);
 		await updateSettings(`{
@@ -335,9 +336,9 @@ suite('SettingsSync - Auto', () => {
 	"files.simpleDialog.enable": true,
 }`, client);
 		await promise;
-	});
+	}));
 
-	test('do not sync ignored settings', async () => {
+	test('do not sync ignored settings', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		const settingsContent =
 			`{
 	// Always
@@ -361,7 +362,7 @@ suite('SettingsSync - Auto', () => {
 }`;
 		await updateSettings(settingsContent, client);
 
-		await testObject.sync(await client.manifest());
+		await testObject.sync(await client.getResourceManifest());
 
 		const { content } = await client.read(testObject.resource);
 		assert.ok(content !== null);
@@ -380,9 +381,9 @@ suite('SettingsSync - Auto', () => {
 		"terminal.integrated.shell.osx"
 	]
 }`);
-	});
+	}));
 
-	test('do not sync ignored and machine settings', async () => {
+	test('do not sync ignored and machine settings', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		const settingsContent =
 			`{
 	// Always
@@ -409,7 +410,7 @@ suite('SettingsSync - Auto', () => {
 }`;
 		await updateSettings(settingsContent, client);
 
-		await testObject.sync(await client.manifest());
+		await testObject.sync(await client.getResourceManifest());
 
 		const { content } = await client.read(testObject.resource);
 		assert.ok(content !== null);
@@ -428,9 +429,9 @@ suite('SettingsSync - Auto', () => {
 		"terminal.integrated.shell.osx"
 	],
 }`);
-	});
+	}));
 
-	test('sync throws invalid content error', async () => {
+	test('sync throws invalid content error', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		const expected =
 			`{
 	// Always
@@ -457,26 +458,26 @@ suite('SettingsSync - Auto', () => {
 		await updateSettings(expected, client);
 
 		try {
-			await testObject.sync(await client.manifest());
+			await testObject.sync(await client.getResourceManifest());
 			assert.fail('should fail with invalid content error');
 		} catch (e) {
 			assert.ok(e instanceof UserDataSyncError);
 			assert.deepStrictEqual((<UserDataSyncError>e).code, UserDataSyncErrorCode.LocalInvalidContent);
 		}
-	});
+	}));
 
-	test('sync throws invalid content error - content is an array', async () => {
+	test('sync throws invalid content error - content is an array', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		await updateSettings('[]', client);
 		try {
-			await testObject.sync(await client.manifest());
+			await testObject.sync(await client.getResourceManifest());
 			assert.fail('should fail with invalid content error');
 		} catch (e) {
 			assert.ok(e instanceof UserDataSyncError);
 			assert.deepStrictEqual((<UserDataSyncError>e).code, UserDataSyncErrorCode.LocalInvalidContent);
 		}
-	});
+	}));
 
-	test('sync when there are conflicts', async () => {
+	test('sync when there are conflicts', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		const client2 = disposableStore.add(new UserDataSyncClient(server));
 		await client2.setUp(true);
 		await updateSettings(JSON.stringify({
@@ -491,18 +492,37 @@ suite('SettingsSync - Auto', () => {
 			'b': 1,
 			'settingsSync.ignoredSettings': ['a']
 		}), client);
-		await testObject.sync(await client.manifest());
+		await testObject.sync(await client.getResourceManifest());
 
 		assert.strictEqual(testObject.status, SyncStatus.HasConflicts);
-		assert.strictEqual(testObject.conflicts[0].localResource.toString(), testObject.localResource.toString());
+		assert.strictEqual(testObject.conflicts.conflicts[0].localResource.toString(), testObject.localResource.toString());
 
 		const fileService = client.instantiationService.get(IFileService);
-		const mergeContent = (await fileService.readFile(testObject.conflicts[0].previewResource)).value.toString();
-		assert.deepStrictEqual(JSON.parse(mergeContent), {
-			'b': 1,
-			'settingsSync.ignoredSettings': ['a']
+		const mergeContent = (await fileService.readFile(testObject.conflicts.conflicts[0].previewResource)).value.toString();
+		assert.strictEqual(mergeContent, '');
+	}));
+
+	test('sync profile settings', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
+		const client2 = disposableStore.add(new UserDataSyncClient(server));
+		await client2.setUp(true);
+		const profile = await client2.instantiationService.get(IUserDataProfilesService).createNamedProfile('profile1');
+		await updateSettings(JSON.stringify({
+			'a': 1,
+			'b': 2,
+		}), client2, profile);
+		await client2.sync();
+
+		await client.sync();
+
+		assert.strictEqual(testObject.status, SyncStatus.Idle);
+
+		const syncedProfile = client.instantiationService.get(IUserDataProfilesService).profiles.find(p => p.id === profile.id)!;
+		const content = (await client.instantiationService.get(IFileService).readFile(syncedProfile.settingsResource)).value.toString();
+		assert.deepStrictEqual(JSON.parse(content), {
+			'a': 1,
+			'b': 2,
 		});
-	});
+	}));
 
 });
 
@@ -522,7 +542,7 @@ suite('SettingsSync - Manual', () => {
 
 	teardown(() => disposableStore.clear());
 
-	test('do not sync ignored settings', async () => {
+	test('do not sync ignored settings', () => runWithFakedTimers<void>({ useFakeTimers: true }, async () => {
 		const settingsContent =
 			`{
 	// Always
@@ -546,7 +566,7 @@ suite('SettingsSync - Manual', () => {
 }`;
 		await updateSettings(settingsContent, client);
 
-		let preview = await testObject.preview(await client.manifest(), {});
+		let preview = await testObject.preview(await client.getResourceManifest(), {});
 		assert.strictEqual(testObject.status, SyncStatus.Syncing);
 		preview = await testObject.accept(preview!.resourcePreviews[0].previewResource);
 		preview = await testObject.apply(false);
@@ -568,7 +588,7 @@ suite('SettingsSync - Manual', () => {
 		"terminal.integrated.shell.osx"
 	]
 }`);
-	});
+	}));
 
 });
 
@@ -578,7 +598,7 @@ function parseSettings(content: string): string {
 	return settingsSyncContent.settings;
 }
 
-async function updateSettings(content: string, client: UserDataSyncClient): Promise<void> {
-	await client.instantiationService.get(IFileService).writeFile(client.instantiationService.get(IUserDataProfilesService).defaultProfile.settingsResource, VSBuffer.fromString(content));
+async function updateSettings(content: string, client: UserDataSyncClient, profile?: IUserDataProfile): Promise<void> {
+	await client.instantiationService.get(IFileService).writeFile((profile ?? client.instantiationService.get(IUserDataProfilesService).defaultProfile).settingsResource, VSBuffer.fromString(content));
 	await client.instantiationService.get(IConfigurationService).reloadConfiguration();
 }
