@@ -4,6 +4,7 @@
  *--------------------------------------------------------------------------------------------*/
 
 import { isNonEmptyArray } from 'vs/base/common/arrays';
+import { CancellationToken } from 'vs/base/common/cancellation';
 import { onUnexpectedError } from 'vs/base/common/errors';
 import { Emitter, Event } from 'vs/base/common/event';
 import { combinedDisposable, DisposableMap, DisposableStore, IDisposable, toDisposable } from 'vs/base/common/lifecycle';
@@ -15,7 +16,7 @@ import { extHostNamedCustomer, IExtHostContext } from 'vs/workbench/services/ext
 import { INotebookEditor } from 'vs/workbench/contrib/notebook/browser/notebookBrowser';
 import { INotebookEditorService } from 'vs/workbench/contrib/notebook/browser/services/notebookEditorService';
 import { INotebookCellExecution, INotebookExecutionStateService } from 'vs/workbench/contrib/notebook/common/notebookExecutionStateService';
-import { INotebookKernel, INotebookKernelChangeEvent, INotebookKernelService } from 'vs/workbench/contrib/notebook/common/notebookKernelService';
+import { IKernelSourceActionProvider, INotebookKernel, INotebookKernelChangeEvent, INotebookKernelDetectionTask, INotebookKernelService } from 'vs/workbench/contrib/notebook/common/notebookKernelService';
 import { SerializableObjectWithBuffers } from 'vs/workbench/services/extensions/common/proxyIdentifier';
 import { ExtHostContext, ExtHostNotebookKernelsShape, ICellExecuteUpdateDto, ICellExecutionCompleteDto, INotebookKernelDto2, MainContext, MainThreadNotebookKernelsShape } from '../common/extHost.protocol';
 import { INotebookService } from 'vs/workbench/contrib/notebook/common/notebookService';
@@ -101,6 +102,10 @@ abstract class MainThreadKernel implements INotebookKernel {
 	abstract cancelNotebookCellExecution(uri: URI, cellHandles: number[]): Promise<void>;
 }
 
+class MainThreadKernelDetectionTask implements INotebookKernelDetectionTask {
+	constructor(readonly notebookType: string) { }
+}
+
 @extHostNamedCustomer(MainContext.MainThreadNotebookKernels)
 export class MainThreadNotebookKernels implements MainThreadNotebookKernelsShape {
 
@@ -108,6 +113,8 @@ export class MainThreadNotebookKernels implements MainThreadNotebookKernelsShape
 	private readonly _disposables = new DisposableStore();
 
 	private readonly _kernels = new Map<number, [kernel: MainThreadKernel, registraion: IDisposable]>();
+	private readonly _kernelDetectionTasks = new Map<number, [task: MainThreadKernelDetectionTask, registraion: IDisposable]>();
+	private readonly _kernelSourceActionProviders = new Map<number, [provider: IKernelSourceActionProvider, registraion: IDisposable]>();
 	private readonly _proxy: ExtHostNotebookKernelsShape;
 
 	private readonly _executions = new Map<number, INotebookCellExecution>();
@@ -143,6 +150,9 @@ export class MainThreadNotebookKernels implements MainThreadNotebookKernelsShape
 		for (const [, registration] of this._kernels.values()) {
 			registration.dispose();
 		}
+		for (const [, registration] of this._kernelDetectionTasks.values()) {
+			registration.dispose();
+		}
 		this._editors.dispose();
 	}
 
@@ -286,4 +296,40 @@ export class MainThreadNotebookKernels implements MainThreadNotebookKernelsShape
 			this._executions.delete(handle);
 		}
 	}
+
+	// --- notebook kernel detection task
+	async $addKernelDetectionTask(handle: number, notebookType: string): Promise<void> {
+		const kernelDetectionTask = new MainThreadKernelDetectionTask(notebookType);
+		const registration = this._notebookKernelService.registerNotebookKernelDetectionTask(kernelDetectionTask);
+		this._kernelDetectionTasks.set(handle, [kernelDetectionTask, registration]);
+	}
+
+	$removeKernelDetectionTask(handle: number): void {
+		const tuple = this._kernelDetectionTasks.get(handle);
+		if (tuple) {
+			tuple[1].dispose();
+			this._kernelDetectionTasks.delete(handle);
+		}
+	}
+
+	// --- notebook kernel source action provider
+
+	async $addKernelSourceActionProvider(handle: number, notebookType: string): Promise<void> {
+		const kernelSourceActionProvider: IKernelSourceActionProvider = {
+			viewType: notebookType,
+			provideKernelSourceActions: async () => {
+				return this._proxy.$provideKernelSourceActions(handle, CancellationToken.None);
+			}
+		};
+		const registration = this._notebookKernelService.registerKernelSourceActionProvider(notebookType, kernelSourceActionProvider);
+		this._kernelSourceActionProviders.set(handle, [kernelSourceActionProvider, registration]);
+	}
+
+	$removeKernelSourceActionProvider(handle: number): void {
+		const tuple = this._kernelSourceActionProviders.get(handle);
+		if (tuple) {
+			tuple[1].dispose();
+			this._kernelSourceActionProviders.delete(handle);
+		}
+	}
 }
