@@ -66,7 +66,7 @@ export function createExtHostComments(mainContext: IMainContext, commands: ExtHo
 						}
 
 						return commentThread.value;
-					} else if (arg && arg.$mid === MarshalledId.CommentThreadReply) {
+					} else if (arg && (arg.$mid === MarshalledId.CommentThreadReply || arg.$mid === MarshalledId.CommentThreadInstance)) {
 						const commentController = this._commentControllers.get(arg.thread.commentControlHandle);
 
 						if (!commentController) {
@@ -79,6 +79,10 @@ export function createExtHostComments(mainContext: IMainContext, commands: ExtHo
 							return arg;
 						}
 
+						if (arg.$mid === MarshalledId.CommentThreadInstance) {
+							return commentThread.value;
+						}
+
 						return {
 							thread: commentThread.value,
 							text: arg.text
@@ -132,7 +136,7 @@ export function createExtHostComments(mainContext: IMainContext, commands: ExtHo
 						if (typeof comment.body === 'string') {
 							comment.body = body;
 						} else {
-							comment.body.value = body;
+							comment.body = new types.MarkdownString(body);
 						}
 						return comment;
 					}
