@@ -46,7 +46,6 @@ import { TestNotificationService } from 'vs/platform/notification/test/common/te
 import { INotificationService } from 'vs/platform/notification/common/notification';
 import { TestTextResourcePropertiesService, TestContextService } from 'vs/workbench/test/common/workbenchTestServices';
 import { IUriIdentityService } from 'vs/platform/uriIdentity/common/uriIdentity';
-import { extUri } from 'vs/base/common/resources';
 import { ITextSnapshot } from 'vs/editor/common/model';
 import { ILifecycleService } from 'vs/workbench/services/lifecycle/common/lifecycle';
 import { IEnvironmentService } from 'vs/platform/environment/common/environment';
@@ -57,6 +56,7 @@ import { LanguageFeatureDebounceService } from 'vs/editor/common/services/langua
 import { LanguageFeaturesService } from 'vs/editor/common/services/languageFeaturesService';
 import { MainThreadBulkEdits } from 'vs/workbench/api/browser/mainThreadBulkEdits';
 import { IWorkingCopyService } from 'vs/workbench/services/workingCopy/common/workingCopyService';
+import { UriIdentityService } from 'vs/platform/uriIdentity/common/uriIdentityService';
 
 suite('MainThreadEditors', () => {
 
@@ -113,6 +113,7 @@ suite('MainThreadEditors', () => {
 		services.set(IModelService, modelService);
 		services.set(ICodeEditorService, new TestCodeEditorService(themeService));
 		services.set(IFileService, new TestFileService());
+		services.set(IUriIdentityService, new SyncDescriptor(UriIdentityService));
 		services.set(IEditorService, new TestEditorService());
 		services.set(ILifecycleService, new TestLifecycleService());
 		services.set(IWorkingCopyService, new TestWorkingCopyService());
@@ -181,9 +182,6 @@ suite('MainThreadEditors', () => {
 				return undefined;
 			}
 		});
-		services.set(IUriIdentityService, new class extends mock<IUriIdentityService>() {
-			override get extUri() { return extUri; }
-		});
 
 		const instaService = new InstantiationService(services);
 
