@@ -10,7 +10,7 @@ import { IComposite, ICompositeControl } from 'vs/workbench/common/composite';
 import { Event, Emitter } from 'vs/base/common/event';
 import { IThemeService } from 'vs/platform/theme/common/themeService';
 import { IConstructorSignature, IInstantiationService } from 'vs/platform/instantiation/common/instantiation';
-import { trackFocus, Dimension } from 'vs/base/browser/dom';
+import { trackFocus, Dimension, IDomPosition } from 'vs/base/browser/dom';
 import { IStorageService } from 'vs/platform/storage/common/storage';
 import { Disposable } from 'vs/base/common/lifecycle';
 import { assertIsDefined } from 'vs/base/common/types';
@@ -153,7 +153,7 @@ export abstract class Composite extends Component implements IComposite {
 	/**
 	 * Layout the contents of this composite using the provided dimensions.
 	 */
-	abstract layout(dimension: Dimension): void;
+	abstract layout(dimension: Dimension, position?: IDomPosition): void;
 
 	/**
 	 * Update the styles of the contents of this composite.
@@ -162,7 +162,6 @@ export abstract class Composite extends Component implements IComposite {
 		super.updateStyles();
 	}
 
-
 	/**
 	 *
 	 * @returns the action runner for this composite
