@@ -262,7 +262,7 @@ export class NotificationsCenter extends Themable implements INotificationsCente
 		}
 	}
 
-	protected override updateStyles(): void {
+	override updateStyles(): void {
 		if (this.notificationsCenterContainer && this.notificationsCenterHeader) {
 			const widgetShadowColor = this.getColor(widgetShadow);
 			this.notificationsCenterContainer.style.boxShadow = widgetShadowColor ? `0 0 8px 2px ${widgetShadowColor}` : '';
@@ -275,6 +275,7 @@ export class NotificationsCenter extends Themable implements INotificationsCente
 
 			const headerBackground = this.getColor(NOTIFICATIONS_CENTER_HEADER_BACKGROUND);
 			this.notificationsCenterHeader.style.background = headerBackground ? headerBackground.toString() : '';
+
 		}
 	}
 
