@@ -196,7 +196,7 @@ export function registerNotificationCommands(center: INotificationsCenterControl
 		weight: KeybindingWeight.WorkbenchContrib,
 		when: ContextKeyExpr.and(NotificationFocusedContext, NotificationsToastsVisibleContext),
 		primary: KeyCode.DownArrow,
-		handler: (accessor) => {
+		handler: () => {
 			toasts.focusNext();
 		}
 	});
@@ -207,7 +207,7 @@ export function registerNotificationCommands(center: INotificationsCenterControl
 		weight: KeybindingWeight.WorkbenchContrib,
 		when: ContextKeyExpr.and(NotificationFocusedContext, NotificationsToastsVisibleContext),
 		primary: KeyCode.UpArrow,
-		handler: (accessor) => {
+		handler: () => {
 			toasts.focusPrevious();
 		}
 	});
@@ -219,7 +219,7 @@ export function registerNotificationCommands(center: INotificationsCenterControl
 		when: ContextKeyExpr.and(NotificationFocusedContext, NotificationsToastsVisibleContext),
 		primary: KeyCode.PageUp,
 		secondary: [KeyCode.Home],
-		handler: (accessor) => {
+		handler: () => {
 			toasts.focusFirst();
 		}
 	});
@@ -231,7 +231,7 @@ export function registerNotificationCommands(center: INotificationsCenterControl
 		when: ContextKeyExpr.and(NotificationFocusedContext, NotificationsToastsVisibleContext),
 		primary: KeyCode.PageDown,
 		secondary: [KeyCode.End],
-		handler: (accessor) => {
+		handler: () => {
 			toasts.focusLast();
 		}
 	});
