@@ -663,6 +663,8 @@ export interface ITreeView extends IDisposable {
 
 	readonly onDidChangeSelection: Event<ITreeItem[]>;
 
+	readonly onDidChangeFocus: Event<ITreeItem>;
+
 	readonly onDidChangeVisibility: Event<boolean>;
 
 	readonly onDidChangeActions: Event<void>;
@@ -673,6 +675,8 @@ export interface ITreeView extends IDisposable {
 
 	readonly onDidChangeWelcomeState: Event<void>;
 
+	readonly onDidChangeCheckboxState: Event<ITreeItem[]>;
+
 	readonly container: any | undefined;
 
 	refresh(treeItems?: ITreeItem[]): Promise<void>;
@@ -691,6 +695,8 @@ export interface ITreeView extends IDisposable {
 
 	setSelection(items: ITreeItem[]): void;
 
+	getSelection(): ITreeItem[];
+
 	setFocus(item: ITreeItem): void;
 
 	show(container: any): void;
@@ -710,6 +716,12 @@ export interface ITreeViewDescriptor extends IViewDescriptor {
 	treeView: ITreeView;
 }
 
+export type TreeViewPaneHandleArg = {
+	$treeViewId: string;
+	$selectedTreeItems?: boolean;
+	$focusedTreeItem?: boolean;
+};
+
 export type TreeViewItemHandleArg = {
 	$treeViewId: string;
 	$treeItemHandle: string;
@@ -733,6 +745,11 @@ export interface ITreeItemLabel {
 
 export type TreeCommand = Command & { originalId?: string };
 
+export interface ITreeItemCheckboxState {
+	isChecked: boolean;
+	tooltip?: string;
+}
+
 export interface ITreeItem {
 
 	handle: string;
@@ -762,6 +779,8 @@ export interface ITreeItem {
 	children?: ITreeItem[];
 
 	accessibilityInformation?: IAccessibilityInformation;
+
+	checkbox?: ITreeItemCheckboxState;
 }
 
 export class ResolvableTreeItem implements ITreeItem {
