@@ -259,8 +259,9 @@ export class CommentReply<T extends IRange | ICellRange> extends Disposable {
 			});
 
 			this.hideReplyArea();
-		}, this.themeService);
+		});
 
+		this._register(this._commentFormActions);
 		this._commentFormActions.setActions(menu);
 	}
 
