@@ -15,10 +15,11 @@ import { OverviewRulerLane } from 'vs/editor/common/model';
 import { MarkdownString } from 'vs/base/common/htmlContent';
 import { createTextModel } from 'vs/editor/test/common/testTextModel';
 import { createTestSession } from 'vs/workbench/contrib/debug/test/browser/callStack.test';
-import { createMockDebugModel, MockDebugService } from 'vs/workbench/contrib/debug/test/browser/mockDebug';
 import { TestInstantiationService } from 'vs/platform/instantiation/test/common/instantiationServiceMock';
 import { ILanguageService } from 'vs/editor/common/languages/language';
 import { LanguageService } from 'vs/editor/common/services/languageService';
+import { createMockDebugModel } from 'vs/workbench/contrib/debug/test/browser/mockDebugModel';
+import { MockDebugService } from 'vs/workbench/contrib/debug/test/common/mockDebug';
 
 function addBreakpointsAndCheckEvents(model: DebugModel, uri: uri, data: IBreakpointData[]): void {
 	let eventCount = 0;
@@ -99,10 +100,10 @@ suite('Debug - Breakpoints', () => {
 		const modelUri1 = uri.file('/myfolder/my file first.js');
 		const modelUri2 = uri.file('/secondfolder/second/second file.js');
 		addBreakpointsAndCheckEvents(model, modelUri1, [{ lineNumber: 5, enabled: true }, { lineNumber: 10, enabled: false }]);
-		assert.strictEqual(getExpandedBodySize(model, 9), 44);
+		assert.strictEqual(getExpandedBodySize(model, undefined, 9), 44);
 
 		addBreakpointsAndCheckEvents(model, modelUri2, [{ lineNumber: 1, enabled: true }, { lineNumber: 2, enabled: true }, { lineNumber: 3, enabled: false }]);
-		assert.strictEqual(getExpandedBodySize(model, 9), 110);
+		assert.strictEqual(getExpandedBodySize(model, undefined, 9), 110);
 
 		assert.strictEqual(model.getBreakpoints().length, 5);
 		assert.strictEqual(model.getBreakpoints({ uri: modelUri1 }).length, 2);
@@ -136,7 +137,7 @@ suite('Debug - Breakpoints', () => {
 		assert.strictEqual(bp.enabled, true);
 
 		model.removeBreakpoints(model.getBreakpoints({ uri: modelUri1 }));
-		assert.strictEqual(getExpandedBodySize(model, 9), 66);
+		assert.strictEqual(getExpandedBodySize(model, undefined, 9), 66);
 
 		assert.strictEqual(model.getBreakpoints().length, 3);
 	});
@@ -212,22 +213,75 @@ suite('Debug - Breakpoints', () => {
 	test('exception breakpoints', () => {
 		let eventCount = 0;
 		model.onDidChangeBreakpoints(() => eventCount++);
-		model.setExceptionBreakpoints([{ filter: 'uncaught', label: 'UNCAUGHT', default: true }]);
+		model.setExceptionBreakpointsForSession("session-id-1", [{ filter: 'uncaught', label: 'UNCAUGHT', default: true }]);
 		assert.strictEqual(eventCount, 1);
-		let exceptionBreakpoints = model.getExceptionBreakpoints();
+		let exceptionBreakpoints = model.getExceptionBreakpointsForSession("session-id-1");
 		assert.strictEqual(exceptionBreakpoints.length, 1);
 		assert.strictEqual(exceptionBreakpoints[0].filter, 'uncaught');
 		assert.strictEqual(exceptionBreakpoints[0].enabled, true);
 
-		model.setExceptionBreakpoints([{ filter: 'uncaught', label: 'UNCAUGHT' }, { filter: 'caught', label: 'CAUGHT' }]);
+		model.setExceptionBreakpointsForSession("session-id-2", [{ filter: 'uncaught', label: 'UNCAUGHT' }, { filter: 'caught', label: 'CAUGHT' }]);
 		assert.strictEqual(eventCount, 2);
-		exceptionBreakpoints = model.getExceptionBreakpoints();
+		exceptionBreakpoints = model.getExceptionBreakpointsForSession("session-id-2");
 		assert.strictEqual(exceptionBreakpoints.length, 2);
 		assert.strictEqual(exceptionBreakpoints[0].filter, 'uncaught');
 		assert.strictEqual(exceptionBreakpoints[0].enabled, true);
 		assert.strictEqual(exceptionBreakpoints[1].filter, 'caught');
 		assert.strictEqual(exceptionBreakpoints[1].label, 'CAUGHT');
 		assert.strictEqual(exceptionBreakpoints[1].enabled, false);
+
+		model.setExceptionBreakpointsForSession("session-id-3", [{ filter: 'all', label: 'ALL' }]);
+		assert.strictEqual(eventCount, 3);
+		assert.strictEqual(model.getExceptionBreakpointsForSession("session-id-3").length, 1);
+		exceptionBreakpoints = model.getExceptionBreakpoints();
+		assert.strictEqual(exceptionBreakpoints[0].filter, 'uncaught');
+		assert.strictEqual(exceptionBreakpoints[0].enabled, true);
+		assert.strictEqual(exceptionBreakpoints[1].filter, 'caught');
+		assert.strictEqual(exceptionBreakpoints[1].label, 'CAUGHT');
+		assert.strictEqual(exceptionBreakpoints[1].enabled, false);
+		assert.strictEqual(exceptionBreakpoints[2].filter, 'all');
+		assert.strictEqual(exceptionBreakpoints[2].label, 'ALL');
+	});
+
+	test('exception breakpoints multiple sessions', () => {
+		let eventCount = 0;
+		model.onDidChangeBreakpoints(() => eventCount++);
+
+		model.setExceptionBreakpointsForSession("session-id-4", [{ filter: 'uncaught', label: 'UNCAUGHT', default: true }, { filter: 'caught', label: 'CAUGHT' }]);
+		model.setExceptionBreakpointFallbackSession("session-id-4");
+		assert.strictEqual(eventCount, 1);
+		let exceptionBreakpointsForSession = model.getExceptionBreakpointsForSession("session-id-4");
+		assert.strictEqual(exceptionBreakpointsForSession.length, 2);
+		assert.strictEqual(exceptionBreakpointsForSession[0].filter, 'uncaught');
+		assert.strictEqual(exceptionBreakpointsForSession[1].filter, 'caught');
+
+		model.setExceptionBreakpointsForSession("session-id-5", [{ filter: 'all', label: 'ALL' }, { filter: 'caught', label: 'CAUGHT' }]);
+		assert.strictEqual(eventCount, 2);
+		exceptionBreakpointsForSession = model.getExceptionBreakpointsForSession("session-id-5");
+		let exceptionBreakpointsForUndefined = model.getExceptionBreakpointsForSession(undefined);
+		assert.strictEqual(exceptionBreakpointsForSession.length, 2);
+		assert.strictEqual(exceptionBreakpointsForSession[0].filter, 'caught');
+		assert.strictEqual(exceptionBreakpointsForSession[1].filter, 'all');
+		assert.strictEqual(exceptionBreakpointsForUndefined.length, 2);
+		assert.strictEqual(exceptionBreakpointsForUndefined[0].filter, 'uncaught');
+		assert.strictEqual(exceptionBreakpointsForUndefined[1].filter, 'caught');
+
+		model.removeExceptionBreakpointsForSession("session-id-4");
+		assert.strictEqual(eventCount, 2);
+		exceptionBreakpointsForUndefined = model.getExceptionBreakpointsForSession(undefined);
+		assert.strictEqual(exceptionBreakpointsForUndefined.length, 2);
+		assert.strictEqual(exceptionBreakpointsForUndefined[0].filter, 'uncaught');
+		assert.strictEqual(exceptionBreakpointsForUndefined[1].filter, 'caught');
+
+		model.setExceptionBreakpointFallbackSession("session-id-5");
+		assert.strictEqual(eventCount, 2);
+		exceptionBreakpointsForUndefined = model.getExceptionBreakpointsForSession(undefined);
+		assert.strictEqual(exceptionBreakpointsForUndefined.length, 2);
+		assert.strictEqual(exceptionBreakpointsForUndefined[0].filter, 'caught');
+		assert.strictEqual(exceptionBreakpointsForUndefined[1].filter, 'all');
+
+		const exceptionBreakpoints = model.getExceptionBreakpoints();
+		assert.strictEqual(exceptionBreakpoints.length, 3);
 	});
 
 	test('instruction breakpoints', () => {
