@@ -6,7 +6,7 @@
 import * as assert from 'assert';
 import { DebugModel, StackFrame, Thread } from 'vs/workbench/contrib/debug/common/debugModel';
 import * as sinon from 'sinon';
-import { MockRawSession, createMockDebugModel, mockUriIdentityService } from 'vs/workbench/contrib/debug/test/browser/mockDebug';
+import { createMockDebugModel, mockUriIdentityService } from 'vs/workbench/contrib/debug/test/browser/mockDebugModel';
 import { Source } from 'vs/workbench/contrib/debug/common/debugSource';
 import { DebugSession } from 'vs/workbench/contrib/debug/browser/debugSession';
 import { Range } from 'vs/editor/common/core/range';
@@ -20,6 +20,7 @@ import { debugStackframe, debugStackframeFocused } from 'vs/workbench/contrib/de
 import { ThemeIcon } from 'vs/platform/theme/common/themeService';
 import { TestConfigurationService } from 'vs/platform/configuration/test/common/testConfigurationService';
 import { TestInstantiationService } from 'vs/platform/instantiation/test/common/instantiationServiceMock';
+import { MockRawSession } from 'vs/workbench/contrib/debug/test/common/mockDebug';
 
 const mockWorkspaceContextService = {
 	getWorkspace: () => {
@@ -67,11 +68,11 @@ function createTwoStackFrames(session: DebugSession): { firstStackFrame: StackFr
 
 suite('Debug - CallStack', () => {
 	let model: DebugModel;
-	let rawSession: MockRawSession;
+	let mockRawSession: MockRawSession;
 
 	setup(() => {
 		model = createMockDebugModel();
-		rawSession = new MockRawSession();
+		mockRawSession = new MockRawSession();
 	});
 
 	// Threads
@@ -109,7 +110,7 @@ suite('Debug - CallStack', () => {
 		const session = createTestSession(model);
 		model.addSession(session);
 
-		session['raw'] = <any>rawSession;
+		session['raw'] = <any>mockRawSession;
 
 		model.rawUpdate({
 			sessionId: session.getId(),
@@ -189,7 +190,7 @@ suite('Debug - CallStack', () => {
 		const session = createTestSession(model);
 		model.addSession(session);
 
-		session['raw'] = <any>rawSession;
+		session['raw'] = <any>mockRawSession;
 
 		// Stopped event with all threads stopped
 		model.rawUpdate({
@@ -232,7 +233,7 @@ suite('Debug - CallStack', () => {
 	});
 
 	test('threads multiple without allThreadsStopped', async () => {
-		const sessionStub = sinon.spy(rawSession, 'stackTrace');
+		const sessionStub = sinon.spy(mockRawSession, 'stackTrace');
 
 		const stoppedThreadId = 1;
 		const stoppedThreadName = 'stoppedThread';
@@ -242,7 +243,7 @@ suite('Debug - CallStack', () => {
 		const session = createTestSession(model);
 		model.addSession(session);
 
-		session['raw'] = <any>rawSession;
+		session['raw'] = <any>mockRawSession;
 
 		// Add the threads
 		model.rawUpdate({
@@ -435,7 +436,7 @@ suite('Debug - CallStack', () => {
 		model.addSession(runningSession);
 		model.addSession(session);
 
-		session['raw'] = <any>rawSession;
+		session['raw'] = <any>mockRawSession;
 
 		model.rawUpdate({
 			sessionId: session.getId(),
