@@ -13,10 +13,11 @@ import { ILogService } from 'vs/platform/log/common/log';
 import { registerIcon } from 'vs/platform/theme/common/iconRegistry';
 import { IResourceRefHandle } from 'vs/platform/userDataSync/common/userDataSync';
 import { Event } from 'vs/base/common/event';
+import { StringSHA1 } from 'vs/base/common/hash';
 
 export const EDIT_SESSION_SYNC_CATEGORY: ILocalizedString = {
-	original: 'Edit Sessions',
-	value: localize('session sync', 'Edit Sessions')
+	original: 'Cloud Changes',
+	value: localize('cloud changes', 'Cloud Changes')
 };
 
 export const IEditSessionsStorageService = createDecorator<IEditSessionsStorageService>('IEditSessionsStorageService');
@@ -82,9 +83,9 @@ export const EDIT_SESSIONS_SIGNED_IN = new RawContextKey<boolean>(EDIT_SESSIONS_
 
 export const EDIT_SESSIONS_CONTAINER_ID = 'workbench.view.editSessions';
 export const EDIT_SESSIONS_DATA_VIEW_ID = 'workbench.views.editSessions.data';
-export const EDIT_SESSIONS_TITLE = localize('edit sessions', 'Edit Sessions');
+export const EDIT_SESSIONS_TITLE = localize('cloud changes', 'Cloud Changes');
 
-export const EDIT_SESSIONS_VIEW_ICON = registerIcon('edit-sessions-view-icon', Codicon.cloudDownload, localize('editSessionViewIcon', 'View icon of the edit sessions view.'));
+export const EDIT_SESSIONS_VIEW_ICON = registerIcon('edit-sessions-view-icon', Codicon.cloudDownload, localize('editSessionViewIcon', 'View icon of the cloud changes view.'));
 
 export const EDIT_SESSIONS_SHOW_VIEW = new RawContextKey<boolean>('editSessionsShowView', false);
 
@@ -100,3 +101,9 @@ export function decodeEditSessionFileContent(version: number, content: string):
 			throw new Error('Upgrade to a newer version to decode this content.');
 	}
 }
+
+export function hashedEditSessionId(editSessionId: string) {
+	const sha1 = new StringSHA1();
+	sha1.update(editSessionId);
+	return sha1.digest();
+}
