@@ -36,6 +36,10 @@ import { IViewDescriptorService } from 'vs/workbench/common/views';
 import { ITextModelService } from 'vs/editor/common/services/resolverService';
 import { ILifecycleService } from 'vs/workbench/services/lifecycle/common/lifecycle';
 import { IDialogService } from 'vs/platform/dialogs/common/dialogs';
+import { IEditorService, ISaveAllEditorsOptions } from 'vs/workbench/services/editor/common/editorService';
+import { CancellationTokenSource } from 'vs/base/common/cancellation';
+import { ITelemetryService } from 'vs/platform/telemetry/common/telemetry';
+import { NullTelemetryService } from 'vs/platform/telemetry/common/telemetryUtils';
 
 const folderName = 'test-folder';
 const folderUri = URI.file(`/${folderName}`);
@@ -73,6 +77,7 @@ suite('Edit session sync', () => {
 		instantiationService.stub(IProgressService, ProgressService);
 		instantiationService.stub(ISCMService, SCMService);
 		instantiationService.stub(IEnvironmentService, TestEnvironmentService);
+		instantiationService.stub(ITelemetryService, NullTelemetryService);
 		instantiationService.stub(IDialogService, new class extends mock<IDialogService>() {
 			override async show() {
 				return { choice: 1 };
@@ -109,6 +114,9 @@ suite('Edit session sync', () => {
 		instantiationService.stub(ITextModelService, new class extends mock<ITextModelService>() {
 			override registerTextModelContentProvider = () => ({ dispose: () => { } });
 		});
+		instantiationService.stub(IEditorService, new class extends mock<IEditorService>() {
+			override saveAll = async (_options: ISaveAllEditorsOptions) => true;
+		});
 
 		editSessionsContribution = instantiationService.createInstance(EditSessionsContribution);
 	});
@@ -164,7 +172,7 @@ suite('Edit session sync', () => {
 		// Create root folder
 		await fileService.createFolder(folderUri);
 
-		await editSessionsContribution.storeEditSession(true);
+		await editSessionsContribution.storeEditSession(true, new CancellationTokenSource().token);
 
 		// Verify that we did not attempt to write the edit session
 		assert.equal(writeStub.called, false);
