@@ -198,7 +198,7 @@ suite('ExtensionsViews Tests', () => {
 		await (<TestExtensionEnablementService>instantiationService.get(IWorkbenchExtensionEnablementService)).setEnablement([localDisabledLanguage], EnablementState.DisabledGlobally);
 
 		instantiationService.set(IExtensionsWorkbenchService, instantiationService.createInstance(ExtensionsWorkbenchService));
-		testableView = instantiationService.createInstance(ExtensionsListView, {}, {});
+		testableView = instantiationService.createInstance(ExtensionsListView, {}, { id: '', title: '' });
 	});
 
 	teardown(() => {
@@ -540,7 +540,7 @@ suite('ExtensionsViews Tests', () => {
 
 		testableView.resetSearchExperiments();
 		testableView.dispose();
-		testableView = instantiationService.createInstance(ExtensionsListView, {}, {});
+		testableView = instantiationService.createInstance(ExtensionsListView, {}, { id: '', title: '' });
 
 		return testableView.show('search-me').then(result => {
 			const options: IQueryOptions = queryTarget.args[0][0];
@@ -567,7 +567,7 @@ suite('ExtensionsViews Tests', () => {
 		const queryTarget = <SinonStub>instantiationService.stubPromise(IExtensionGalleryService, 'query', aPage(...realResults));
 
 		testableView.dispose();
-		testableView = instantiationService.createInstance(ExtensionsListView, {}, {});
+		testableView = instantiationService.createInstance(ExtensionsListView, {}, { id: '', title: '' });
 
 		return testableView.show('search-me @sort:installs').then(result => {
 			const options: IQueryOptions = queryTarget.args[0][0];
