@@ -330,7 +330,7 @@ CommandsRegistry.registerCommand({
 			const explorerView = viewlet.getExplorerView();
 			if (explorerView) {
 				explorerView.setExpanded(true);
-				await explorerService.select(uri, true);
+				await explorerService.select(uri, 'force');
 				explorerView.focus();
 			}
 		} else {
@@ -655,7 +655,7 @@ KeybindingsRegistry.registerCommandAndKeybindingRule({
 		args: [
 			{
 				isOptional: true,
-				name: 'New Untitled File args',
+				name: 'New Untitled Text File args',
 				description: 'The editor view type, language ID, or resource path if known',
 				schema: {
 					'type': 'object',
