@@ -3,25 +3,26 @@
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
 
-import { h, reset } from 'vs/base/browser/dom';
+import { h } from 'vs/base/browser/dom';
 import { IView, IViewSize } from 'vs/base/browser/ui/grid/grid';
-import { renderLabelWithIcons } from 'vs/base/browser/ui/iconLabel/iconLabels';
 import { Emitter, Event } from 'vs/base/common/event';
-import { Disposable } from 'vs/base/common/lifecycle';
-import { IObservable, observableFromEvent, observableValue, transaction } from 'vs/base/common/observable';
+import { Disposable, IDisposable } from 'vs/base/common/lifecycle';
+import { autorun, derived, IObservable, observableFromEvent } from 'vs/base/common/observable';
 import { IEditorContributionDescription } from 'vs/editor/browser/editorExtensions';
 import { CodeEditorWidget } from 'vs/editor/browser/widget/codeEditorWidget';
 import { IEditorOptions } from 'vs/editor/common/config/editorOptions';
+import { Range } from 'vs/editor/common/core/range';
+import { Selection } from 'vs/editor/common/core/selection';
+import { MenuWorkbenchToolBar } from 'vs/platform/actions/browser/toolbar';
+import { MenuId } from 'vs/platform/actions/common/actions';
+import { IConfigurationService } from 'vs/platform/configuration/common/configuration';
 import { IInstantiationService } from 'vs/platform/instantiation/common/instantiation';
 import { DEFAULT_EDITOR_MAX_DIMENSIONS, DEFAULT_EDITOR_MIN_DIMENSIONS } from 'vs/workbench/browser/parts/editor/editor';
-import { InputData } from 'vs/workbench/contrib/mergeEditor/browser/model/mergeEditorModel';
 import { setStyle } from 'vs/workbench/contrib/mergeEditor/browser/utils';
 import { MergeEditorViewModel } from 'vs/workbench/contrib/mergeEditor/browser/view/viewModel';
 
 export abstract class CodeEditorView extends Disposable {
-	private readonly _viewModel = observableValue<undefined | MergeEditorViewModel>('viewModel', undefined);
-	readonly viewModel: IObservable<undefined | MergeEditorViewModel> = this._viewModel;
-	readonly model = this._viewModel.map(m => /** @description model */ m?.model);
+	readonly model = this.viewModel.map(m => /** @description model */ m?.model);
 
 	protected readonly htmlElements = h('div.code-view', [
 		h('div.title@header', [
@@ -58,6 +59,21 @@ export abstract class CodeEditorView extends Disposable {
 		// snap?: boolean | undefined;
 	};
 
+	protected readonly checkboxesVisible = observableFromEvent<boolean>(
+		this.configurationService.onDidChangeConfiguration,
+		() => /** @description checkboxesVisible */ this.configurationService.getValue('mergeEditor.showCheckboxes') ?? false
+	);
+
+	protected readonly showDeletionMarkers = observableFromEvent<boolean>(
+		this.configurationService.onDidChangeConfiguration,
+		() => /** @description showDeletionMarkers */ this.configurationService.getValue('mergeEditor.showDeletionMarkers') ?? true
+	);
+
+	protected readonly useSimplifiedDecorations = observableFromEvent<boolean>(
+		this.configurationService.onDidChangeConfiguration,
+		() => /** @description useSimplifiedDecorations */ this.configurationService.getValue('mergeEditor.useSimplifiedDecorations') ?? false
+	);
+
 	public readonly editor = this.instantiationService.createInstance(
 		CodeEditorWidget,
 		this.htmlElements.editor,
@@ -81,32 +97,64 @@ export abstract class CodeEditorView extends Disposable {
 		() => /** @description editor.getPosition */ this.editor.getPosition()
 	);
 
+	public readonly selection = observableFromEvent(
+		this.editor.onDidChangeCursorSelection,
+		() => /** @description editor.getSelections */ this.editor.getSelections()
+	);
+
 	public readonly cursorLineNumber = this.cursorPosition.map(p => /** @description cursorPosition.lineNumber */ p?.lineNumber);
 
 	constructor(
-		@IInstantiationService
-		private readonly instantiationService: IInstantiationService
+		private readonly instantiationService: IInstantiationService,
+		public readonly viewModel: IObservable<undefined | MergeEditorViewModel>,
+		private readonly configurationService: IConfigurationService,
 	) {
 		super();
+
 	}
 
 	protected getEditorContributions(): IEditorContributionDescription[] | undefined {
 		return undefined;
 	}
+}
 
-	public setModel(
-		viewModel: MergeEditorViewModel,
-		inputData: InputData
-	): void {
-		this.editor.setModel(inputData.textModel);
+export function createSelectionsAutorun(
+	codeEditorView: CodeEditorView,
+	translateRange: (baseRange: Range, viewModel: MergeEditorViewModel) => Range
+): IDisposable {
+	const selections = derived('selections', reader => {
+		const viewModel = codeEditorView.viewModel.read(reader);
+		if (!viewModel) {
+			return [];
+		}
+		const baseRange = viewModel.selectionInBase.read(reader);
+		if (!baseRange || baseRange.sourceEditor === codeEditorView) {
+			return [];
+		}
+		return baseRange.rangesInBase.map(r => translateRange(r, viewModel));
+	});
 
-		reset(this.htmlElements.title, ...renderLabelWithIcons(inputData.title || ''));
-		reset(this.htmlElements.description, ...(inputData.description ? renderLabelWithIcons(inputData.description) : []));
-		reset(this.htmlElements.detail, ...(inputData.detail ? renderLabelWithIcons(inputData.detail) : []));
+	return autorun('set selections', (reader) => {
+		const ranges = selections.read(reader);
+		if (ranges.length === 0) {
+			return;
+		}
+		codeEditorView.editor.setSelections(ranges.map(r => new Selection(r.startLineNumber, r.startColumn, r.endLineNumber, r.endColumn)));
+	});
+}
 
-		transaction(tx => {
-			/** @description CodeEditorView: Set Model */
-			this._viewModel.set(viewModel, tx);
+export class TitleMenu extends Disposable {
+	constructor(
+		menuId: MenuId,
+		targetHtmlElement: HTMLElement,
+		@IInstantiationService instantiationService: IInstantiationService,
+	) {
+		super();
+
+		const toolbar = instantiationService.createInstance(MenuWorkbenchToolBar, targetHtmlElement, menuId, {
+			menuOptions: { renderShortTitle: true },
+			toolbarOptions: { primaryGroup: () => false }
 		});
+		this._store.add(toolbar);
 	}
 }
