@@ -3,32 +3,30 @@
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
 
-import { $, Dimension, reset } from 'vs/base/browser/dom';
-import { Direction, Grid, IView, SerializableGrid } from 'vs/base/browser/ui/grid/grid';
-import { Orientation, Sizing } from 'vs/base/browser/ui/splitview/splitview';
+import { Dimension, reset } from 'vs/base/browser/dom';
+import { Grid, GridNodeDescriptor, IView, SerializableGrid } from 'vs/base/browser/ui/grid/grid';
+import { Orientation } from 'vs/base/browser/ui/splitview/splitview';
 import { CancellationToken } from 'vs/base/common/cancellation';
 import { Color } from 'vs/base/common/color';
-import { BugIndicatingError } from 'vs/base/common/errors';
+import { BugIndicatingError, onUnexpectedError } from 'vs/base/common/errors';
 import { Emitter, Event } from 'vs/base/common/event';
-import { Disposable, DisposableStore, toDisposable } from 'vs/base/common/lifecycle';
-import { autorunWithStore, IObservable } from 'vs/base/common/observable';
+import { Disposable, DisposableStore, IDisposable, MutableDisposable, toDisposable } from 'vs/base/common/lifecycle';
+import { autorun, autorunWithStore, IObservable, IReader, observableFromEvent, observableValue, transaction } from 'vs/base/common/observable';
 import { basename, isEqual } from 'vs/base/common/resources';
+import { isDefined } from 'vs/base/common/types';
 import { URI } from 'vs/base/common/uri';
 import 'vs/css!./media/mergeEditor';
-import { ICodeEditor } from 'vs/editor/browser/editorBrowser';
+import { ICodeEditor, IViewZoneChangeAccessor } from 'vs/editor/browser/editorBrowser';
 import { ICodeEditorService } from 'vs/editor/browser/services/codeEditorService';
-import { CodeEditorWidget } from 'vs/editor/browser/widget/codeEditorWidget';
 import { IEditorOptions as ICodeEditorOptions } from 'vs/editor/common/config/editorOptions';
 import { ICodeEditorViewState, ScrollType } from 'vs/editor/common/editorCommon';
 import { ITextResourceConfigurationService } from 'vs/editor/common/services/textResourceConfiguration';
 import { localize } from 'vs/nls';
-import { MenuId } from 'vs/platform/actions/common/actions';
 import { IConfigurationService } from 'vs/platform/configuration/common/configuration';
 import { IContextKey, IContextKeyService } from 'vs/platform/contextkey/common/contextkey';
 import { IEditorOptions, ITextEditorOptions, ITextResourceEditorInput } from 'vs/platform/editor/common/editor';
 import { IFileService } from 'vs/platform/files/common/files';
 import { IInstantiationService } from 'vs/platform/instantiation/common/instantiation';
-import { ILabelService } from 'vs/platform/label/common/label';
 import { IStorageService, StorageScope, StorageTarget } from 'vs/platform/storage/common/storage';
 import { ITelemetryService } from 'vs/platform/telemetry/common/telemetry';
 import { IThemeService } from 'vs/platform/theme/common/themeService';
@@ -38,11 +36,14 @@ import { EditorInput } from 'vs/workbench/common/editor/editorInput';
 import { applyTextEditorOptions } from 'vs/workbench/common/editor/editorOptions';
 import { readTransientState, writeTransientState } from 'vs/workbench/contrib/codeEditor/browser/toggleWordWrap';
 import { MergeEditorInput } from 'vs/workbench/contrib/mergeEditor/browser/mergeEditorInput';
-import { DocumentMapping, getOppositeDirection, MappingDirection } from 'vs/workbench/contrib/mergeEditor/browser/model/mapping';
+import { IMergeEditorInputModel } from 'vs/workbench/contrib/mergeEditor/browser/mergeEditorInputModel';
 import { MergeEditorModel } from 'vs/workbench/contrib/mergeEditor/browser/model/mergeEditorModel';
-import { deepMerge, ReentrancyBarrier, thenIfNotDisposed } from 'vs/workbench/contrib/mergeEditor/browser/utils';
+import { deepMerge, PersistentStore, thenIfNotDisposed } from 'vs/workbench/contrib/mergeEditor/browser/utils';
+import { BaseCodeEditorView } from 'vs/workbench/contrib/mergeEditor/browser/view/editors/baseCodeEditorView';
+import { ScrollSynchronizer } from 'vs/workbench/contrib/mergeEditor/browser/view/scrollSynchronizer';
 import { MergeEditorViewModel } from 'vs/workbench/contrib/mergeEditor/browser/view/viewModel';
-import { ctxMergeBaseUri, ctxIsMergeEditor, ctxMergeEditorLayout, ctxMergeResultUri, MergeEditorLayoutTypes } from 'vs/workbench/contrib/mergeEditor/common/mergeEditor';
+import { ViewZoneComputer } from 'vs/workbench/contrib/mergeEditor/browser/view/viewZones';
+import { ctxIsMergeEditor, ctxMergeBaseUri, ctxMergeEditorLayout, ctxMergeEditorShowBase, ctxMergeEditorShowBaseAtTop, ctxMergeEditorShowNonConflictingChanges, ctxMergeResultUri, MergeEditorLayoutKind } from 'vs/workbench/contrib/mergeEditor/common/mergeEditor';
 import { settingsSashBorder } from 'vs/workbench/contrib/preferences/common/settingsEditorColorRegistry';
 import { IEditorGroup, IEditorGroupsService } from 'vs/workbench/services/editor/common/editorGroupsService';
 import { IEditorResolverService, MergeEditorInputFactoryFunction, RegisteredEditorPriority } from 'vs/workbench/services/editor/common/editorResolverService';
@@ -51,61 +52,62 @@ import './colors';
 import { InputCodeEditorView } from './editors/inputCodeEditorView';
 import { ResultCodeEditorView } from './editors/resultCodeEditorView';
 
-class MergeEditorLayout {
-
-	private static readonly _key = 'mergeEditor/layout';
-	private _value: MergeEditorLayoutTypes = 'mixed';
-
-
-	constructor(@IStorageService private _storageService: IStorageService) {
-		const value = _storageService.get(MergeEditorLayout._key, StorageScope.PROFILE, 'mixed');
-		if (value === 'mixed' || value === 'columns') {
-			this._value = value;
-		} else {
-			this._value = 'mixed';
-		}
-	}
-
-	get value() {
-		return this._value;
-	}
-
-	set value(value) {
-		if (this._value !== value) {
-			this._value = value;
-			this._storageService.store(MergeEditorLayout._key, this._value, StorageScope.PROFILE, StorageTarget.USER);
-		}
-	}
-}
-
 export class MergeEditor extends AbstractTextEditor<IMergeEditorViewState> {
 
 	static readonly ID = 'mergeEditor';
 
 	private readonly _sessionDisposables = new DisposableStore();
+	private readonly _viewModel = observableValue<MergeEditorViewModel | undefined>('viewModel', undefined);
 
-	private _grid!: Grid<IView>;
-	private readonly input1View = this._register(this.instantiationService.createInstance(InputCodeEditorView, 1, MenuId.MergeInput1Toolbar));
-	private readonly input2View = this._register(this.instantiationService.createInstance(InputCodeEditorView, 2, MenuId.MergeInput2Toolbar));
-	private readonly inputResultView = this._register(this.instantiationService.createInstance(ResultCodeEditorView));
+	public get viewModel(): IObservable<MergeEditorViewModel | undefined> {
+		return this._viewModel;
+	}
 
-	private readonly _layoutMode: MergeEditorLayout;
-	private readonly _ctxIsMergeEditor: IContextKey<boolean>;
-	private readonly _ctxUsesColumnLayout: IContextKey<string>;
-	private readonly _ctxResultUri: IContextKey<string>;
-	private readonly _ctxBaseUri: IContextKey<string>;
+	private rootHtmlElement: HTMLElement | undefined;
+	private readonly _grid = this._register(new MutableDisposable<Grid<IView>>());
+	private readonly input1View = this._register(this.instantiationService.createInstance(InputCodeEditorView, 1, this._viewModel));
+	private readonly baseView = observableValue<BaseCodeEditorView | undefined>('baseView', undefined);
+	private readonly baseViewOptions = observableValue<Readonly<ICodeEditorOptions> | undefined>('baseViewOptions', undefined);
+	private readonly input2View = this._register(this.instantiationService.createInstance(InputCodeEditorView, 2, this._viewModel));
 
-	private _model: MergeEditorModel | undefined;
-	public get model(): MergeEditorModel | undefined { return this._model; }
+	private readonly inputResultView = this._register(this.instantiationService.createInstance(ResultCodeEditorView, this._viewModel));
+	private readonly _layoutMode = this.instantiationService.createInstance(MergeEditorLayoutStore);
+	private readonly _layoutModeObs = observableValue('layoutMode', this._layoutMode.value);
+	private readonly _ctxIsMergeEditor: IContextKey<boolean> = ctxIsMergeEditor.bindTo(this.contextKeyService);
+	private readonly _ctxUsesColumnLayout: IContextKey<string> = ctxMergeEditorLayout.bindTo(this.contextKeyService);
+	private readonly _ctxShowBase: IContextKey<boolean> = ctxMergeEditorShowBase.bindTo(this.contextKeyService);
+	private readonly _ctxShowBaseAtTop = ctxMergeEditorShowBaseAtTop.bindTo(this.contextKeyService);
+	private readonly _ctxResultUri: IContextKey<string> = ctxMergeResultUri.bindTo(this.contextKeyService);
+	private readonly _ctxBaseUri: IContextKey<string> = ctxMergeBaseUri.bindTo(this.contextKeyService);
+	private readonly _ctxShowNonConflictingChanges: IContextKey<boolean> = ctxMergeEditorShowNonConflictingChanges.bindTo(this.contextKeyService);
+	private readonly _inputModel = observableValue<IMergeEditorInputModel | undefined>('inputModel', undefined);
+	public get inputModel(): IObservable<IMergeEditorInputModel | undefined> {
+		return this._inputModel;
+	}
+	public get model(): MergeEditorModel | undefined {
+		return this.inputModel.get()?.model;
+	}
 
 	private get inputsWritable(): boolean {
 		return !!this._configurationService.getValue<boolean>('mergeEditor.writableInputs');
 	}
 
+	private readonly viewZoneComputer = new ViewZoneComputer(
+		this.input1View.editor,
+		this.input2View.editor,
+		this.inputResultView.editor,
+	);
+
+	protected readonly codeLensesVisible = observableFromEvent<boolean>(
+		this.configurationService.onDidChangeConfiguration,
+		() => /** @description codeLensesVisible */ this.configurationService.getValue('mergeEditor.showCodeLenses') ?? true
+	);
+
+	private readonly scrollSynchronizer = this._register(new ScrollSynchronizer(this._viewModel, this.input1View, this.input2View, this.baseView, this.inputResultView, this._layoutModeObs));
+
 	constructor(
 		@IInstantiationService instantiation: IInstantiationService,
-		@ILabelService private readonly _labelService: ILabelService,
-		@IContextKeyService contextKeyService: IContextKeyService,
+		@IContextKeyService private readonly contextKeyService: IContextKeyService,
 		@ITelemetryService telemetryService: ITelemetryService,
 		@IStorageService storageService: IStorageService,
 		@IThemeService themeService: IThemeService,
@@ -115,94 +117,31 @@ export class MergeEditor extends AbstractTextEditor<IMergeEditorViewState> {
 		@IEditorGroupsService editorGroupService: IEditorGroupsService,
 		@IFileService fileService: IFileService,
 		@ICodeEditorService private readonly _codeEditorService: ICodeEditorService,
+		@IConfigurationService private readonly configurationService: IConfigurationService
 	) {
 		super(MergeEditor.ID, telemetryService, instantiation, storageService, textResourceConfigurationService, themeService, editorService, editorGroupService, fileService);
-
-		this._ctxIsMergeEditor = ctxIsMergeEditor.bindTo(contextKeyService);
-		this._ctxUsesColumnLayout = ctxMergeEditorLayout.bindTo(contextKeyService);
-		this._ctxBaseUri = ctxMergeBaseUri.bindTo(contextKeyService);
-		this._ctxResultUri = ctxMergeResultUri.bindTo(contextKeyService);
-
-		this._layoutMode = instantiation.createInstance(MergeEditorLayout);
-		this._ctxUsesColumnLayout.set(this._layoutMode.value);
-
-		const reentrancyBarrier = new ReentrancyBarrier();
-
-		this._store.add(
-			this.input1View.editor.onDidScrollChange(
-				reentrancyBarrier.makeExclusive((c) => {
-					if (c.scrollTopChanged) {
-						const mapping = this.model?.input1ResultMapping.get();
-						synchronizeScrolling(this.input1View.editor, this.inputResultView.editor, mapping, MappingDirection.input);
-						this.input2View.editor.setScrollTop(c.scrollTop, ScrollType.Immediate);
-					}
-					if (c.scrollLeftChanged) {
-						this.input2View.editor.setScrollLeft(c.scrollLeft, ScrollType.Immediate);
-						this.inputResultView.editor.setScrollLeft(c.scrollLeft, ScrollType.Immediate);
-					}
-				})
-			)
-		);
-		this._store.add(
-			this.input2View.editor.onDidScrollChange(
-				reentrancyBarrier.makeExclusive((c) => {
-					if (c.scrollTopChanged) {
-						const mapping = this.model?.input2ResultMapping.get();
-						synchronizeScrolling(this.input2View.editor, this.inputResultView.editor, mapping, MappingDirection.input);
-						this.input1View.editor.setScrollTop(c.scrollTop, ScrollType.Immediate);
-					}
-					if (c.scrollLeftChanged) {
-						this.input1View.editor.setScrollLeft(c.scrollLeft, ScrollType.Immediate);
-						this.inputResultView.editor.setScrollLeft(c.scrollLeft, ScrollType.Immediate);
-					}
-				})
-			)
-		);
-		this._store.add(
-			this.inputResultView.editor.onDidScrollChange(
-				reentrancyBarrier.makeExclusive((c) => {
-					this.updateResultScrolling(c.scrollTopChanged, c.scrollLeftChanged);
-				})
-			)
-		);
-	}
-
-	private updateResultScrolling(scrollTopChanged: boolean, scrollLeftChanged: boolean): void {
-		if (scrollTopChanged) {
-			const mapping1 = this.model?.input1ResultMapping.get();
-			synchronizeScrolling(this.inputResultView.editor, this.input1View.editor, mapping1, MappingDirection.output);
-			const mapping2 = this.model?.input2ResultMapping.get();
-			synchronizeScrolling(this.inputResultView.editor, this.input2View.editor, mapping2, MappingDirection.output);
-		}
-		if (scrollLeftChanged) {
-			this.input1View.editor.setScrollLeft(this.inputResultView.editor.getScrollLeft(), ScrollType.Immediate);
-			this.input2View.editor.setScrollLeft(this.inputResultView.editor.getScrollLeft(), ScrollType.Immediate);
-		}
-	}
-
-	public get viewModel(): IObservable<MergeEditorViewModel | undefined> {
-		return this.input1View.viewModel;
 	}
 
 	override dispose(): void {
 		this._sessionDisposables.dispose();
 		this._ctxIsMergeEditor.reset();
 		this._ctxUsesColumnLayout.reset();
+		this._ctxShowNonConflictingChanges.reset();
 		super.dispose();
 	}
 
-	// --- layout constraints
+	// #region layout constraints
 
 	private readonly _onDidChangeSizeConstraints = new Emitter<void>();
 	override readonly onDidChangeSizeConstraints: Event<void> = this._onDidChangeSizeConstraints.event;
 
 	override get minimumWidth() {
-		return this._layoutMode.value === 'mixed'
-			? this.input1View.view.minimumWidth + this.input1View.view.minimumWidth
-			: this.input1View.view.minimumWidth + this.input1View.view.minimumWidth + this.inputResultView.view.minimumWidth;
+		return this._layoutMode.value.kind === 'mixed'
+			? this.input1View.view.minimumWidth + this.input2View.view.minimumWidth
+			: this.input1View.view.minimumWidth + this.input2View.view.minimumWidth + this.inputResultView.view.minimumWidth;
 	}
 
-	// ---
+	// #endregion
 
 	override getTitle(): string {
 		if (this.input) {
@@ -213,37 +152,9 @@ export class MergeEditor extends AbstractTextEditor<IMergeEditorViewState> {
 	}
 
 	protected createEditorControl(parent: HTMLElement, initialOptions: ICodeEditorOptions): void {
+		this.rootHtmlElement = parent;
 		parent.classList.add('merge-editor');
-
-		this._grid = SerializableGrid.from<any /*TODO@jrieken*/>({
-			orientation: Orientation.VERTICAL,
-			size: 100,
-			groups: [
-				{
-					size: 38,
-					groups: [{
-						data: this.input1View.view
-					}, {
-						data: this.input2View.view
-					}]
-				},
-				{
-					size: 62,
-					data: this.inputResultView.view
-				},
-			]
-		}, {
-			styles: { separatorBorder: this.theme.getColor(settingsSashBorder) ?? Color.transparent },
-			proportionalLayout: true
-		});
-
-		reset(parent, this._grid.element);
-		this._register(this._grid);
-
-		if (this._layoutMode.value === 'columns') {
-			this._grid.moveView(this.inputResultView.view, Sizing.Distribute, this.input1View.view, Direction.Right);
-		}
-
+		this.applyLayout(this._layoutMode.value);
 		this.applyOptions(initialOptions);
 	}
 
@@ -261,6 +172,7 @@ export class MergeEditor extends AbstractTextEditor<IMergeEditorViewState> {
 
 		this.input1View.updateOptions(inputOptions);
 		this.input2View.updateOptions(inputOptions);
+		this.baseViewOptions.set(this.input2View.editor.getRawOptions(), undefined);
 		this.inputResultView.updateOptions(options);
 	}
 
@@ -269,7 +181,7 @@ export class MergeEditor extends AbstractTextEditor<IMergeEditorViewState> {
 	}
 
 	layout(dimension: Dimension): void {
-		this._grid.layout(dimension.width, dimension.height);
+		this._grid.value?.layout(dimension.width, dimension.height);
 	}
 
 	override async setInput(input: EditorInput, options: IEditorOptions | undefined, context: IEditorOpenContext, token: CancellationToken): Promise<void> {
@@ -279,31 +191,98 @@ export class MergeEditor extends AbstractTextEditor<IMergeEditorViewState> {
 		await super.setInput(input, options, context, token);
 
 		this._sessionDisposables.clear();
+		transaction(tx => {
+			this._viewModel.set(undefined, tx);
+			this._inputModel.set(undefined, tx);
+		});
 
-		const model = await input.resolve();
-		this._model = model;
+		const inputModel = await input.resolve();
+		const model = inputModel.model;
 
-		const viewModel = new MergeEditorViewModel(model, this.input1View, this.input2View, this.inputResultView);
-
-		this.input1View.setModel(viewModel, { ...model.input1, title: model.input1.title || localize('input1', 'Input 1') });
-		this.input2View.setModel(viewModel, { ...model.input2, title: model.input2.title || localize('input2', 'Input 2') });
-		this.inputResultView.setModel(viewModel,
-			{
-				textModel: model.resultTextModel,
-				title: localize('result', 'Result'),
-				description: this._labelService.getUriLabel(model.resultTextModel.uri, { relative: true }),
-				detail: undefined,
-			},
+		const viewModel = this.instantiationService.createInstance(
+			MergeEditorViewModel,
+			model,
+			this.input1View,
+			this.input2View,
+			this.inputResultView,
+			this.baseView,
+			this.showNonConflictingChanges,
 		);
 
+
+		model.telemetry.reportMergeEditorOpened({
+			combinableConflictCount: model.combinableConflictCount,
+			conflictCount: model.conflictCount,
+
+			baseTop: this._layoutModeObs.get().showBaseAtTop,
+			baseVisible: this._layoutModeObs.get().showBase,
+			isColumnView: this._layoutModeObs.get().kind === 'columns',
+		});
+
+		transaction(tx => {
+			this._viewModel.set(viewModel, tx);
+			this._inputModel.set(inputModel, tx);
+		});
+		this._sessionDisposables.add(viewModel);
+
 		// Set/unset context keys based on input
-		this._ctxResultUri.set(model.resultTextModel.uri.toString());
+		this._ctxResultUri.set(inputModel.resultUri.toString());
 		this._ctxBaseUri.set(model.base.uri.toString());
 		this._sessionDisposables.add(toDisposable(() => {
 			this._ctxBaseUri.reset();
 			this._ctxResultUri.reset();
 		}));
 
+		// Set the view zones before restoring view state!
+		// Otherwise scrolling will be off
+		this._sessionDisposables.add(autorunWithStore((reader, store) => {
+			const baseView = this.baseView.read(reader);
+
+			this.inputResultView.editor.changeViewZones(resultViewZoneAccessor => {
+				const layout = this._layoutModeObs.read(reader);
+				const shouldAlignResult = layout.kind === 'columns';
+				const shouldAlignBase = layout.kind === 'mixed' && !layout.showBaseAtTop;
+
+				this.input1View.editor.changeViewZones(input1ViewZoneAccessor => {
+					this.input2View.editor.changeViewZones(input2ViewZoneAccessor => {
+						if (baseView) {
+							baseView.editor.changeViewZones(baseViewZoneAccessor => {
+								store.add(this.setViewZones(reader,
+									viewModel,
+									this.input1View.editor,
+									input1ViewZoneAccessor,
+									this.input2View.editor,
+									input2ViewZoneAccessor,
+									baseView.editor,
+									baseViewZoneAccessor,
+									shouldAlignBase,
+									this.inputResultView.editor,
+									resultViewZoneAccessor,
+									shouldAlignResult
+								));
+							});
+						} else {
+							store.add(this.setViewZones(reader,
+								viewModel,
+								this.input1View.editor,
+								input1ViewZoneAccessor,
+								this.input2View.editor,
+								input2ViewZoneAccessor,
+								undefined,
+								undefined,
+								false,
+								this.inputResultView.editor,
+								resultViewZoneAccessor,
+								shouldAlignResult
+							));
+						}
+					});
+				});
+			});
+
+			this.scrollSynchronizer.updateScrolling();
+		}, 'update alignment view zones'));
+
 		const viewState = this.loadEditorViewState(input, context);
 		if (viewState) {
 			this._applyViewState(viewState);
@@ -314,49 +293,13 @@ export class MergeEditor extends AbstractTextEditor<IMergeEditorViewState> {
 					return;
 				}
 				this.input1View.editor.revealLineInCenter(firstConflict.input1Range.startLineNumber);
+				transaction(tx => {
+					/** @description setActiveModifiedBaseRange */
+					viewModel.setActiveModifiedBaseRange(firstConflict, tx);
+				});
 			}));
 		}
 
-
-		this._sessionDisposables.add(autorunWithStore((reader, store) => {
-			const input1ViewZoneIds: string[] = [];
-			const input2ViewZoneIds: string[] = [];
-			this.input1View.editor.changeViewZones(a1 => {
-				this.input2View.editor.changeViewZones(a2 => {
-					for (const m of model.modifiedBaseRanges.read(reader)) {
-						const max = Math.max(m.input1Range.lineCount, m.input2Range.lineCount, 1);
-
-						input1ViewZoneIds.push(a1.addZone({
-							afterLineNumber: m.input1Range.endLineNumberExclusive - 1,
-							heightInLines: max - m.input1Range.lineCount,
-							domNode: $('div.diagonal-fill'),
-						}));
-
-						input2ViewZoneIds.push(a2.addZone({
-							afterLineNumber: m.input2Range.endLineNumberExclusive - 1,
-							heightInLines: max - m.input2Range.lineCount,
-							domNode: $('div.diagonal-fill'),
-						}));
-					}
-				});
-			});
-
-			store.add({
-				dispose: () => {
-					this.input1View.editor.changeViewZones(a => {
-						for (const zone of input1ViewZoneIds) {
-							a.removeZone(zone);
-						}
-					});
-					this.input2View.editor.changeViewZones(a => {
-						for (const zone of input2ViewZoneIds) {
-							a.removeZone(zone);
-						}
-					});
-				}
-			});
-		}, 'update alignment view zones'));
-
 		// word wrap special case - sync transient state from result model to input[1|2] models
 		const mirrorWordWrapTransientState = () => {
 			const state = readTransientState(model.resultTextModel, this._codeEditorService);
@@ -370,8 +313,6 @@ export class MergeEditor extends AbstractTextEditor<IMergeEditorViewState> {
 		}));
 		mirrorWordWrapTransientState();
 
-		this.updateResultScrolling(true, true);
-
 		// detect when base, input1, and input2 become empty and replace THIS editor with its result editor
 		// TODO@jrieken@hediet this needs a better/cleaner solution
 		// https://github.com/microsoft/vscode/issues/155940
@@ -404,13 +345,87 @@ export class MergeEditor extends AbstractTextEditor<IMergeEditorViewState> {
 				}
 				// all empty -> replace this editor with a normal editor for result
 				that.editorService.replaceEditors(
-					[{ editor: input, replacement: { resource: input.result }, forceReplaceDirty: true }],
+					[{ editor: input, replacement: { resource: input.result, options: { preserveFocus: true } }, forceReplaceDirty: true }],
 					that.group ?? that.editorGroupService.activeGroup
 				);
 			}
 		});
 	}
 
+	private setViewZones(
+		reader: IReader,
+		viewModel: MergeEditorViewModel,
+		input1Editor: ICodeEditor,
+		input1ViewZoneAccessor: IViewZoneChangeAccessor,
+		input2Editor: ICodeEditor,
+		input2ViewZoneAccessor: IViewZoneChangeAccessor,
+		baseEditor: ICodeEditor | undefined,
+		baseViewZoneAccessor: IViewZoneChangeAccessor | undefined,
+		shouldAlignBase: boolean,
+		resultEditor: ICodeEditor,
+		resultViewZoneAccessor: IViewZoneChangeAccessor,
+		shouldAlignResult: boolean,
+	): IDisposable {
+		const input1ViewZoneIds: string[] = [];
+		const input2ViewZoneIds: string[] = [];
+		const baseViewZoneIds: string[] = [];
+		const resultViewZoneIds: string[] = [];
+
+		const viewZones = this.viewZoneComputer.computeViewZones(reader, viewModel, {
+			codeLensesVisible: this.codeLensesVisible.read(reader),
+			showNonConflictingChanges: this.showNonConflictingChanges.read(reader),
+			shouldAlignBase,
+			shouldAlignResult,
+		});
+
+		const disposableStore = new DisposableStore();
+
+		if (baseViewZoneAccessor) {
+			for (const v of viewZones.baseViewZones) {
+				v.create(baseViewZoneAccessor, baseViewZoneIds, disposableStore);
+			}
+		}
+
+		for (const v of viewZones.resultViewZones) {
+			v.create(resultViewZoneAccessor, resultViewZoneIds, disposableStore);
+		}
+
+		for (const v of viewZones.input1ViewZones) {
+			v.create(input1ViewZoneAccessor, input1ViewZoneIds, disposableStore);
+		}
+
+		for (const v of viewZones.input2ViewZones) {
+			v.create(input2ViewZoneAccessor, input2ViewZoneIds, disposableStore);
+		}
+
+		disposableStore.add({
+			dispose: () => {
+				input1Editor.changeViewZones(a => {
+					for (const zone of input1ViewZoneIds) {
+						a.removeZone(zone);
+					}
+				});
+				input2Editor.changeViewZones(a => {
+					for (const zone of input2ViewZoneIds) {
+						a.removeZone(zone);
+					}
+				});
+				baseEditor?.changeViewZones(a => {
+					for (const zone of baseViewZoneIds) {
+						a.removeZone(zone);
+					}
+				});
+				resultEditor.changeViewZones(a => {
+					for (const zone of resultViewZoneIds) {
+						a.removeZone(zone);
+					}
+				});
+			}
+		});
+
+		return disposableStore;
+	}
+
 	override setOptions(options: ITextEditorOptions | undefined): void {
 		super.setOptions(options);
 
@@ -469,20 +484,140 @@ export class MergeEditor extends AbstractTextEditor<IMergeEditorViewState> {
 
 	// --- layout
 
-	setLayout(newValue: MergeEditorLayoutTypes): void {
+	public toggleBase(): void {
+		this.setLayout({
+			...this._layoutMode.value,
+			showBase: !this._layoutMode.value.showBase
+		});
+	}
+
+	public toggleShowBaseTop(): void {
+		const showBaseTop = this._layoutMode.value.showBase && this._layoutMode.value.showBaseAtTop;
+		this.setLayout({
+			...this._layoutMode.value,
+			showBaseAtTop: true,
+			showBase: !showBaseTop,
+		});
+	}
+
+	public toggleShowBaseCenter(): void {
+		const showBaseCenter = this._layoutMode.value.showBase && !this._layoutMode.value.showBaseAtTop;
+		this.setLayout({
+			...this._layoutMode.value,
+			showBaseAtTop: false,
+			showBase: !showBaseCenter,
+		});
+	}
+
+	public setLayoutKind(kind: MergeEditorLayoutKind): void {
+		this.setLayout({
+			...this._layoutMode.value,
+			kind
+		});
+	}
+
+	public setLayout(newLayout: IMergeEditorLayout): void {
 		const value = this._layoutMode.value;
-		if (value === newValue) {
+		if (JSON.stringify(value) === JSON.stringify(newLayout)) {
 			return;
 		}
-		if (newValue === 'mixed') {
-			this._grid.moveView(this.inputResultView.view, this._grid.height * .62, this.input1View.view, Direction.Down);
-			this._grid.moveView(this.input2View.view, Sizing.Distribute, this.input1View.view, Direction.Right);
-		} else {
-			this._grid.moveView(this.inputResultView.view, Sizing.Distribute, this.input1View.view, Direction.Right);
+		this.model?.telemetry.reportLayoutChange({
+			baseTop: newLayout.showBaseAtTop,
+			baseVisible: newLayout.showBase,
+			isColumnView: newLayout.kind === 'columns',
+		});
+		this.applyLayout(newLayout);
+	}
+
+	private readonly baseViewDisposables = this._register(new DisposableStore());
+
+	private applyLayout(layout: IMergeEditorLayout): void {
+		transaction(tx => {
+			/** @description applyLayout */
+
+			if (layout.showBase && !this.baseView.get()) {
+				this.baseViewDisposables.clear();
+				const baseView = this.baseViewDisposables.add(
+					this.instantiationService.createInstance(
+						BaseCodeEditorView,
+						this.viewModel
+					)
+				);
+				this.baseViewDisposables.add(autorun('Update base view options', reader => {
+					const options = this.baseViewOptions.read(reader);
+					if (options) {
+						baseView.updateOptions(options);
+					}
+				}));
+				this.baseView.set(baseView, tx);
+			} else if (!layout.showBase && this.baseView.get()) {
+				this.baseView.set(undefined, tx);
+				this.baseViewDisposables.clear();
+			}
+
+			if (layout.kind === 'mixed') {
+				this.setGrid([
+					layout.showBaseAtTop && layout.showBase ? {
+						size: 38,
+						data: this.baseView.get()!.view
+					} : undefined,
+					{
+						size: 38,
+						groups: [
+							{ data: this.input1View.view },
+							!layout.showBaseAtTop && layout.showBase ? { data: this.baseView.get()!.view } : undefined,
+							{ data: this.input2View.view }
+						].filter(isDefined)
+					},
+					{
+						size: 62,
+						data: this.inputResultView.view
+					},
+				].filter(isDefined));
+			} else if (layout.kind === 'columns') {
+				this.setGrid([
+					layout.showBase ? {
+						size: 40,
+						data: this.baseView.get()!.view
+					} : undefined,
+					{
+						size: 60,
+						groups: [{ data: this.input1View.view }, { data: this.inputResultView.view }, { data: this.input2View.view }]
+					},
+				].filter(isDefined));
+			}
+
+			this._layoutMode.value = layout;
+			this._ctxUsesColumnLayout.set(layout.kind);
+			this._ctxShowBase.set(layout.showBase);
+			this._ctxShowBaseAtTop.set(layout.showBaseAtTop);
+			this._onDidChangeSizeConstraints.fire();
+			this._layoutModeObs.set(layout, tx);
+		});
+	}
+
+	private setGrid(descriptor: GridNodeDescriptor<any>[]) {
+		let width = -1;
+		let height = -1;
+		if (this._grid.value) {
+			width = this._grid.value.width;
+			height = this._grid.value.height;
+		}
+		this._grid.value = SerializableGrid.from<any>({
+			orientation: Orientation.VERTICAL,
+			size: 100,
+			groups: descriptor,
+		}, {
+			styles: { separatorBorder: this.theme.getColor(settingsSashBorder) ?? Color.transparent },
+			proportionalLayout: true
+		});
+
+		reset(this.rootHtmlElement!, this._grid.value.element);
+		// Only call layout after the elements have been added to the DOM,
+		// so that they have a defined size.
+		if (width !== -1) {
+			this._grid.value.layout(width, height);
 		}
-		this._layoutMode.value = newValue;
-		this._ctxUsesColumnLayout.set(newValue);
-		this._onDidChangeSizeConstraints.fire();
 	}
 
 	private _applyViewState(state: IMergeEditorViewState | undefined) {
@@ -502,7 +637,7 @@ export class MergeEditor extends AbstractTextEditor<IMergeEditorViewState> {
 	}
 
 	protected computeEditorViewState(resource: URI): IMergeEditorViewState | undefined {
-		if (!isEqual(this.model?.resultTextModel.uri, resource)) {
+		if (!isEqual(this.inputModel.get()?.resultUri, resource)) {
 			return undefined;
 		}
 		const result = this.inputResultView.editor.saveViewState();
@@ -519,6 +654,52 @@ export class MergeEditor extends AbstractTextEditor<IMergeEditorViewState> {
 	protected tracksEditorViewState(input: EditorInput): boolean {
 		return input instanceof MergeEditorInput;
 	}
+
+	private readonly showNonConflictingChangesStore = this.instantiationService.createInstance(PersistentStore<boolean>, 'mergeEditor/showNonConflictingChanges');
+	private readonly showNonConflictingChanges = observableValue('showNonConflictingChanges', this.showNonConflictingChangesStore.get() ?? false);
+
+	public toggleShowNonConflictingChanges(): void {
+		this.showNonConflictingChanges.set(!this.showNonConflictingChanges.get(), undefined);
+		this.showNonConflictingChangesStore.set(this.showNonConflictingChanges.get());
+		this._ctxShowNonConflictingChanges.set(this.showNonConflictingChanges.get());
+	}
+}
+
+export interface IMergeEditorLayout {
+	readonly kind: MergeEditorLayoutKind;
+	readonly showBase: boolean;
+	readonly showBaseAtTop: boolean;
+}
+
+// TODO use PersistentStore
+class MergeEditorLayoutStore {
+	private static readonly _key = 'mergeEditor/layout';
+	private _value: IMergeEditorLayout = { kind: 'mixed', showBase: false, showBaseAtTop: true };
+
+	constructor(@IStorageService private _storageService: IStorageService) {
+		const value = _storageService.get(MergeEditorLayoutStore._key, StorageScope.PROFILE, 'mixed');
+
+		if (value === 'mixed' || value === 'columns') {
+			this._value = { kind: value, showBase: false, showBaseAtTop: true };
+		} else if (value) {
+			try {
+				this._value = JSON.parse(value);
+			} catch (e) {
+				onUnexpectedError(e);
+			}
+		}
+	}
+
+	get value() {
+		return this._value;
+	}
+
+	set value(value: IMergeEditorLayout) {
+		if (this._value !== value) {
+			this._value = value;
+			this._storageService.store(MergeEditorLayoutStore._key, JSON.stringify(this._value), StorageScope.PROFILE, StorageTarget.USER);
+		}
+	}
 }
 
 export class MergeEditorOpenHandlerContribution extends Disposable {
@@ -603,31 +784,3 @@ type IMergeEditorViewState = ICodeEditorViewState & {
 	readonly input2State?: ICodeEditorViewState;
 	readonly focusIndex: number;
 };
-
-
-function synchronizeScrolling(scrollingEditor: CodeEditorWidget, targetEditor: CodeEditorWidget, mapping: DocumentMapping | undefined, source: MappingDirection) {
-	if (!mapping) {
-		return;
-	}
-
-	const visibleRanges = scrollingEditor.getVisibleRanges();
-	if (visibleRanges.length === 0) {
-		return;
-	}
-	const topLineNumber = visibleRanges[0].startLineNumber - 1;
-
-	const result = mapping.getMappingContaining(topLineNumber, source);
-	const sourceRange = result.getRange(source);
-	const targetRange = result.getRange(getOppositeDirection(source));
-
-	const resultStartTopPx = targetEditor.getTopForLineNumber(targetRange.startLineNumber);
-	const resultEndPx = targetEditor.getTopForLineNumber(targetRange.endLineNumberExclusive);
-
-	const sourceStartTopPx = scrollingEditor.getTopForLineNumber(sourceRange.startLineNumber);
-	const sourceEndPx = scrollingEditor.getTopForLineNumber(sourceRange.endLineNumberExclusive);
-
-	const factor = Math.min((scrollingEditor.getScrollTop() - sourceStartTopPx) / (sourceEndPx - sourceStartTopPx), 1);
-	const resultScrollPosition = resultStartTopPx + (resultEndPx - resultStartTopPx) * factor;
-
-	targetEditor.setScrollTop(resultScrollPosition, ScrollType.Immediate);
-}
