@@ -4,11 +4,9 @@
  *--------------------------------------------------------------------------------------------*/
 
 import * as DOM from 'vs/base/browser/dom';
-import { ToolBar } from 'vs/base/browser/ui/toolbar/toolbar';
-import { IAction } from 'vs/base/common/actions';
 import { Disposable, DisposableStore } from 'vs/base/common/lifecycle';
-import { createAndFillInActionBarActions } from 'vs/platform/actions/browser/menuEntryActionViewItem';
-import { IMenu, IMenuService, MenuItemAction } from 'vs/platform/actions/common/actions';
+import { HiddenItemStrategy, MenuWorkbenchToolBar } from 'vs/platform/actions/browser/toolbar';
+import { IMenuService, MenuItemAction } from 'vs/platform/actions/common/actions';
 import { IContextKeyService } from 'vs/platform/contextkey/common/contextkey';
 import { IContextMenuService } from 'vs/platform/contextview/browser/contextView';
 import { IInstantiationService } from 'vs/platform/instantiation/common/instantiation';
@@ -18,8 +16,7 @@ import { CodiconActionViewItem } from 'vs/workbench/contrib/notebook/browser/vie
 
 export class ListTopCellToolbar extends Disposable {
 	private topCellToolbar: HTMLElement;
-	private menu: IMenu;
-	private toolbar: ToolBar;
+	private toolbar: MenuWorkbenchToolBar;
 	private readonly _modelDisposables = this._register(new DisposableStore());
 	constructor(
 		protected readonly notebookEditor: INotebookEditorDelegate,
@@ -34,7 +31,7 @@ export class ListTopCellToolbar extends Disposable {
 
 		this.topCellToolbar = DOM.append(insertionIndicatorContainer, DOM.$('.cell-list-top-cell-toolbar-container'));
 
-		this.toolbar = this._register(new ToolBar(this.topCellToolbar, this.contextMenuService, {
+		this.toolbar = this._register(instantiationService.createInstance(MenuWorkbenchToolBar, this.topCellToolbar, this.notebookEditor.creationOptions.menuIds.cellTopInsertToolbar, {
 			actionViewItemProvider: action => {
 				if (action instanceof MenuItemAction) {
 					const item = this.instantiationService.createInstance(CodiconActionViewItem, action, undefined);
@@ -42,18 +39,20 @@ export class ListTopCellToolbar extends Disposable {
 				}
 
 				return undefined;
-			}
+			},
+			menuOptions: {
+				shouldForwardArgs: true
+			},
+			toolbarOptions: {
+				primaryGroup: g => /^inline/.test(g),
+			},
+			hiddenItemStrategy: HiddenItemStrategy.Ignore,
 		}));
+
 		this.toolbar.context = <INotebookActionContext>{
 			notebookEditor
 		};
 
-		this.menu = this._register(this.menuService.createMenu(this.notebookEditor.creationOptions.menuIds.cellTopInsertToolbar, contextKeyService));
-		this._register(this.menu.onDidChange(() => {
-			this.updateActions();
-		}));
-		this.updateActions();
-
 		// update toolbar container css based on cell list length
 		this._register(this.notebookEditor.onDidChangeModel(() => {
 			this._modelDisposables.clear();
@@ -70,11 +69,6 @@ export class ListTopCellToolbar extends Disposable {
 		this.updateClass();
 	}
 
-	private updateActions() {
-		const actions = this.getCellToolbarActions(this.menu, false);
-		this.toolbar.setActions(actions.primary, actions.secondary);
-	}
-
 	private updateClass() {
 		if (this.notebookEditor.hasModel() && this.notebookEditor.getLength() === 0) {
 			this.topCellToolbar.classList.add('emptyNotebook');
@@ -82,16 +76,4 @@ export class ListTopCellToolbar extends Disposable {
 			this.topCellToolbar.classList.remove('emptyNotebook');
 		}
 	}
-
-	private getCellToolbarActions(menu: IMenu, alwaysFillSecondaryActions: boolean): { primary: IAction[]; secondary: IAction[] } {
-		type NewType = IAction;
-
-		const primary: NewType[] = [];
-		const secondary: IAction[] = [];
-		const result = { primary, secondary };
-
-		createAndFillInActionBarActions(menu, { shouldForwardArgs: true }, result, g => /^inline/.test(g));
-
-		return result;
-	}
 }
