@@ -36,7 +36,7 @@ class NotebookModelReferenceCollection extends ReferenceCollection<Promise<IReso
 	private readonly _dirtyStates = new ResourceMap<boolean>();
 
 	constructor(
-		@IInstantiationService readonly _instantiationService: IInstantiationService,
+		@IInstantiationService private readonly _instantiationService: IInstantiationService,
 		@INotebookService private readonly _notebookService: INotebookService,
 		@ILogService private readonly _logService: ILogService,
 	) {
