@@ -25,14 +25,6 @@ export interface ICellExecutionComplete {
 	lastRunSuccess?: boolean;
 }
 
-export interface ICellExecutionEntry {
-	notebook: URI;
-	cellHandle: number;
-	state: NotebookCellExecutionState;
-	didPause: boolean;
-	isPaused: boolean;
-}
-
 export interface ICellExecutionStateChangedEvent {
 	notebook: URI;
 	cellHandle: number;
@@ -60,7 +52,8 @@ export interface INotebookExecutionStateService {
 	onDidChangeLastRunFailState: Event<INotebookFailStateChangedEvent>;
 
 	forceCancelNotebookExecutions(notebookUri: URI): void;
-	getCellExecutionStatesForNotebook(notebook: URI): INotebookCellExecution[];
+	getCellExecutionsForNotebook(notebook: URI): INotebookCellExecution[];
+	getCellExecutionsByHandleForNotebook(notebook: URI): Map<number, INotebookCellExecution> | undefined;
 	getCellExecution(cellUri: URI): INotebookCellExecution | undefined;
 	createCellExecution(notebook: URI, cellHandle: number): INotebookCellExecution;
 	getLastFailedCellForNotebook(notebook: URI): number | undefined;
