@@ -123,18 +123,27 @@ class MirrorNotebookDocument {
 				const cell = this.cells[e.index];
 				cell.outputs = e.outputs;
 			} else if (e.kind === NotebookCellsChangeType.ChangeCellLanguage) {
+				this._assertIndex(e.index);
 				const cell = this.cells[e.index];
 				cell.language = e.language;
 			} else if (e.kind === NotebookCellsChangeType.ChangeCellMetadata) {
+				this._assertIndex(e.index);
 				const cell = this.cells[e.index];
 				cell.metadata = e.metadata;
 			} else if (e.kind === NotebookCellsChangeType.ChangeCellInternalMetadata) {
+				this._assertIndex(e.index);
 				const cell = this.cells[e.index];
 				cell.internalMetadata = e.internalMetadata;
 			}
 		});
 	}
 
+	private _assertIndex(index: number): void {
+		if (index < 0 || index >= this.cells.length) {
+			throw new Error(`Illegal index ${index}. Cells length: ${this.cells.length}`);
+		}
+	}
+
 	_spliceNotebookCells(splices: NotebookCellTextModelSplice<IMainCellDto>[]) {
 		splices.reverse().forEach(splice => {
 			const cellDtos = splice[2];
