@@ -25,7 +25,7 @@ import { nullRange } from 'vs/workbench/services/preferences/common/preferencesM
 import { IConfigurationService } from 'vs/platform/configuration/common/configuration';
 import { IStringDictionary } from 'vs/base/common/collections';
 import { IProductService } from 'vs/platform/product/common/productService';
-import { registerSingleton } from 'vs/platform/instantiation/common/extensions';
+import { InstantiationType, registerSingleton } from 'vs/platform/instantiation/common/extensions';
 
 export interface IEndpointDetails {
 	urlBase?: string;
@@ -607,4 +607,4 @@ export class SettingMatches {
 	}
 }
 
-registerSingleton(IPreferencesSearchService, PreferencesSearchService, true);
+registerSingleton(IPreferencesSearchService, PreferencesSearchService, InstantiationType.Delayed);
