@@ -66,35 +66,35 @@ export class PreferencesContribution implements IWorkbenchContribution {
 					label: nls.localize('splitSettingsEditorLabel', "Split Settings Editor"),
 					priority: RegisteredEditorPriority.builtin,
 				},
+				{},
 				{
-					canHandleDiff: false,
-				},
-				({ resource, options }): EditorInputWithOptions => {
-					// Global User Settings File
-					if (isEqual(resource, this.userDataProfileService.currentProfile.settingsResource)) {
-						return { editor: this.preferencesService.createSplitJsonEditorInput(ConfigurationTarget.USER_LOCAL, resource), options };
-					}
-
-					// Single Folder Workspace Settings File
-					const state = this.workspaceService.getWorkbenchState();
-					if (state === WorkbenchState.FOLDER) {
-						const folders = this.workspaceService.getWorkspace().folders;
-						if (isEqual(resource, folders[0].toResource(FOLDER_SETTINGS_PATH))) {
-							return { editor: this.preferencesService.createSplitJsonEditorInput(ConfigurationTarget.WORKSPACE, resource), options };
+					createEditorInput: ({ resource, options }): EditorInputWithOptions => {
+						// Global User Settings File
+						if (isEqual(resource, this.userDataProfileService.currentProfile.settingsResource)) {
+							return { editor: this.preferencesService.createSplitJsonEditorInput(ConfigurationTarget.USER_LOCAL, resource), options };
 						}
-					}
 
-					// Multi Folder Workspace Settings File
-					else if (state === WorkbenchState.WORKSPACE) {
-						const folders = this.workspaceService.getWorkspace().folders;
-						for (const folder of folders) {
-							if (isEqual(resource, folder.toResource(FOLDER_SETTINGS_PATH))) {
-								return { editor: this.preferencesService.createSplitJsonEditorInput(ConfigurationTarget.WORKSPACE_FOLDER, resource), options };
+						// Single Folder Workspace Settings File
+						const state = this.workspaceService.getWorkbenchState();
+						if (state === WorkbenchState.FOLDER) {
+							const folders = this.workspaceService.getWorkspace().folders;
+							if (isEqual(resource, folders[0].toResource(FOLDER_SETTINGS_PATH))) {
+								return { editor: this.preferencesService.createSplitJsonEditorInput(ConfigurationTarget.WORKSPACE, resource), options };
 							}
 						}
-					}
 
-					return { editor: this.textEditorService.createTextEditor({ resource }), options };
+						// Multi Folder Workspace Settings File
+						else if (state === WorkbenchState.WORKSPACE) {
+							const folders = this.workspaceService.getWorkspace().folders;
+							for (const folder of folders) {
+								if (isEqual(resource, folder.toResource(FOLDER_SETTINGS_PATH))) {
+									return { editor: this.preferencesService.createSplitJsonEditorInput(ConfigurationTarget.WORKSPACE_FOLDER, resource), options };
+								}
+							}
+						}
+
+						return { editor: this.textEditorService.createTextEditor({ resource }), options };
+					}
 				}
 			);
 		}
