@@ -496,14 +496,13 @@ configurationRegistry.registerConfiguration({
 		},
 		[TaskSettingId.AllowAutomaticTasks]: {
 			type: 'string',
-			enum: ['on', 'auto', 'off'],
+			enum: ['on', 'off'],
 			enumDescriptions: [
 				nls.localize('task.allowAutomaticTasks.on', "Always"),
-				nls.localize('task.allowAutomaticTasks.auto', "Prompt for permission for each folder"),
 				nls.localize('task.allowAutomaticTasks.off', "Never"),
 			],
-			description: nls.localize('task.allowAutomaticTasks', "Enable automatic tasks in the folder - note that tasks won't run in an untrusted workspace."),
-			default: 'auto',
+			description: nls.localize('task.allowAutomaticTasks', "Enable automatic tasks - note that tasks won't run in an untrusted workspace."),
+			default: 'on',
 			restricted: true
 		},
 		[TaskSettingId.ShowDecorations]: {
