@@ -8,14 +8,12 @@ import { Disposable, dispose, IDisposable } from 'vs/base/common/lifecycle';
 import { IConfigurationService } from 'vs/platform/configuration/common/configuration';
 import { IInstantiationService } from 'vs/platform/instantiation/common/instantiation';
 import { ITerminalGroupService, ITerminalInstance, ITerminalService, TerminalConnectionState } from 'vs/workbench/contrib/terminal/browser/terminal';
-import { TerminalFindWidget } from 'vs/workbench/contrib/terminal/browser/terminalFindWidget';
 import { TerminalTabsListSizes, TerminalTabList } from 'vs/workbench/contrib/terminal/browser/terminalTabsList';
-import { IThemeService, IColorTheme } from 'vs/platform/theme/common/themeService';
 import { isLinux, isMacintosh } from 'vs/base/common/platform';
 import * as dom from 'vs/base/browser/dom';
 import { BrowserFeatures } from 'vs/base/browser/canIUse';
 import { INotificationService } from 'vs/platform/notification/common/notification';
-import { Action, Separator } from 'vs/base/common/actions';
+import { Action, IAction, Separator } from 'vs/base/common/actions';
 import { IMenu, IMenuService, MenuId } from 'vs/platform/actions/common/actions';
 import { IContextKey, IContextKeyService } from 'vs/platform/contextkey/common/contextkey';
 import { IContextMenuService } from 'vs/platform/contextview/browser/contextView';
@@ -30,7 +28,6 @@ const $ = dom.$;
 
 const enum CssClass {
 	ViewIsVertical = 'terminal-side-view',
-	FindFocus = 'find-focused'
 }
 
 const enum WidthConstants {
@@ -48,7 +45,6 @@ export class TerminalTabbedView extends Disposable {
 	private _tabContainer: HTMLElement;
 
 	private _tabList: TerminalTabList;
-	private _findWidget: TerminalFindWidget;
 	private _sashDisposables: IDisposable[] | undefined;
 
 	private _plusButton: HTMLElement | undefined;
@@ -77,7 +73,6 @@ export class TerminalTabbedView extends Disposable {
 		@IInstantiationService private readonly _instantiationService: IInstantiationService,
 		@INotificationService private readonly _notificationService: INotificationService,
 		@IContextMenuService private readonly _contextMenuService: IContextMenuService,
-		@IThemeService private readonly _themeService: IThemeService,
 		@IConfigurationService private readonly _configurationService: IConfigurationService,
 		@IMenuService menuService: IMenuService,
 		@IStorageService private readonly _storageService: IStorageService,
@@ -103,9 +98,6 @@ export class TerminalTabbedView extends Disposable {
 		this._terminalContainer = $('.terminal-groups-container');
 		terminalOuterContainer.appendChild(this._terminalContainer);
 
-		this._findWidget = this._register(this._instantiationService.createInstance(TerminalFindWidget, this._terminalGroupService.getFindState()));
-		terminalOuterContainer.appendChild(this._findWidget.getDomNode());
-
 		this._terminalService.setContainers(parentElement, this._terminalContainer);
 
 		this._terminalIsTabsNarrowContextKey = TerminalContextKeys.tabsNarrow.bindTo(contextKeyService);
@@ -132,12 +124,6 @@ export class TerminalTabbedView extends Disposable {
 		});
 		this._register(this._terminalGroupService.onDidChangeInstances(() => this._refreshShowTabs()));
 		this._register(this._terminalGroupService.onDidChangeGroups(() => this._refreshShowTabs()));
-		this._register(this._themeService.onDidColorThemeChange(theme => this._updateTheme(theme)));
-		this._register(this._terminalService.onDidRequestHideFindWidget(() => this.hideFindWidget()));
-		this._updateTheme();
-
-		this._findWidget.focusTracker.onDidFocus(() => this._terminalContainer.classList.add(CssClass.FindFocus));
-		this._findWidget.focusTracker.onDidBlur(() => this._terminalContainer.classList.remove(CssClass.FindFocus));
 
 		this._attachEventListeners(parentElement, this._terminalContainer);
 
@@ -151,11 +137,6 @@ export class TerminalTabbedView extends Disposable {
 		});
 
 		this._splitView = new SplitView(parentElement, { orientation: Orientation.HORIZONTAL, proportionalLayout: false });
-		this._terminalService.onDidCreateInstance(instance => {
-			instance.onDidChangeFindResults(() => {
-				this._findWidget.updateResultCount();
-			});
-		});
 		this._setupSplitView(terminalOuterContainer);
 	}
 
@@ -341,14 +322,6 @@ export class TerminalTabbedView extends Disposable {
 		this._updateHasText();
 	}
 
-	private _updateTheme(theme?: IColorTheme): void {
-		if (!theme) {
-			theme = this._themeService.getColorTheme();
-		}
-
-		this._findWidget?.updateTheme(theme);
-	}
-
 	private _attachEventListeners(parentDomElement: HTMLElement, terminalContainer: HTMLElement): void {
 		this._register(dom.addDisposableListener(this._tabContainer, 'mouseleave', async (event: MouseEvent) => {
 			this._terminalTabsMouseContextKey.set(false);
@@ -453,7 +426,7 @@ export class TerminalTabbedView extends Disposable {
 		}));
 	}
 
-	private _getTabActions(): Action[] {
+	private _getTabActions(): IAction[] {
 		return [
 			new Separator(),
 			this._configurationService.inspect(TerminalSettingId.TabsLocation).userValue === 'left' ?
@@ -488,33 +461,6 @@ export class TerminalTabbedView extends Disposable {
 		}
 	}
 
-	focusFindWidget() {
-		const activeInstance = this._terminalGroupService.activeInstance;
-		if (activeInstance && activeInstance.hasSelection() && activeInstance.selection!.indexOf('\n') === -1) {
-			this._findWidget!.reveal(activeInstance.selection);
-		} else {
-			this._findWidget!.reveal();
-		}
-	}
-
-	hideFindWidget() {
-		this.focus();
-		this._findWidget!.hide();
-	}
-
-	showFindWidget() {
-		const activeInstance = this._terminalGroupService.activeInstance;
-		if (activeInstance && activeInstance.hasSelection() && activeInstance.selection!.indexOf('\n') === -1) {
-			this._findWidget!.show(activeInstance.selection);
-		} else {
-			this._findWidget!.show();
-		}
-	}
-
-	getFindWidget(): TerminalFindWidget {
-		return this._findWidget!;
-	}
-
 	focus() {
 		if (this._terminalService.connectionState === TerminalConnectionState.Connecting) {
 			// If the terminal is waiting to reconnect to remote terminals, then there is no TerminalInstance yet that can
