@@ -22,7 +22,9 @@ export function getShellIntegrationTooltip(instance: ITerminalInstance, markdown
 		if (instance.shellLaunchConfig.ignoreShellIntegration) {
 			shellIntegrationString += `${markdown ? '\n\n---\n\n' : '\n\n'} ${localize('launchFailed.exitCodeOnlyShellIntegration', "The terminal process failed to launch. Disabling shell integration with terminal.integrated.shellIntegration.enabled might help.")}`;
 		} else {
-			shellIntegrationString += `${markdown ? '\n\n---\n\n' : '\n\n'} ${localize('shellIntegration.activationFailed', "Shell integration failed to activate")}`;
+			if (instance.usedShellIntegrationInjection) {
+				shellIntegrationString += `${markdown ? '\n\n---\n\n' : '\n\n'} ${localize('shellIntegration.activationFailed', "Shell integration failed to activate")}`;
+			}
 		}
 	}
 	return shellIntegrationString;
