@@ -131,8 +131,8 @@ class LocalTerminalBackend extends BaseTerminalBackend implements ITerminalBacke
 		await this._localPtyService.updateTitle(id, title, titleSource);
 	}
 
-	async updateIcon(id: number, icon: URI | { light: URI; dark: URI } | { id: string; color?: { id: string } }, color?: string): Promise<void> {
-		await this._localPtyService.updateIcon(id, icon, color);
+	async updateIcon(id: number, userInitiated: boolean, icon: URI | { light: URI; dark: URI } | { id: string; color?: { id: string } }, color?: string): Promise<void> {
+		await this._localPtyService.updateIcon(id, userInitiated, icon, color);
 	}
 
 	updateProperty<T extends ProcessPropertyType>(id: number, property: ProcessPropertyType, value: IProcessPropertyMap[T]): Promise<void> {
