@@ -10,20 +10,19 @@ import { AnchorAlignment } from 'vs/base/browser/ui/contextview/contextview';
 import { DropdownMenuActionViewItem } from 'vs/base/browser/ui/dropdown/dropdownActionViewItem';
 import { Action, IAction, IActionRunner, Separator } from 'vs/base/common/actions';
 import { Delayer } from 'vs/base/common/async';
+import { Emitter } from 'vs/base/common/event';
 import { Iterable } from 'vs/base/common/iterator';
 import { localize } from 'vs/nls';
-import { Action2, registerAction2 } from 'vs/platform/actions/common/actions';
 import { IContextMenuService } from 'vs/platform/contextview/browser/contextView';
 import { IInstantiationService } from 'vs/platform/instantiation/common/instantiation';
 import { StorageScope, StorageTarget } from 'vs/platform/storage/common/storage';
 import { IThemeService, ThemeIcon } from 'vs/platform/theme/common/themeService';
 import { attachSuggestEnabledInputBoxStyler, ContextScopedSuggestEnabledInputWithHistory, SuggestEnabledInputWithHistory, SuggestResultsProvider } from 'vs/workbench/contrib/codeEditor/browser/suggestEnabledInput/suggestEnabledInput';
 import { testingFilterIcon } from 'vs/workbench/contrib/testing/browser/icons';
-import { TestCommandId } from 'vs/workbench/contrib/testing/common/constants';
 import { StoredValue } from 'vs/workbench/contrib/testing/common/storedValue';
-import { denamespaceTestTag } from 'vs/workbench/contrib/testing/common/testTypes';
 import { ITestExplorerFilterState, TestFilterTerm } from 'vs/workbench/contrib/testing/common/testExplorerFilterState';
 import { ITestService } from 'vs/workbench/contrib/testing/common/testService';
+import { denamespaceTestTag } from 'vs/workbench/contrib/testing/common/testTypes';
 
 const testFilterDescriptions: { [K in TestFilterTerm]: string } = {
 	[TestFilterTerm.Failed]: localize('testing.filters.showOnlyFailed', "Show Only Failed Tests"),
@@ -35,6 +34,8 @@ const testFilterDescriptions: { [K in TestFilterTerm]: string } = {
 export class TestingExplorerFilter extends BaseActionViewItem {
 	private input!: SuggestEnabledInputWithHistory;
 	private wrapper!: HTMLDivElement;
+	private readonly focusEmitter = this._register(new Emitter<void>());
+	public readonly onDidFocus = this.focusEmitter.event;
 	private readonly history: StoredValue<{ values: string[]; lastValue: string } | string[]> = this.instantiationService.createInstance(StoredValue, {
 		key: 'testing.filterHistory2',
 		scope: StorageScope.WORKSPACE,
@@ -111,6 +112,10 @@ export class TestingExplorerFilter extends BaseActionViewItem {
 			input.focus();
 		}));
 
+		this._register(input.onDidFocus(() => {
+			this.focusEmitter.fire();
+		}));
+
 		this._register(input.onInputDidChange(() => updateDelayer.trigger(() => {
 			input.addToHistory();
 			this.state.setText(input.getValue());
@@ -242,13 +247,3 @@ class FiltersDropdownMenuActionViewItem extends DropdownMenuActionViewItem {
 		this.element!.classList.toggle('checked', this._action.checked);
 	}
 }
-
-registerAction2(class extends Action2 {
-	constructor() {
-		super({
-			id: TestCommandId.FilterAction,
-			title: { value: localize('filter', "Filter"), original: 'Filter' },
-		});
-	}
-	async run(): Promise<void> { }
-});
