@@ -626,26 +626,26 @@ export interface IncrementalTestCollectionItem extends InternalTestItem {
  * and called with diff changes as they're applied. This is used in the
  * ext host to create a cohesive change event from a diff.
  */
-export class IncrementalChangeCollector<T> {
+export interface IncrementalChangeCollector<T> {
 	/**
 	 * A node was added.
 	 */
-	public add(node: T): void { }
+	add?(node: T): void;
 
 	/**
 	 * A node in the collection was updated.
 	 */
-	public update(node: T): void { }
+	update?(node: T): void;
 
 	/**
 	 * A node was removed.
 	 */
-	public remove(node: T, isNestedOperation: boolean): void { }
+	remove?(node: T, isNestedOperation: boolean): void;
 
 	/**
 	 * Called when the diff has been applied.
 	 */
-	public complete(): void { }
+	complete?(): void;
 }
 
 /**
@@ -687,80 +687,17 @@ export abstract class AbstractIncrementalTestCollection<T extends IncrementalTes
 
 		for (const op of diff) {
 			switch (op.op) {
-				case TestDiffOpType.Add: {
-					const internalTest = InternalTestItem.deserialize(op.item);
-					const parentId = TestId.parentId(internalTest.item.extId)?.toString();
-					if (!parentId) {
-						const created = this.createItem(internalTest);
-						this.roots.add(created);
-						this.items.set(internalTest.item.extId, created);
-						changes.add(created);
-					} else if (this.items.has(parentId)) {
-						const parent = this.items.get(parentId)!;
-						parent.children.add(internalTest.item.extId);
-						const created = this.createItem(internalTest, parent);
-						this.items.set(internalTest.item.extId, created);
-						changes.add(created);
-					}
-
-					if (internalTest.expand === TestItemExpandState.BusyExpanding) {
-						this.busyControllerCount++;
-					}
+				case TestDiffOpType.Add:
+					this.add(InternalTestItem.deserialize(op.item), changes);
 					break;
-				}
 
-				case TestDiffOpType.Update: {
-					const patch = ITestItemUpdate.deserialize(op.item);
-					const existing = this.items.get(patch.extId);
-					if (!existing) {
-						break;
-					}
-
-					if (patch.expand !== undefined) {
-						if (existing.expand === TestItemExpandState.BusyExpanding) {
-							this.busyControllerCount--;
-						}
-						if (patch.expand === TestItemExpandState.BusyExpanding) {
-							this.busyControllerCount++;
-						}
-					}
-
-					applyTestItemUpdate(existing, patch);
-					changes.update(existing);
+				case TestDiffOpType.Update:
+					this.update(ITestItemUpdate.deserialize(op.item), changes);
 					break;
-				}
 
-				case TestDiffOpType.Remove: {
-					const toRemove = this.items.get(op.itemId);
-					if (!toRemove) {
-						break;
-					}
-
-					const parentId = TestId.parentId(toRemove.item.extId)?.toString();
-					if (parentId) {
-						const parent = this.items.get(parentId)!;
-						parent.children.delete(toRemove.item.extId);
-					} else {
-						this.roots.delete(toRemove);
-					}
-
-					const queue: Iterable<string>[] = [[op.itemId]];
-					while (queue.length) {
-						for (const itemId of queue.pop()!) {
-							const existing = this.items.get(itemId);
-							if (existing) {
-								queue.push(existing.children);
-								this.items.delete(itemId);
-								changes.remove(existing, existing !== toRemove);
-
-								if (existing.expand === TestItemExpandState.BusyExpanding) {
-									this.busyControllerCount--;
-								}
-							}
-						}
-					}
+				case TestDiffOpType.Remove:
+					this.remove(op.itemId, changes);
 					break;
-				}
 
 				case TestDiffOpType.Retire:
 					this.retireTest(op.itemId);
@@ -780,7 +717,85 @@ export abstract class AbstractIncrementalTestCollection<T extends IncrementalTes
 			}
 		}
 
-		changes.complete();
+		changes.complete?.();
+	}
+
+	protected add(item: InternalTestItem, changes: IncrementalChangeCollector<T>
+	) {
+		const parentId = TestId.parentId(item.item.extId)?.toString();
+		let created: T;
+		if (!parentId) {
+			created = this.createItem(item);
+			this.roots.add(created);
+			this.items.set(item.item.extId, created);
+		} else if (this.items.has(parentId)) {
+			const parent = this.items.get(parentId)!;
+			parent.children.add(item.item.extId);
+			created = this.createItem(item, parent);
+			this.items.set(item.item.extId, created);
+		} else {
+			console.error(`Test with unknown parent ID: ${JSON.stringify(item)}`);
+			return;
+		}
+
+		changes.add?.(created);
+		if (item.expand === TestItemExpandState.BusyExpanding) {
+			this.busyControllerCount++;
+		}
+
+		return created;
+	}
+
+	protected update(patch: ITestItemUpdate, changes: IncrementalChangeCollector<T>
+	) {
+		const existing = this.items.get(patch.extId);
+		if (!existing) {
+			return;
+		}
+
+		if (patch.expand !== undefined) {
+			if (existing.expand === TestItemExpandState.BusyExpanding) {
+				this.busyControllerCount--;
+			}
+			if (patch.expand === TestItemExpandState.BusyExpanding) {
+				this.busyControllerCount++;
+			}
+		}
+
+		applyTestItemUpdate(existing, patch);
+		changes.update?.(existing);
+		return existing;
+	}
+
+	protected remove(itemId: string, changes: IncrementalChangeCollector<T>) {
+		const toRemove = this.items.get(itemId);
+		if (!toRemove) {
+			return;
+		}
+
+		const parentId = TestId.parentId(toRemove.item.extId)?.toString();
+		if (parentId) {
+			const parent = this.items.get(parentId)!;
+			parent.children.delete(toRemove.item.extId);
+		} else {
+			this.roots.delete(toRemove);
+		}
+
+		const queue: Iterable<string>[] = [[itemId]];
+		while (queue.length) {
+			for (const itemId of queue.pop()!) {
+				const existing = this.items.get(itemId);
+				if (existing) {
+					queue.push(existing.children);
+					this.items.delete(itemId);
+					changes.remove?.(existing, existing !== toRemove);
+
+					if (existing.expand === TestItemExpandState.BusyExpanding) {
+						this.busyControllerCount--;
+					}
+				}
+			}
+		}
 	}
 
 	/**
@@ -802,8 +817,8 @@ export abstract class AbstractIncrementalTestCollection<T extends IncrementalTes
 	/**
 	 * Called before a diff is applied to create a new change collector.
 	 */
-	protected createChangeCollector() {
-		return new IncrementalChangeCollector<T>();
+	protected createChangeCollector(): IncrementalChangeCollector<T> {
+		return {};
 	}
 
 	/**
