@@ -28,8 +28,9 @@ import { IEditorGroupsService } from 'vs/workbench/services/editor/common/editor
 import { ACTIVE_GROUP, IEditorService } from 'vs/workbench/services/editor/common/editorService';
 import { IExtensionService } from 'vs/workbench/services/extensions/common/extensions';
 import { getTelemetryLevel, supportsTelemetry } from 'vs/platform/telemetry/common/telemetryUtils';
-import { IConfigurationService } from 'vs/platform/configuration/common/configuration';
+import { IConfigurationChangeEvent, IConfigurationService } from 'vs/platform/configuration/common/configuration';
 import { TelemetryLevel } from 'vs/platform/telemetry/common/telemetry';
+import { DisposableStore } from 'vs/base/common/lifecycle';
 
 export class ReleaseNotesManager {
 
@@ -37,6 +38,7 @@ export class ReleaseNotesManager {
 
 	private _currentReleaseNotes: WebviewInput | undefined = undefined;
 	private _lastText: string | undefined;
+	private disposables = new DisposableStore();
 
 	public constructor(
 		@IEnvironmentService private readonly _environmentService: IEnvironmentService,
@@ -60,6 +62,9 @@ export class ReleaseNotesManager {
 				this._currentReleaseNotes.webview.html = html;
 			}
 		});
+
+		_configurationService.onDidChangeConfiguration(this.onDidChangeConfiguration, this, this.disposables);
+		_webviewWorkbenchService.onDidChangeActiveWebviewEditor(this.onDidChangeActiveWebviewEditor, this, this.disposables);
 	}
 
 	public async show(version: string): Promise<boolean> {
@@ -76,13 +81,13 @@ export class ReleaseNotesManager {
 		} else {
 			this._currentReleaseNotes = this._webviewWorkbenchService.openWebview(
 				{
-					id: generateUuid(),
 					options: {
 						tryRestoreScrollPosition: true,
 						enableFindWidget: true,
 					},
 					contentOptions: {
-						localResourceRoots: []
+						localResourceRoots: [],
+						allowScripts: true
 					},
 					extension: undefined
 				},
@@ -91,7 +96,18 @@ export class ReleaseNotesManager {
 				{ group: ACTIVE_GROUP, preserveFocus: false });
 
 			this._currentReleaseNotes.webview.onDidClickLink(uri => this.onDidClickLink(URI.parse(uri)));
-			this._currentReleaseNotes.onWillDispose(() => { this._currentReleaseNotes = undefined; });
+
+			const disposables = new DisposableStore();
+			disposables.add(this._currentReleaseNotes.webview.onMessage(e => {
+				if (e.message.type === 'showReleaseNotes') {
+					this._configurationService.updateValue('update.showReleaseNotes', e.message.value);
+				}
+			}));
+
+			disposables.add(this._currentReleaseNotes.onWillDispose(() => {
+				disposables.dispose();
+				this._currentReleaseNotes = undefined;
+			}));
 
 			this._currentReleaseNotes.webview.html = html;
 		}
@@ -207,18 +223,62 @@ export class ReleaseNotesManager {
 		const content = await renderMarkdownDocument(text, this._extensionService, this._languageService, false);
 		const colorMap = TokenizationRegistry.getColorMap();
 		const css = colorMap ? generateTokensCSSForColorMap(colorMap) : '';
+		const showReleaseNotes = this._configurationService.getValue<boolean>('update.showReleaseNotes');
+
 		return `<!DOCTYPE html>
 		<html>
 			<head>
 				<base href="https://code.visualstudio.com/raw/">
 				<meta http-equiv="Content-type" content="text/html;charset=UTF-8">
-				<meta http-equiv="Content-Security-Policy" content="default-src 'none'; img-src https: data:; media-src https:; style-src 'nonce-${nonce}' https://code.visualstudio.com;">
+				<meta http-equiv="Content-Security-Policy" content="default-src 'none'; img-src https: data:; media-src https:; style-src 'nonce-${nonce}' https://code.visualstudio.com; script-src 'nonce-${nonce}';">
 				<style nonce="${nonce}">
 					${DEFAULT_MARKDOWN_STYLES}
 					${css}
+					header { display: flex; align-items: center; padding-top: 1em; }
 				</style>
 			</head>
-			<body>${content}</body>
+			<body>
+				<header>
+					<input type="checkbox" id="showReleaseNotes" ${showReleaseNotes ? 'checked' : ''}>
+					<label for="showReleaseNotes">${nls.localize('showOnUpdate', "Show release notes after an update")}</label>
+				</header>
+				${content}
+				<script nonce="${nonce}">
+					const vscode = acquireVsCodeApi();
+					const checkbox = document.getElementById('showReleaseNotes');
+
+					window.addEventListener('message', event => {
+						if (event.data.type === 'showReleaseNotes') {
+							checkbox.checked = event.data.value;
+						}
+					});
+
+					checkbox.addEventListener('change', event => {
+						vscode.postMessage({ type: 'showReleaseNotes', value: checkbox.checked }, '*');
+					});
+				</script>
+			</body>
 		</html>`;
 	}
+
+	private onDidChangeConfiguration(e: IConfigurationChangeEvent): void {
+		if (e.affectsConfiguration('update.showReleaseNotes')) {
+			this.updateWebview();
+		}
+	}
+
+	private onDidChangeActiveWebviewEditor(input: WebviewInput | undefined): void {
+		if (input && input === this._currentReleaseNotes) {
+			this.updateWebview();
+		}
+	}
+
+	private updateWebview() {
+		if (this._currentReleaseNotes) {
+			this._currentReleaseNotes.webview.postMessage({
+				type: 'showReleaseNotes',
+				value: this._configurationService.getValue<boolean>('update.showReleaseNotes')
+			});
+		}
+	}
 }
