@@ -29,48 +29,15 @@ import { IRemoteAuthorityResolverService } from 'vs/platform/remote/common/remot
 import { ITelemetryService } from 'vs/platform/telemetry/common/telemetry';
 import { ITunnelService } from 'vs/platform/tunnel/common/tunnel';
 import { WebviewPortMappingManager } from 'vs/platform/webview/common/webviewPortMapping';
-import { parentOriginHash } from 'vs/workbench/browser/webview';
-import { decodeAuthority, webviewGenericCspSource, webviewRootResourceAuthority } from 'vs/workbench/common/webview';
+import { parentOriginHash } from 'vs/workbench/browser/iframe';
 import { loadLocalResource, WebviewResourceResponse } from 'vs/workbench/contrib/webview/browser/resourceLoading';
 import { WebviewThemeDataProvider } from 'vs/workbench/contrib/webview/browser/themeing';
 import { areWebviewContentOptionsEqual, IWebview, WebviewContentOptions, WebviewExtensionDescription, WebviewInitInfo, WebviewMessageReceivedEvent, WebviewOptions } from 'vs/workbench/contrib/webview/browser/webview';
 import { WebviewFindDelegate, WebviewFindWidget } from 'vs/workbench/contrib/webview/browser/webviewFindWidget';
+import { FromWebviewMessage, KeyEvent, ToWebviewMessage } from 'vs/workbench/contrib/webview/browser/webviewMessages';
+import { decodeAuthority, webviewGenericCspSource, webviewRootResourceAuthority } from 'vs/workbench/contrib/webview/common/webview';
 import { IWorkbenchEnvironmentService } from 'vs/workbench/services/environment/common/environmentService';
 
-const enum WebviewMessageChannels {
-	onmessage = 'onmessage',
-	didClickLink = 'did-click-link',
-	didScroll = 'did-scroll',
-	didFocus = 'did-focus',
-	didBlur = 'did-blur',
-	didLoad = 'did-load',
-	didFind = 'did-find',
-	doUpdateState = 'do-update-state',
-	doReload = 'do-reload',
-	setConfirmBeforeClose = 'set-confirm-before-close',
-	loadResource = 'load-resource',
-	loadLocalhost = 'load-localhost',
-	webviewReady = 'webview-ready',
-	wheel = 'did-scroll-wheel',
-	fatalError = 'fatal-error',
-	noCspFound = 'no-csp-found',
-	didKeydown = 'did-keydown',
-	didKeyup = 'did-keyup',
-	didContextMenu = 'did-context-menu',
-	dragStart = 'drag-start',
-}
-
-interface IKeydownEvent {
-	key: string;
-	keyCode: number;
-	code: string;
-	shiftKey: boolean;
-	altKey: boolean;
-	ctrlKey: boolean;
-	metaKey: boolean;
-	repeat: boolean;
-}
-
 interface WebviewContent {
 	readonly html: string;
 	readonly options: WebviewContentOptions;
@@ -99,18 +66,15 @@ namespace WebviewState {
 }
 
 interface WebviewActionContext {
-	webview?: string;
-	[key: string]: unknown;
+	readonly webview?: string;
+	readonly [key: string]: unknown;
 }
 
 const webviewIdContext = 'webviewId';
 
 export class WebviewElement extends Disposable implements IWebview, WebviewFindDelegate {
 
-	/**
-	 * External identifier of this webview.
-	 */
-	public readonly id: string;
+	protected readonly id = generateUuid();
 
 	/**
 	 * The provided identifier of this webview.
@@ -122,11 +86,6 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 	 */
 	public readonly origin: string;
 
-	/**
-	 * Unique internal identifier of this webview's iframe element.
-	 */
-	private readonly _iframeId: string;
-
 	private readonly _encodedWebviewOriginPromise: Promise<string>;
 	private _encodedWebviewOrigin: string | undefined;
 
@@ -197,10 +156,8 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 	) {
 		super();
 
-		this.id = initInfo.id;
 		this.providedViewType = initInfo.providedViewType;
-		this._iframeId = generateUuid();
-		this.origin = initInfo.origin ?? this._iframeId;
+		this.origin = initInfo.origin ?? this.id;
 
 		this._encodedWebviewOriginPromise = parentOriginHash(window.origin, this.origin).then(id => this._encodedWebviewOrigin = id);
 
@@ -223,7 +180,7 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 
 
 		const subscription = this._register(addDisposableListener(window, 'message', (e: MessageEvent) => {
-			if (!this._encodedWebviewOrigin || e?.data?.target !== this._iframeId) {
+			if (!this._encodedWebviewOrigin || e?.data?.target !== this.id) {
 				return;
 			}
 
@@ -232,7 +189,7 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 				return;
 			}
 
-			if (e.data.channel === WebviewMessageChannels.webviewReady) {
+			if (e.data.channel === 'webview-ready') {
 				if (this._messagePort) {
 					return;
 				}
@@ -260,66 +217,63 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 			}
 		}));
 
-		this._register(this.on(WebviewMessageChannels.noCspFound, () => {
+		this._register(this.on('no-csp-found', () => {
 			this.handleNoCspFound();
 		}));
 
-		this._register(this.on(WebviewMessageChannels.didClickLink, (uri: string) => {
+		this._register(this.on('did-click-link', ({ uri }) => {
 			this._onDidClickLink.fire(uri);
 		}));
 
-		this._register(this.on(WebviewMessageChannels.onmessage, (data: { message: any; transfer?: ArrayBuffer[] }) => {
-			this._onMessage.fire({
-				message: data.message,
-				transfer: data.transfer,
-			});
+		this._register(this.on('onmessage', ({ message, transfer }) => {
+			this._onMessage.fire({ message, transfer });
 		}));
 
-		this._register(this.on(WebviewMessageChannels.didScroll, (scrollYPercentage: number) => {
-			this._onDidScroll.fire({ scrollYPercentage: scrollYPercentage });
+		this._register(this.on('did-scroll', ({ scrollYPercentage }) => {
+			this._onDidScroll.fire({ scrollYPercentage });
 		}));
 
-		this._register(this.on(WebviewMessageChannels.doReload, () => {
+		this._register(this.on('do-reload', () => {
 			this.reload();
 		}));
 
-		this._register(this.on(WebviewMessageChannels.doUpdateState, (state: any) => {
+		this._register(this.on('do-update-state', (state) => {
 			this.state = state;
 			this._onDidUpdateState.fire(state);
 		}));
 
-		this._register(this.on(WebviewMessageChannels.didFocus, () => {
+		this._register(this.on('did-focus', () => {
 			this.handleFocusChange(true);
 		}));
 
-		this._register(this.on(WebviewMessageChannels.didBlur, () => {
+		this._register(this.on('did-blur', () => {
 			this.handleFocusChange(false);
 		}));
 
-		this._register(this.on(WebviewMessageChannels.wheel, (event: IMouseWheelEvent) => {
+		this._register(this.on('did-scroll-wheel', (event) => {
 			this._onDidWheel.fire(event);
 		}));
 
-		this._register(this.on(WebviewMessageChannels.didFind, (didFind: boolean) => {
+		this._register(this.on('did-find', ({ didFind }) => {
 			this._hasFindResult.fire(didFind);
 		}));
 
-		this._register(this.on<{ message: string }>(WebviewMessageChannels.fatalError, (e) => {
+		this._register(this.on('fatal-error', (e) => {
 			notificationService.error(localize('fatalErrorMessage', "Error loading webview: {0}", e.message));
 		}));
 
-		this._register(this.on(WebviewMessageChannels.didKeydown, (data: KeyboardEvent) => {
+		this._register(this.on('did-keydown', (data) => {
 			// Electron: workaround for https://github.com/electron/electron/issues/14258
 			// We have to detect keyboard events in the <webview> and dispatch them to our
 			// keybinding service because these events do not bubble to the parent window anymore.
 			this.handleKeyEvent('keydown', data);
 		}));
 
-		this._register(this.on(WebviewMessageChannels.didKeyup, (data: KeyboardEvent) => {
+		this._register(this.on('did-keyup', (data) => {
 			this.handleKeyEvent('keyup', data);
 		}));
 
-		this._register(this.on(WebviewMessageChannels.didContextMenu, (data: { clientX: number; clientY: number; context: { [key: string]: unknown } }) => {
+		this._register(this.on('did-context-menu', (data) => {
 			if (!this.element) {
 				return;
 			}
@@ -343,7 +297,7 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 			});
 		}));
 
-		this._register(this.on(WebviewMessageChannels.loadResource, async (entry: { id: number; path: string; query: string; scheme: string; authority: string; ifNoneMatch?: string }) => {
+		this._register(this.on('load-resource', async (entry) => {
 			try {
 				// Restore the authority we previously encoded
 				const authority = decodeAuthority(entry.authority);
@@ -363,7 +317,7 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 			}
 		}));
 
-		this._register(this.on(WebviewMessageChannels.loadLocalhost, (entry: any) => {
+		this._register(this.on('load-localhost', (entry) => {
 			this.localLocalhost(entry.id, entry.origin);
 		}));
 
@@ -376,17 +330,16 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 		this._register(configurationService.onDidChangeConfiguration(e => {
 			if (e.affectsConfiguration('window.confirmBeforeClose')) {
 				this._confirmBeforeClose = configurationService.getValue('window.confirmBeforeClose');
-				this._send(WebviewMessageChannels.setConfirmBeforeClose, this._confirmBeforeClose);
+				this._send('set-confirm-before-close', this._confirmBeforeClose);
 			}
 		}));
 
-		this._register(this.on(WebviewMessageChannels.dragStart, () => {
+		this._register(this.on('drag-start', () => {
 			this._startBlockingIframeDragEvents();
 		}));
 
 		if (initInfo.options.enableFindWidget) {
 			this._webviewFindWidget = this._register(instantiationService.createInstance(WebviewFindWidget, this));
-			this.styledFindWidget();
 		}
 
 		this._encodedWebviewOriginPromise.then(encodedWebviewOrigin => {
@@ -456,7 +409,7 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 		return this._send('message', { message, transfer });
 	}
 
-	private async _send(channel: string, data?: any, _createElement: Transferable[] = []): Promise<boolean> {
+	private async _send<K extends keyof ToWebviewMessage>(channel: K, data: ToWebviewMessage[K], _createElement: Transferable[] = []): Promise<boolean> {
 		if (this._state.type === WebviewState.Type.Initializing) {
 			let resolve: (x: boolean) => void;
 			const promise = new Promise<boolean>(r => resolve = r);
@@ -475,12 +428,11 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 		element.className = `webview ${options.customClasses || ''}`;
 		element.sandbox.add('allow-scripts', 'allow-same-origin', 'allow-forms', 'allow-pointer-lock', 'allow-downloads');
 
-		const allowRules = ['cross-origin-isolated;'];
+		const allowRules = ['cross-origin-isolated', 'autoplay'];
 		if (!isFirefox) {
-			allowRules.push('clipboard-read;', 'clipboard-write;');
-			element.setAttribute('allow', 'clipboard-read; clipboard-write; cross-origin-isolated;');
+			allowRules.push('clipboard-read', 'clipboard-write');
 		}
-		element.setAttribute('allow', allowRules.join(' '));
+		element.setAttribute('allow', allowRules.join('; '));
 
 		element.style.border = 'none';
 		element.style.width = '100%';
@@ -496,7 +448,7 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 	private _initElement(encodedWebviewOrigin: string, extension: WebviewExtensionDescription | undefined, options: WebviewOptions) {
 		// The extensionId and purpose in the URL are used for filtering in js-debug:
 		const params: { [key: string]: string } = {
-			id: this._iframeId,
+			id: this.id,
 			origin: this.origin,
 			swVersion: String(this._expectedServiceWorkerVersion),
 			extensionId: extension?.id.value ?? '',
@@ -523,28 +475,30 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 		this.element!.setAttribute('src', `${this.webviewContentEndpoint(encodedWebviewOrigin)}/${fileName}?${queryString}`);
 	}
 
-	public mountTo(_stopBlockingIframeDragEvents: HTMLElement) {
+	public mountTo(element: HTMLElement) {
 		if (!this.element) {
 			return;
 		}
 
 		if (this._webviewFindWidget) {
-			_stopBlockingIframeDragEvents.appendChild(this._webviewFindWidget.getDomNode());
+			element.appendChild(this._webviewFindWidget.getDomNode());
 		}
 
 		for (const eventName of [EventType.MOUSE_DOWN, EventType.MOUSE_MOVE, EventType.DROP]) {
-			this._register(addDisposableListener(_stopBlockingIframeDragEvents, eventName, () => {
+			this._register(addDisposableListener(element, eventName, () => {
 				this._stopBlockingIframeDragEvents();
 			}));
 		}
 
-		for (const node of [_stopBlockingIframeDragEvents, window]) {
+		for (const node of [element, window]) {
 			this._register(addDisposableListener(node, EventType.DRAG_END, () => {
 				this._stopBlockingIframeDragEvents();
 			}));
 		}
 
-		_stopBlockingIframeDragEvents.appendChild(this.element);
+		element.id = this.id; // This is used by aria-flow for accessibility order
+
+		element.appendChild(this.element);
 	}
 
 	private _startBlockingIframeDragEvents() {
@@ -585,7 +539,7 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 		return false;
 	}
 
-	private on<T = unknown>(channel: WebviewMessageChannels, handler: (data: T, e: MessageEvent) => void): IDisposable {
+	private on<K extends keyof FromWebviewMessage>(channel: K, handler: (data: FromWebviewMessage[K], e: MessageEvent) => void): IDisposable {
 		let handlers = this._messageHandlers.get(channel);
 		if (!handlers) {
 			handlers = new Set();
@@ -627,7 +581,7 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 	public reload(): void {
 		this.doUpdateContent(this._content);
 
-		const subscription = this._register(this.on(WebviewMessageChannels.didLoad, () => {
+		const subscription = this._register(this.on('did-load', () => {
 			this._onDidReload.fire();
 			subscription.dispose();
 		}));
@@ -705,13 +659,8 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 		const screenReader = this._accessibilityService.isScreenReaderOptimized();
 
 		this._send('styles', { styles, activeTheme, themeId, themeLabel, reduceMotion, screenReader });
-
-		this.styledFindWidget();
 	}
 
-	private styledFindWidget() {
-		this._webviewFindWidget?.updateTheme(this.webviewThemeDataProvider.getTheme());
-	}
 
 	protected handleFocusChange(isFocused: boolean): void {
 		this._focused = isFocused;
@@ -722,7 +671,7 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 		}
 	}
 
-	private handleKeyEvent(type: 'keydown' | 'keyup', event: IKeydownEvent) {
+	private handleKeyEvent(type: 'keydown' | 'keyup', event: KeyEvent) {
 		// Create a fake KeyboardEvent from the data provided
 		const emulatedKeyboardEvent = new KeyboardEvent(type, event);
 		// Force override the target
@@ -876,7 +825,7 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 				return;
 			}
 
-			this._send('focus');
+			this._send('focus', undefined);
 		});
 	}
 
@@ -912,7 +861,7 @@ export class WebviewElement extends Disposable implements IWebview, WebviewFindD
 		if (!this.element) {
 			return;
 		}
-		this._send('find-stop', { keepSelection });
+		this._send('find-stop', { clearSelection: !keepSelection });
 		this._onDidStopFind.fire();
 	}
 
