@@ -169,6 +169,7 @@ import product from 'vs/platform/product/common/product';
 			'window.zoomLevel': {
 				'type': 'number',
 				'default': 0,
+				'minimum': -5,
 				'description': localize('zoomLevel', "Adjust the zoom level of the window. The original size is 0 and each increment above (e.g. 1) or below (e.g. -1) represents zooming 20% larger or smaller. You can also enter decimals to adjust the zoom level with a finer granularity."),
 				ignoreSync: true,
 				tags: ['accessibility']
@@ -207,7 +208,7 @@ import product from 'vs/platform/product/common/product';
 			},
 			'window.experimental.windowControlsOverlay.enabled': {
 				'type': 'boolean',
-				'default': false,
+				'default': true,
 				'scope': ConfigurationScope.APPLICATION,
 				'description': localize('windowControlsOverlay', "Use window controls provided by the platform instead of our HTML-based window controls. Changes require a full restart to apply."),
 				'included': isWindows
@@ -244,6 +245,7 @@ import product from 'vs/platform/product/common/product';
 				type: 'boolean',
 				description: localize('experimentalUseSandbox', "Experimental: When enabled, the window will have sandbox mode enabled via Electron API."),
 				default: typeof product.quality === 'string' && product.quality !== 'stable', // disabled by default in stable for now
+				tags: product.quality === 'stable' ? ['experimental'] : undefined,
 				'scope': ConfigurationScope.APPLICATION,
 				ignoreSync: true
 			},
@@ -334,7 +336,7 @@ import product from 'vs/platform/product/common/product';
 			},
 			'log-level': {
 				type: 'string',
-				description: localize('argv.logLevel', "Log level to use. Default is 'info'. Allowed values are 'critical', 'error', 'warn', 'info', 'debug', 'trace', 'off'.")
+				description: localize('argv.logLevel', "Log level to use. Default is 'info'. Allowed values are 'error', 'warn', 'info', 'debug', 'trace', 'off'.")
 			}
 		}
 	};
