@@ -6,7 +6,7 @@
 import { VSBuffer, VSBufferReadable, VSBufferReadableStream } from 'vs/base/common/buffer';
 import { URI } from 'vs/base/common/uri';
 import { IFileStatWithMetadata, IWriteFileOptions } from 'vs/platform/files/common/files';
-import { registerSingleton } from 'vs/platform/instantiation/common/extensions';
+import { InstantiationType, registerSingleton } from 'vs/platform/instantiation/common/extensions';
 import { IElevatedFileService } from 'vs/workbench/services/files/common/elevatedFileService';
 
 export class BrowserElevatedFileService implements IElevatedFileService {
@@ -25,4 +25,4 @@ export class BrowserElevatedFileService implements IElevatedFileService {
 	}
 }
 
-registerSingleton(IElevatedFileService, BrowserElevatedFileService, true);
+registerSingleton(IElevatedFileService, BrowserElevatedFileService, InstantiationType.Delayed);
