@@ -8,11 +8,11 @@ import { Emitter, Event } from 'vs/base/common/event';
 import { Disposable } from 'vs/base/common/lifecycle';
 import { KeymapInfo, IRawMixedKeyboardMapping, IKeymapInfo } from 'vs/workbench/services/keybinding/common/keymapInfo';
 import { InstantiationType, registerSingleton } from 'vs/platform/instantiation/common/extensions';
-import { DispatchConfig } from 'vs/platform/keyboardLayout/common/dispatchConfig';
+import { DispatchConfig, readKeyboardConfig } from 'vs/platform/keyboardLayout/common/keyboardConfig';
 import { IKeyboardMapper, CachedKeyboardMapper } from 'vs/platform/keyboardLayout/common/keyboardMapper';
 import { OS, OperatingSystem, isMacintosh, isWindows } from 'vs/base/common/platform';
 import { WindowsKeyboardMapper } from 'vs/workbench/services/keybinding/common/windowsKeyboardMapper';
-import { MacLinuxFallbackKeyboardMapper } from 'vs/workbench/services/keybinding/common/macLinuxFallbackKeyboardMapper';
+import { FallbackKeyboardMapper } from 'vs/workbench/services/keybinding/common/fallbackKeyboardMapper';
 import { IKeyboardEvent } from 'vs/platform/keybinding/common/keybinding';
 import { MacLinuxKeyboardMapper } from 'vs/workbench/services/keybinding/common/macLinuxKeyboardMapper';
 import { StandardKeyboardEvent } from 'vs/base/browser/keyboardEvent';
@@ -31,7 +31,7 @@ import { ICommandService } from 'vs/platform/commands/common/commands';
 import { IStorageService } from 'vs/platform/storage/common/storage';
 import { getKeyboardLayoutId, IKeyboardLayoutInfo, IKeyboardLayoutService, IKeyboardMapping, IMacLinuxKeyboardMapping, IWindowsKeyboardMapping } from 'vs/platform/keyboardLayout/common/keyboardLayout';
 
-export class BrowserKeyboardMapperFactoryBase {
+export class BrowserKeyboardMapperFactoryBase extends Disposable {
 	// keyboard mapper
 	protected _initialized: boolean;
 	protected _keyboardMapper: IKeyboardMapper | null;
@@ -56,7 +56,7 @@ export class BrowserKeyboardMapperFactoryBase {
 			return null;
 		}
 
-		return this._activeKeymapInfo && this._activeKeymapInfo.layout;
+		return this._activeKeymapInfo?.layout ?? null;
 	}
 
 	get activeKeyMapping(): IKeyboardMapping | null {
@@ -64,7 +64,7 @@ export class BrowserKeyboardMapperFactoryBase {
 			return null;
 		}
 
-		return this._activeKeymapInfo && this._activeKeymapInfo.mapping;
+		return this._activeKeymapInfo?.mapping ?? null;
 	}
 
 	get keyboardLayouts(): IKeyboardLayoutInfo[] {
@@ -72,10 +72,12 @@ export class BrowserKeyboardMapperFactoryBase {
 	}
 
 	protected constructor(
+		private readonly _configurationService: IConfigurationService,
 		// private _notificationService: INotificationService,
 		// private _storageService: IStorageService,
 		// private _commandService: ICommandService
 	) {
+		super();
 		this._keyboardMapper = null;
 		this._initialized = false;
 		this._keymapInfos = [];
@@ -94,6 +96,13 @@ export class BrowserKeyboardMapperFactoryBase {
 				});
 			});
 		}
+
+		this._register(this._configurationService.onDidChangeConfiguration((e) => {
+			if (e.affectsConfiguration('keyboard')) {
+				this._keyboardMapper = null;
+				this._onDidChangeKeyboardMapper.fire();
+			}
+		}));
 	}
 
 	registerKeyboardLayout(layout: KeymapInfo) {
@@ -270,15 +279,16 @@ export class BrowserKeyboardMapperFactoryBase {
 		});
 	}
 
-	public getKeyboardMapper(dispatchConfig: DispatchConfig): IKeyboardMapper {
-		if (!this._initialized) {
-			return new MacLinuxFallbackKeyboardMapper(OS);
-		}
-		if (dispatchConfig === DispatchConfig.KeyCode) {
+	public getKeyboardMapper(): IKeyboardMapper {
+		const config = readKeyboardConfig(this._configurationService);
+		if (config.dispatch === DispatchConfig.KeyCode || !this._initialized || !this._activeKeymapInfo) {
 			// Forcefully set to use keyCode
-			return new MacLinuxFallbackKeyboardMapper(OS);
+			return new FallbackKeyboardMapper(config.mapAltGrToCtrlAlt, OS);
 		}
-		return this._keyboardMapper!;
+		if (!this._keyboardMapper) {
+			this._keyboardMapper = new CachedKeyboardMapper(BrowserKeyboardMapperFactory._createKeyboardMapper(this._activeKeymapInfo, config.mapAltGrToCtrlAlt));
+		}
+		return this._keyboardMapper;
 	}
 
 	public validateCurrentKeyboardMapping(keyboardEvent: IKeyboardEvent): void {
@@ -306,22 +316,22 @@ export class BrowserKeyboardMapperFactoryBase {
 	private _setKeyboardData(keymapInfo: KeymapInfo): void {
 		this._initialized = true;
 
-		this._keyboardMapper = new CachedKeyboardMapper(BrowserKeyboardMapperFactory._createKeyboardMapper(keymapInfo));
+		this._keyboardMapper = null;
 		this._onDidChangeKeyboardMapper.fire();
 	}
 
-	private static _createKeyboardMapper(keymapInfo: KeymapInfo): IKeyboardMapper {
+	private static _createKeyboardMapper(keymapInfo: KeymapInfo, mapAltGrToCtrlAlt: boolean): IKeyboardMapper {
 		const rawMapping = keymapInfo.mapping;
 		const isUSStandard = !!keymapInfo.layout.isUSStandard;
 		if (OS === OperatingSystem.Windows) {
-			return new WindowsKeyboardMapper(isUSStandard, <IWindowsKeyboardMapping>rawMapping);
+			return new WindowsKeyboardMapper(isUSStandard, <IWindowsKeyboardMapping>rawMapping, mapAltGrToCtrlAlt);
 		}
 		if (Object.keys(rawMapping).length === 0) {
 			// Looks like reading the mappings failed (most likely Mac + Japanese/Chinese keyboard layouts)
-			return new MacLinuxFallbackKeyboardMapper(OS);
+			return new FallbackKeyboardMapper(mapAltGrToCtrlAlt, OS);
 		}
 
-		return new MacLinuxKeyboardMapper(isUSStandard, <IMacLinuxKeyboardMapping>rawMapping, OS);
+		return new MacLinuxKeyboardMapper(isUSStandard, <IMacLinuxKeyboardMapping>rawMapping, mapAltGrToCtrlAlt, OS);
 	}
 
 	//#region Browser API
@@ -436,9 +446,9 @@ export class BrowserKeyboardMapperFactoryBase {
 }
 
 export class BrowserKeyboardMapperFactory extends BrowserKeyboardMapperFactoryBase {
-	constructor(notificationService: INotificationService, storageService: IStorageService, commandService: ICommandService) {
+	constructor(configurationService: IConfigurationService, notificationService: INotificationService, storageService: IStorageService, commandService: ICommandService) {
 		// super(notificationService, storageService, commandService);
-		super();
+		super(configurationService);
 
 		const platform = isWindows ? 'win' : isMacintosh ? 'darwin' : 'linux';
 
@@ -526,7 +536,7 @@ export class BrowserKeyboardLayoutService extends Disposable implements IKeyboar
 		const keyboardConfig = configurationService.getValue<{ layout: string }>('keyboard');
 		const layout = keyboardConfig.layout;
 		this._keyboardLayoutMode = layout ?? 'autodetect';
-		this._factory = new BrowserKeyboardMapperFactory(notificationService, storageService, commandService);
+		this._factory = new BrowserKeyboardMapperFactory(configurationService, notificationService, storageService, commandService);
 
 		this._register(this._factory.onDidChangeKeyboardMapper(() => {
 			this._onDidChangeKeyboardLayout.fire();
@@ -593,8 +603,8 @@ export class BrowserKeyboardLayoutService extends Disposable implements IKeyboar
 		}
 	}
 
-	getKeyboardMapper(dispatchConfig: DispatchConfig): IKeyboardMapper {
-		return this._factory.getKeyboardMapper(dispatchConfig);
+	getKeyboardMapper(): IKeyboardMapper {
+		return this._factory.getKeyboardMapper();
 	}
 
 	public getCurrentKeyboardLayout(): IKeyboardLayoutInfo | null {
