@@ -15,9 +15,9 @@ import { IMacLinuxKeyboardMapping } from 'vs/platform/keyboardLayout/common/keyb
 
 const WRITE_FILE_IF_DIFFERENT = false;
 
-async function createKeyboardMapper(isUSStandard: boolean, file: string, OS: OperatingSystem): Promise<MacLinuxKeyboardMapper> {
+async function createKeyboardMapper(isUSStandard: boolean, file: string, mapAltGrToCtrlAlt: boolean, OS: OperatingSystem): Promise<MacLinuxKeyboardMapper> {
 	const rawMappings = await readRawMapping<IMacLinuxKeyboardMapping>(file);
-	return new MacLinuxKeyboardMapper(isUSStandard, rawMappings, OS);
+	return new MacLinuxKeyboardMapper(isUSStandard, rawMappings, mapAltGrToCtrlAlt, OS);
 }
 
 suite('keyboardMapper - MAC de_ch', () => {
@@ -25,7 +25,7 @@ suite('keyboardMapper - MAC de_ch', () => {
 	let mapper: MacLinuxKeyboardMapper;
 
 	suiteSetup(async () => {
-		const _mapper = await createKeyboardMapper(false, 'mac_de_ch', OperatingSystem.Macintosh);
+		const _mapper = await createKeyboardMapper(false, 'mac_de_ch', false, OperatingSystem.Macintosh);
 		mapper = _mapper;
 	});
 
@@ -113,6 +113,7 @@ suite('keyboardMapper - MAC de_ch', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: true,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'KeyY'
 			},
@@ -154,6 +155,7 @@ suite('keyboardMapper - MAC de_ch', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: true,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'BracketRight'
 			},
@@ -307,6 +309,7 @@ suite('keyboardMapper - MAC de_ch', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: true,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'Home'
 			},
@@ -356,6 +359,7 @@ suite('keyboardMapper - MAC de_ch', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: true,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'MetaLeft'
 			},
@@ -381,6 +385,7 @@ suite('keyboardMapper - MAC de_ch', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: true,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'MetaRight'
 			},
@@ -403,7 +408,7 @@ suite('keyboardMapper - MAC en_us', () => {
 	let mapper: MacLinuxKeyboardMapper;
 
 	suiteSetup(async () => {
-		const _mapper = await createKeyboardMapper(true, 'mac_en_us', OperatingSystem.Macintosh);
+		const _mapper = await createKeyboardMapper(true, 'mac_en_us', false, OperatingSystem.Macintosh);
 		mapper = _mapper;
 	});
 
@@ -440,6 +445,7 @@ suite('keyboardMapper - MAC en_us', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: true,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'MetaLeft'
 			},
@@ -465,6 +471,7 @@ suite('keyboardMapper - MAC en_us', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: true,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'MetaRight'
 			},
@@ -480,6 +487,34 @@ suite('keyboardMapper - MAC en_us', () => {
 			}
 		);
 	});
+
+	test('resolveKeyboardEvent mapAltGrToCtrlAlt AltGr+Z', async () => {
+		const mapper = await createKeyboardMapper(true, 'mac_en_us', true, OperatingSystem.Macintosh);
+
+		assertResolveKeyboardEvent(
+			mapper,
+			{
+				_standardKeyboardEventBrand: true,
+				ctrlKey: false,
+				shiftKey: false,
+				altKey: false,
+				metaKey: false,
+				altGraphKey: true,
+				keyCode: -1,
+				code: 'KeyZ'
+			},
+			{
+				label: '⌃⌥Z',
+				ariaLabel: 'Control+Option+Z',
+				electronAccelerator: 'Ctrl+Alt+Z',
+				userSettingsLabel: 'ctrl+alt+z',
+				isWYSIWYG: true,
+				isChord: false,
+				dispatchParts: ['ctrl+alt+[KeyZ]'],
+				singleModifierDispatchParts: [null],
+			}
+		);
+	});
 });
 
 suite('keyboardMapper - LINUX de_ch', () => {
@@ -487,7 +522,7 @@ suite('keyboardMapper - LINUX de_ch', () => {
 	let mapper: MacLinuxKeyboardMapper;
 
 	suiteSetup(async () => {
-		const _mapper = await createKeyboardMapper(false, 'linux_de_ch', OperatingSystem.Linux);
+		const _mapper = await createKeyboardMapper(false, 'linux_de_ch', false, OperatingSystem.Linux);
 		mapper = _mapper;
 	});
 
@@ -559,6 +594,7 @@ suite('keyboardMapper - LINUX de_ch', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'KeyY'
 			},
@@ -591,6 +627,7 @@ suite('keyboardMapper - LINUX de_ch', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'BracketRight'
 			},
@@ -744,6 +781,7 @@ suite('keyboardMapper - LINUX de_ch', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'Home'
 			},
@@ -769,6 +807,7 @@ suite('keyboardMapper - LINUX de_ch', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'KeyX'
 			},
@@ -813,6 +852,7 @@ suite('keyboardMapper - LINUX de_ch', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'ControlLeft'
 			},
@@ -838,6 +878,7 @@ suite('keyboardMapper - LINUX de_ch', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'ControlRight'
 			},
@@ -860,7 +901,7 @@ suite('keyboardMapper - LINUX en_us', () => {
 	let mapper: MacLinuxKeyboardMapper;
 
 	suiteSetup(async () => {
-		const _mapper = await createKeyboardMapper(true, 'linux_en_us', OperatingSystem.Linux);
+		const _mapper = await createKeyboardMapper(true, 'linux_en_us', false, OperatingSystem.Linux);
 		mapper = _mapper;
 	});
 
@@ -913,6 +954,7 @@ suite('keyboardMapper - LINUX en_us', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'KeyZ'
 			},
@@ -954,6 +996,7 @@ suite('keyboardMapper - LINUX en_us', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'BracketRight'
 			},
@@ -1107,6 +1150,7 @@ suite('keyboardMapper - LINUX en_us', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'Home'
 			},
@@ -1173,6 +1217,7 @@ suite('keyboardMapper - LINUX en_us', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'NumpadEnter'
 			},
@@ -1235,6 +1280,7 @@ suite('keyboardMapper - LINUX en_us', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'ControlLeft'
 			},
@@ -1260,6 +1306,7 @@ suite('keyboardMapper - LINUX en_us', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'ControlRight'
 			},
@@ -1285,6 +1332,7 @@ suite('keyboardMapper - LINUX en_us', () => {
 				shiftKey: true,
 				altKey: false,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'ShiftLeft'
 			},
@@ -1310,6 +1358,7 @@ suite('keyboardMapper - LINUX en_us', () => {
 				shiftKey: true,
 				altKey: false,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'ShiftRight'
 			},
@@ -1335,6 +1384,7 @@ suite('keyboardMapper - LINUX en_us', () => {
 				shiftKey: false,
 				altKey: true,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'AltLeft'
 			},
@@ -1360,6 +1410,7 @@ suite('keyboardMapper - LINUX en_us', () => {
 				shiftKey: false,
 				altKey: true,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'AltRight'
 			},
@@ -1385,6 +1436,7 @@ suite('keyboardMapper - LINUX en_us', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: true,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'MetaLeft'
 			},
@@ -1410,6 +1462,7 @@ suite('keyboardMapper - LINUX en_us', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: true,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'MetaRight'
 			},
@@ -1435,6 +1488,7 @@ suite('keyboardMapper - LINUX en_us', () => {
 				shiftKey: true,
 				altKey: false,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'ShiftLeft'
 			},
@@ -1450,6 +1504,34 @@ suite('keyboardMapper - LINUX en_us', () => {
 			}
 		);
 	});
+
+	test('resolveKeyboardEvent mapAltGrToCtrlAlt AltGr+Z', async () => {
+		const mapper = await createKeyboardMapper(true, 'linux_en_us', true, OperatingSystem.Linux);
+
+		assertResolveKeyboardEvent(
+			mapper,
+			{
+				_standardKeyboardEventBrand: true,
+				ctrlKey: false,
+				shiftKey: false,
+				altKey: false,
+				metaKey: false,
+				altGraphKey: true,
+				keyCode: -1,
+				code: 'KeyZ'
+			},
+			{
+				label: 'Ctrl+Alt+Z',
+				ariaLabel: 'Control+Alt+Z',
+				electronAccelerator: 'Ctrl+Alt+Z',
+				userSettingsLabel: 'ctrl+alt+z',
+				isWYSIWYG: true,
+				isChord: false,
+				dispatchParts: ['ctrl+alt+[KeyZ]'],
+				singleModifierDispatchParts: [null],
+			}
+		);
+	});
 });
 
 suite('keyboardMapper', () => {
@@ -1462,7 +1544,7 @@ suite('keyboardMapper', () => {
 				'withAltGr': '|',
 				'withShiftAltGr': '|'
 			}
-		}, OperatingSystem.Linux);
+		}, false, OperatingSystem.Linux);
 
 		assertResolveKeyboardEvent(
 			mapper,
@@ -1472,6 +1554,7 @@ suite('keyboardMapper', () => {
 				shiftKey: false,
 				altKey: false,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'Backquote'
 			},
@@ -1489,7 +1572,7 @@ suite('keyboardMapper', () => {
 	});
 
 	test('issue #24064: NumLock/NumPad keys stopped working in 1.11 on Linux', () => {
-		const mapper = new MacLinuxKeyboardMapper(false, {}, OperatingSystem.Linux);
+		const mapper = new MacLinuxKeyboardMapper(false, {}, false, OperatingSystem.Linux);
 
 		function assertNumpadKeyboardEvent(keyCode: KeyCode, code: string, label: string, electronAccelerator: string | null, userSettingsLabel: string, dispatch: string): void {
 			assertResolveKeyboardEvent(
@@ -1500,6 +1583,7 @@ suite('keyboardMapper', () => {
 					shiftKey: false,
 					altKey: false,
 					metaKey: false,
+					altGraphKey: false,
 					keyCode: keyCode,
 					code: code
 				},
@@ -1530,7 +1614,7 @@ suite('keyboardMapper', () => {
 	});
 
 	test('issue #24107: Delete, Insert, Home, End, PgUp, PgDn, and arrow keys no longer work editor in 1.11', () => {
-		const mapper = new MacLinuxKeyboardMapper(false, {}, OperatingSystem.Linux);
+		const mapper = new MacLinuxKeyboardMapper(false, {}, false, OperatingSystem.Linux);
 
 		function assertKeyboardEvent(keyCode: KeyCode, code: string, label: string, electronAccelerator: string, userSettingsLabel: string, dispatch: string): void {
 			assertResolveKeyboardEvent(
@@ -1541,6 +1625,7 @@ suite('keyboardMapper', () => {
 					shiftKey: false,
 					altKey: false,
 					metaKey: false,
+					altGraphKey: false,
 					keyCode: keyCode,
 					code: code
 				},
@@ -1588,7 +1673,7 @@ suite('keyboardMapper - LINUX ru', () => {
 	let mapper: MacLinuxKeyboardMapper;
 
 	suiteSetup(async () => {
-		const _mapper = await createKeyboardMapper(false, 'linux_ru', OperatingSystem.Linux);
+		const _mapper = await createKeyboardMapper(false, 'linux_ru', false, OperatingSystem.Linux);
 		mapper = _mapper;
 	});
 
@@ -1622,7 +1707,7 @@ suite('keyboardMapper - LINUX en_uk', () => {
 	let mapper: MacLinuxKeyboardMapper;
 
 	suiteSetup(async () => {
-		const _mapper = await createKeyboardMapper(false, 'linux_en_uk', OperatingSystem.Linux);
+		const _mapper = await createKeyboardMapper(false, 'linux_en_uk', false, OperatingSystem.Linux);
 		mapper = _mapper;
 	});
 
@@ -1639,6 +1724,7 @@ suite('keyboardMapper - LINUX en_uk', () => {
 				shiftKey: false,
 				altKey: true,
 				metaKey: false,
+				altGraphKey: false,
 				keyCode: -1,
 				code: 'Minus'
 			},
@@ -1661,7 +1747,7 @@ suite('keyboardMapper - MAC zh_hant', () => {
 	let mapper: MacLinuxKeyboardMapper;
 
 	suiteSetup(async () => {
-		const _mapper = await createKeyboardMapper(false, 'mac_zh_hant', OperatingSystem.Macintosh);
+		const _mapper = await createKeyboardMapper(false, 'mac_zh_hant', false, OperatingSystem.Macintosh);
 		mapper = _mapper;
 	});
 
@@ -1695,7 +1781,7 @@ suite('keyboardMapper - MAC zh_hant2', () => {
 	let mapper: MacLinuxKeyboardMapper;
 
 	suiteSetup(async () => {
-		const _mapper = await createKeyboardMapper(false, 'mac_zh_hant2', OperatingSystem.Macintosh);
+		const _mapper = await createKeyboardMapper(false, 'mac_zh_hant2', false, OperatingSystem.Macintosh);
 		mapper = _mapper;
 	});
 
