@@ -99,7 +99,7 @@ suite('Themes - TokenStyleResolving', () => {
 
 	test('color defaults', async () => {
 		const themeData = ColorThemeData.createUnloadedTheme('foo');
-		themeData.location = FileAccess.asFileUri('./color-theme.json', require);
+		themeData.location = FileAccess.asFileUri('vs/workbench/services/themes/test/electron-browser/color-theme.json');
 		await themeData.ensureLoaded(extensionResourceLoaderService);
 
 		assert.strictEqual(themeData.isLoaded, true);
