@@ -246,7 +246,7 @@ export abstract class AbstractWorkspaceEditingService implements IWorkspaceEditi
 		} else {
 			path = untitledWorkspace.configPath;
 			if (!this.userDataProfileService.currentProfile.isDefault) {
-				await this.userDataProfilesService.setProfileForWorkspace(this.userDataProfileService.currentProfile, untitledWorkspace);
+				await this.userDataProfilesService.setProfileForWorkspace(untitledWorkspace, this.userDataProfileService.currentProfile);
 			}
 		}
 
@@ -285,7 +285,7 @@ export abstract class AbstractWorkspaceEditingService implements IWorkspaceEditi
 		const isNotUntitledWorkspace = !isUntitledWorkspace(targetConfigPathURI, this.environmentService);
 		if (isNotUntitledWorkspace && !this.userDataProfileService.currentProfile.isDefault) {
 			const newWorkspace = await this.workspacesService.getWorkspaceIdentifier(targetConfigPathURI);
-			await this.userDataProfilesService.setProfileForWorkspace(this.userDataProfileService.currentProfile, newWorkspace);
+			await this.userDataProfilesService.setProfileForWorkspace(newWorkspace, this.userDataProfileService.currentProfile);
 		}
 
 		// Return early if target is same as source
