@@ -3,7 +3,7 @@
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
 
-import { CancellationTokenSource } from 'vs/base/common/cancellation';
+import { CancellationToken } from 'vs/base/common/cancellation';
 import { IDisposable, toDisposable } from 'vs/base/common/lifecycle';
 import { InstantiationType, registerSingleton } from 'vs/platform/instantiation/common/extensions';
 import { ILogService } from 'vs/platform/log/common/log';
@@ -32,22 +32,22 @@ export class EditSessionIdentityService implements IEditSessionIdentityService {
 		});
 	}
 
-	async getEditSessionIdentifier(workspaceFolder: IWorkspaceFolder, cancellationTokenSource: CancellationTokenSource): Promise<string | undefined> {
+	async getEditSessionIdentifier(workspaceFolder: IWorkspaceFolder, token: CancellationToken): Promise<string | undefined> {
 		const { scheme } = workspaceFolder.uri;
 
 		const provider = await this.activateProvider(scheme);
 		this._logService.trace(`EditSessionIdentityProvider for scheme ${scheme} available: ${!!provider}`);
 
-		return provider?.getEditSessionIdentifier(workspaceFolder, cancellationTokenSource.token);
+		return provider?.getEditSessionIdentifier(workspaceFolder, token);
 	}
 
-	async provideEditSessionIdentityMatch(workspaceFolder: IWorkspaceFolder, identity1: string, identity2: string, cancellationTokenSource: CancellationTokenSource): Promise<EditSessionIdentityMatch | undefined> {
+	async provideEditSessionIdentityMatch(workspaceFolder: IWorkspaceFolder, identity1: string, identity2: string, cancellationToken: CancellationToken): Promise<EditSessionIdentityMatch | undefined> {
 		const { scheme } = workspaceFolder.uri;
 
 		const provider = await this.activateProvider(scheme);
 		this._logService.trace(`EditSessionIdentityProvider for scheme ${scheme} available: ${!!provider}`);
 
-		return provider?.provideEditSessionIdentityMatch?.(workspaceFolder, identity1, identity2, cancellationTokenSource.token);
+		return provider?.provideEditSessionIdentityMatch?.(workspaceFolder, identity1, identity2, cancellationToken);
 	}
 
 	private async activateProvider(scheme: string) {
