@@ -68,7 +68,7 @@ const NULL_PROFILE = {
 	keybindingsResource: joinPath(URI.file(homeDir), 'keybindings.json'),
 	tasksResource: joinPath(URI.file(homeDir), 'tasks.json'),
 	snippetsHome: joinPath(URI.file(homeDir), 'snippets'),
-	extensionsResource: undefined
+	extensionsResource: joinPath(URI.file(homeDir), 'extensions.json')
 };
 
 export const TestNativeWindowConfiguration: INativeWindowConfiguration = {
@@ -276,6 +276,7 @@ export class TestNativeHostService implements INativeHostService {
 	async sendInputEvent(event: MouseInputEvent): Promise<void> { }
 	async windowsGetStringRegKey(hive: 'HKEY_CURRENT_USER' | 'HKEY_LOCAL_MACHINE' | 'HKEY_CLASSES_ROOT' | 'HKEY_USERS' | 'HKEY_CURRENT_CONFIG', path: string, name: string): Promise<string | undefined> { return undefined; }
 	async profileRenderer(): Promise<any> { throw new Error(); }
+	async enableSandbox(enabled: boolean): Promise<void> { throw new Error('Method not implemented.'); }
 }
 
 export function workbenchInstantiationService(disposables = new DisposableStore()): ITestInstantiationService {
